-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '0.9.3'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '0.10.0'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION


    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    -- ACTUALIZAMOS EL NUEVO CAMPO PARA TODAS LAS HABILIDADES
    UPDATE [dbo].[Ability]  SET [Type] = CASE WHEN [Query] IS NULL THEN 'MANUAL' ELSE 'MANUAL_AUTOMATIC' END

    -- ACTUALIZAMOS LOS REGISTROS YA EXISTENTES, QUE HAN SIDO NETAMENTE MANUAL O NETAMENTE AUTOMATICOS
    UPDATE [dbo].[AuditorEvaluationPlan]
        SET [AutomaticScore] = CASE WHEN [IdAuditor] = 'SPEECH' THEN [Score] ELSE 0 END,  
            [ManualScore] = CASE WHEN [IdAuditor] <> 'SPEECH' THEN [Score] ELSE 0 END  
        WHERE [Completed] = 1

    -- ACTUALIZAMOS A 0 LA NOTA MINIMA PARA LA PARTE AUTOMATICA DE LOS FORMATOS DE EVALUACION
    UPDATE [dbo].[EvaluationFormat] SET [MinAutomaticQualification] = 0

    
    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH