-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '0.12.0'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '0.13.0'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION


    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION





    -- DECLARAMOS UNA VARIABLE PARA ALMACENAR LAS HABILIDADES QUE MIGRAREMOS
    DECLARE RECURRENT_CURSOR CURSOR 
    LOCAL STATIC READ_ONLY FORWARD_ONLY
        FOR 
        -- SELECCIONAMOS LAS HABILIDADES AUTOMATICAS QUE TENGAN QUERY
        SELECT A.[Instance], 
                A.[ID], 
                A.[QueryName], 
                A.[Query] 
            FROM [dbo].[Ability] A (NOLOCK) 
            WHERE A.[Type] = 'MANUAL_AUTOMATIC' 
                AND A.[QueryName] IS NOT NULL 
                AND A.[Query] IS NOT NULL

    -- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS ACTUALIZANDO
    DECLARE @CURRENT_VCC VARCHAR(50) = ''
    DECLARE @CURRENT_ABILITY_ID VARCHAR(50) = ''
    DECLARE @CURRENT_QUERY_ID VARCHAR(50) = ''
    DECLARE @CURRENT_QUERY_CONTENT VARCHAR(1000) = ''

    -- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
    OPEN RECURRENT_CURSOR
    FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC, @CURRENT_ABILITY_ID, @CURRENT_QUERY_ID, @CURRENT_QUERY_CONTENT
    WHILE @@FETCH_STATUS = 0
    BEGIN 

        -- EJECUTAMOS EL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE`

            
        INSERT [dbo].[AbilityQuery] ([ID], [VCC], [AbilityId], [QueryId], [QueryContent], [AcceptancePercentage], [Order], [CreatedDate], [TimeStamp]) VALUES (NEWID(), @CURRENT_VCC, @CURRENT_ABILITY_ID, @CURRENT_QUERY_ID, @CURRENT_QUERY_CONTENT, 0.5, 1, GETUTCDATE(), GETUTCDATE())
            

        -- FIN DEL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE

        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC, @CURRENT_ABILITY_ID, @CURRENT_QUERY_ID, @CURRENT_QUERY_CONTENT
    END
    CLOSE RECURRENT_CURSOR
    DEALLOCATE RECURRENT_CURSOR

    -- ACTUALIZAMOS EL TIPO DE ANALISIS PARA LAS HABILIDADES YA EXISTENTES
    UPDATE [dbo].[Ability] SET [AnalysisType] = CASE WHEN [Query] LIKE '%|%' THEN 'COGNITVE' ELSE 'SEMANTIC' END WHERE [TYPE] = 'MANUAL_AUTOMATIC'    

    
    

    
    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH

