PRINT N'Iniciando recompilación de la tabla [dbo].[Ability]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_Ability] (
    [Instance]             VARCHAR (50)   NOT NULL,
    [ID]                   VARCHAR (50)   NOT NULL,
    [Title]                VARCHAR (100)  NOT NULL,
    [Detail]               VARCHAR (500)  NOT NULL,
    [Type]                 VARCHAR (50)   NULL,
    [Binary]               BIT            NULL,
    [NotApply]             BIT            NULL,
    [AcceptComments]       BIT            NULL,
    [CreatedDate]          DATETIME       NULL,
    [CreatedByUserId]      VARCHAR (50)   NULL,
    [LastModifiedDate]     DATETIME       NULL,
    [LastModifiedByUserId] VARCHAR (50)   NULL,
    [TimeStamp]            DATETIME       NULL,
    [Enabled]              BIT            NULL,
    [AnalysisType]         VARCHAR (25)   NULL,
    [Query]                VARCHAR (1000) NULL,
    [QueryName]            VARCHAR (50)   NULL,
    [Language]             VARCHAR (50)   NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_Ability1] PRIMARY KEY CLUSTERED ([Instance] ASC, [ID] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[Ability])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_Ability] ([Instance], [ID], [Title], [Detail], [Type], [Binary], [NotApply], [AcceptComments], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp], [Enabled], [Query], [QueryName])
        SELECT   [Instance],
                 [ID],
                 [Title],
                 [Detail],
                 [Type],
                 [Binary],
                 [NotApply],
                 [AcceptComments],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp],
                 [Enabled],
                 [Query],
                 [QueryName]
        FROM     [dbo].[Ability]
        ORDER BY [Instance] ASC, [ID] ASC;
    END

DROP TABLE [dbo].[Ability];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_Ability]', N'Ability';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_Ability1]', N'PK_Ability', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Creando [dbo].[AbilityQuery]...';


GO
CREATE TABLE [dbo].[AbilityQuery] (
    [ID]                   VARCHAR (50)    NOT NULL,
    [VCC]                  VARCHAR (50)    NOT NULL,
    [AbilityId]            VARCHAR (50)    NOT NULL,
    [QueryId]              VARCHAR (50)    NOT NULL,
    [QueryContent]         VARCHAR (1000)  NULL,
    [AcceptancePercentage] DECIMAL (18, 2) NULL,
    [Order]                INT             NULL,
    [CreatedDate]          DATETIME        NULL,
    [CreatedByUserId]      VARCHAR (50)    NULL,
    [LastModifiedDate]     DATETIME        NULL,
    [LastModifiedByUserId] VARCHAR (50)    NULL,
    [TimeStamp]            DATETIME        NULL
);


GO
PRINT N'Creando [dbo].[AbilityQueryEntity]...';


GO
CREATE TABLE [dbo].[AbilityQueryEntity] (
    [VCC]                  VARCHAR (50)    NOT NULL,
    [AbilityQueryId]       VARCHAR (50)    NOT NULL,
    [EntityId]             VARCHAR (50)    NOT NULL,
    [EntityName]           VARCHAR (50)    NULL,
    [AcceptancePercentage] DECIMAL (18, 2) NULL,
    [Order]                INT             NULL,
    [CreatedDate]          DATETIME        NULL,
    [CreatedByUserId]      VARCHAR (50)    NULL,
    [LastModifiedDate]     DATETIME        NULL,
    [LastModifiedByUserId] VARCHAR (50)    NULL,
    [TimeStamp]            DATETIME        NULL
);


GO
PRINT N'Creando [dbo].[DF_AbilityQuery_AcceptancePercentage]...';


GO
ALTER TABLE [dbo].[AbilityQuery]
    ADD CONSTRAINT [DF_AbilityQuery_AcceptancePercentage] DEFAULT ((0)) FOR [AcceptancePercentage];


GO
PRINT N'Creando [dbo].[DF_AbilityQueryEntity_AcceptancePercentage]...';


GO
ALTER TABLE [dbo].[AbilityQueryEntity]
    ADD CONSTRAINT [DF_AbilityQueryEntity_AcceptancePercentage] DEFAULT ((0)) FOR [AcceptancePercentage];


GO
PRINT N'Modificando [dbo].[GetAbility]...';


GO

ALTER PROCEDURE [dbo].[GetAbility] (
	@Instance Varchar(50) = NULL, @ID Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[ID]							'id',
		[Title]							'title',
		[Detail]						'detail',
		[Type]							'type',
		[AnalysisType]					'analysisType',
		[Binary]						'binary',
		[NotApply]						'notApply',
		[AcceptComments]				'acceptComments',
		[CreatedDate]					'createdDate',
		[CreatedByUserId]				'createdByUserId',
		[LastModifiedDate]				'lastModifiedDate',
		[LastModifiedByUserId]			'lastModifiedByUserId',
		[Enabled]						'enabled',
		[Query]							'query',
		[QueryName]                     'queryName',
		[Language]						'language'
	FROM [dbo].[Ability] (NOLOCK)
	WHERE [Instance] = @Instance
		AND [ID] = @ID

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAbilityEvaluationFormats]...';


GO


ALTER PROCEDURE [dbo].[GetAbilityEvaluationFormats] (
	@Instance Varchar(50) = NULL, 
	@IdEvaluationFormat Varchar(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	SELECT
		AEF.[ID]						'id',
		AEF.[IdEvaluationFormat]		'idEvaluationFormat',
		AEF.[IdAbility]					'idAbility',
		A.[Title]						'titleAbility',
		A.[Detail]						'detailAbility',
		A.[Type]						'abilityType',
		A.[Query]						'abilityQuery',
		AEF.[IdGroup]					'idGroup',
		G.[Description]                 'descriptionGroup',
		AEF.[IdSubGroup]				'idSubGroup',
		SG.[Description]                 'descriptionSubGroup',
		AEF.[Penalizes]					'penalizes',
		AEF.[Score]						'score',
		AEF.[Order]						'order',
		A.[NotApply]					'acceptNotApplies',
		A.[AcceptComments]				'acceptComments',
		A.[Detail]						'descriptionAbility',
		AEF.[Conditional]				'conditional',
        A.QueryName						'query'
	FROM [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
	INNER JOIN [dbo].[Group] G (NOLOCK)
		ON G.[Instance] = AEF.[Instance]
			AND G.[ID] = AEF.[IdGroup]
	INNER JOIN [dbo].[SubGroup] SG (NOLOCK)
		ON SG.[Instance] = AEF.[Instance]
			AND SG.[ID] = AEF.[IdSubGroup]
	INNER JOIN [dbo].[Ability] A (NOLOCK)
		ON A.[Instance] = AEF.[Instance]
			AND A.[ID] = AEF.[IdAbility]
	WHERE AEF.[Instance] = @Instance
		AND AEF.[IdEvaluationFormat]= @IdEvaluationFormat
	ORDER BY [Order] ASC
	
	/* DEPRECATED
	SELECT
		A.[ID]							'id',
		A.[IdEvaluationFormat]			'idEvaluationFormat',
		A.[IdAbility]					'idAbility',
		AB.[Title]						'titleAbility',
		AB.[Detail]						'detailAbility',
		AB.[Type]						'abilityType',
		AB.[Query]						'abilityQuery',
		A.[IdGroup]						'idGroup',
		G.[Description]                 'descriptionGroup',
		A.[IdSubGroup]					'idSubGroup',
		S.[Description]                 'descriptionSubGroup',
		A.[Penalizes]					'penalizes',
		A.[Score]						'score',
		A.[Order]						'order',
		AB.[NotApply]					'acceptNotApplies',
		AB.[AcceptComments]				'acceptComments',
		AB.[Detail]						'descriptionAbility',
		A.[Conditional]					'conditional',
        AB.QueryName					'query'
	FROM [SubGroup] S (NOLOCK)
	full join [AbilityEvaluationFormat] A (NOLOCK)
		on S.ID=A.IdSubGroup, [Ability] AB (NOLOCK),
		 [Group] G (NOLOCK)
	WHERE A.[Instance] = @Instance
		AND S.[Instance] = @Instance
		AND G.[Instance] = @Instance
		AND AB.[Instance] = @Instance
		AND A.IdAbility=AB.ID
		AND A.IdGroup=G.ID
		AND A.[IdEvaluationFormat]= @IdEvaluationFormat
	ORDER BY [Order] ASC
	*/
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationPlanAbilityGenericQueryTask]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationPlanAbilityGenericQueryTask] (
    @VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL
)
AS
BEGIN
SET NOCOUNT ON
	/*
	SELECT DISTINCT
			C.Instance			'vcc'
			,C.QueryName		'name'
		FROM [EvaluationPlan] A (NOLOCK)
		INNER JOIN [AbilityEvaluationFormat] B (NOLOCK)  
			ON A.Instance = B.Instance 
				AND A.IdEvaluationFormat = B.IdEvaluationFormat
		INNER JOIN [Ability] C (NOLOCK)  
			ON A.Instance = C.Instance 
				AND B.IdAbility = C.Id 
				AND C.QueryName IS NOT NULL
		INNER JOIN [dbo].[GenericQuery] D (NOLOCK) 
			ON A.Instance = D.vcc 
			AND D.[Name] = C.[QueryName]
		WHERE A.[Instance] = @VCC
			AND A.[ID] = @ID
	*/

	-- ESTE SP RETORNA LAS GENERICQUERY ASOCIADAS A UN PLAN POR MEDIO DEL FORMATO Y SUS HABILIDADES
	SELECT DISTINCT
			A.[Instance]			'vcc'
			,AQ.[QueryId]			'name'
		FROM [dbo].[EvaluationPlan] EP (NOLOCK)
		INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)  
			ON EP.[Instance] = AEF.[Instance] 
				AND EP.[IdEvaluationFormat] = AEF.IdEvaluationFormat
		INNER JOIN [dbo].[Ability] A (NOLOCK)  
			ON A.[Instance] = EP.[Instance]
				AND AEF.[IdAbility] = A.[Id] 
				AND (
					A.[Type] = 'MANUAL_AUTOMATIC'
					OR
					A.[Type] = 'MIXED' -- PROXIMA IMPLEMENTACION
				)
				--AND A.[AnalysisType] = 'SEMANTIC'
		INNER JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
			ON AQ.[VCC] = EP.[Instance]
				AND AQ.[AbilityId] = A.[ID]
		INNER JOIN [dbo].[GenericQuery] GQ (NOLOCK) 
			ON EP.[Instance] = GQ.[vcc] 
			AND GQ.[Name] = AQ.[QueryId]
		WHERE EP.[Instance] = @VCC
			AND EP.[ID] = @ID

SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationPlanCognitiveInteractionTask]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationPlanCognitiveInteractionTask] (
    @VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL -- EVALUATION PLAN ID
)
AS
BEGIN
SET NOCOUNT ON

	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO CALL QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance					'vcc'
			,EP.ProcessId				'processId'
			,AU.Campaign				'campaign'
			,IEP.[InteractionType]		'interactionType'
			,EP.[Id]					'evaluationPlanId'
			,IEP.IdInteraction			'id'
			,AU.Section					'section'
			,AU.Part					'part'
			,NULL						'folder'
			,F.nluId					'nluId'
			,F.appId					'appId'
			,AU.[FileName]				'fileName'
			--,F.[cognitiveId]			-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]		'cognitiveEngine'
			,STUFF(
				(
					/*SELECT ',' + A_INNER.[ID]
						FROM [Ability] A_INNER (NOLOCK)
						WHERE A_INNER.[ID] = AB.[ID]*/
					SELECT DISTINCT ',' + AEF_INNER.[IdAbility]
						FROM [dbo].[AbilityEvaluationFormat] AEF_INNER (NOLOCK)
						INNER JOIN [dbo].[AbilityQuery] AQ_INNER (NOLOCK)
							ON AQ_INNER.[VCC] = AEF_INNER.[Instance]
								AND AQ_INNER.[AbilityId] = AEF_INNER.[IdAbility]
						WHERE AEF_INNER.[Instance] = EP.[Instance]
							AND AEF_INNER.[IdEvaluationFormat] =  EP.[IdEvaluationFormat]
							AND AQ_INNER.[QueryContent] LIKE CONCAT(F.[nluId], '|%')
					--SELECT ',' + AEF_INNER.[IdAbility]
						--FROM [dbo].[EvaluationPlan]
					FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, ''
			)							'abilities'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON IEP.Instance = EP.Instance 
			AND IEP.IdEvaluationPlan = EP.Id
	INNER JOIN [dbo].[Audio] AU (NOLOCK) 
		ON AU.VCC = EP.Instance
			AND AU.ID = IEP.IdInteraction 
	INNER JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
		ON AEF.Instance = EP.Instance
			AND AEF.IdEvaluationFormat = EP.IdEvaluationFormat 
	INNER JOIN [Ability] AB (NOLOCK) 
		ON AB.Instance = EP.Instance 
			AND AB.ID = AEF.IdAbility 
			AND AB.[AnalysisType] IS NOT NULL
	INNER JOIN [dbo].[AbilityQuery] AQ (NOLOCK) 
		ON AQ.[VCC] = EP.[Instance]
			AND AQ.[AbilityId] = AB.[ID]
	INNER JOIN (SELECT DISTINCT
				A.VCC 'vcc'
				,A.[Name] + '|'+ B.[Name] 'cognitiveId'
				,A.[Name] 'nluId'
				,A.AppId 'appId'
				,B.[IntentId] 'intentId',B.Name
			FROM NLU A (NOLOCK)
			INNER JOIN Intent B (NOLOCK) 
				ON A.VCC = B.VCC
					AND B.AppId = A.AppId) F 
		ON F.[VCC] = EP.[Instance]
			AND F.[cognitiveId] = AQ.[QueryContent] 
			AND F.[intentId] = AQ.[QueryId] 
	LEFT JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @ID
	
	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO TEXT QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance					'vcc'
			,EP.ProcessId				'processId'
			,AI.[Campaign]				'campaign'
			,IEP.[InteractionType]		'interactionType'
			,EP.[Id]					'evaluationPlanId'
			,IEP.IdInteraction			'id'
			,NULL						'section'
			,NULL						'part'
			,AI.[EndDate]				'endDate'
			,AI.[Folder]				'folder'
			,AI.[DispositionCode]		'dispositionCode'
			,F.nluId					'nluId'
			,F.appId					'appId'
			,AI.[FileName]				'fileName'
			--,F.[cognitiveId]			-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]		'cognitiveEngine'
			,STUFF(
				(
					SELECT DISTINCT ',' + AEF_INNER.[IdAbility]
						FROM [dbo].[AbilityEvaluationFormat] AEF_INNER (NOLOCK)
						INNER JOIN [dbo].[AbilityQuery] AQ_INNER (NOLOCK)
							ON AQ_INNER.[VCC] = AEF_INNER.[Instance]
								AND AQ_INNER.[AbilityId] = AEF_INNER.[IdAbility]
						WHERE AEF_INNER.[Instance] = EP.[Instance]
							AND AEF_INNER.[IdEvaluationFormat] =  EP.[IdEvaluationFormat]
							AND AQ_INNER.[QueryContent] LIKE CONCAT(F.[nluId], '|%')
					FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, ''
			)							'abilities'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON EP.Instance = IEP.Instance 
			AND EP.Id = IEP.IdEvaluationPlan
	INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK) 
		ON EP.Instance = AI.VCC 
			AND IEP.IdInteraction = AI.ID
			AND IEP.FormattedEndDate = AI.Folder
	INNER JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
		ON EP.Instance = AEF.Instance 
			AND EP.IdEvaluationFormat = AEF.IdEvaluationFormat
	INNER JOIN [Ability] AB (NOLOCK)
		ON EP.Instance = AB.Instance 
			AND AEF.IdAbility = AB.ID 
			AND AB.[AnalysisType] IS NOT NULL
	INNER JOIN [dbo].[AbilityQuery] AQ (NOLOCK) 
		ON AQ.[VCC] = EP.[Instance]
			AND AQ.[AbilityId] = AB.[ID]
	INNER JOIN (SELECT DISTINCT
				A.VCC 'vcc'
				,A.[Name] + '|'+ B.[Name] 'cognitiveId'
				,A.[Name] 'nluId'
				,A.AppId 'appId'
				,B.[IntentId] 'intentId',B.Name
			FROM NLU A (NOLOCK)
			INNER JOIN Intent B (NOLOCK) 
				ON A.VCC = B.VCC
					AND B.AppId = A.AppId) F 
		ON F.[VCC] = EP.[Instance]
			AND F.[cognitiveId] = AQ.[QueryContent] 
			AND F.[intentId] = AQ.[QueryId] 
	LEFT JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @ID

SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan] (
	@Instance Varchar(50) = NULL,
    @EvaluationPlanId Varchar(50) = NULL,
    @InteractionId varchar(250) = NULL,
    @InteractionType varchar(50) = NULL,
    @AuditorId varchar(50) = NULL,
    @AgentId varchar(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON

    SELECT DISTINCT
         EF.Id										'EvaluationFormatId'				-- Id
        ,EF.Description								'EvaluationFormatDescription'		-- Titulo del reporte
        ,ER.Instance								'Instance'							-- Subtitulo del reporte
        ,ER.IdAgent									'AgentId'							-- Agente
        ,ER.IdAgent									'AgentDescription'					-- Agente
        ,CONCAT(U.Firstname, ' ', U.Lastname)		'CoordinatorFullName'				-- Coordinador
        ,AEP.IdAuditor								'AuditorId'							-- Auditor
        ,CONCAT(UA.Firstname, ' ',UA.Lastname)		'AuditorDescription'				-- Auditor
		,AEP.IdAuditor
        ,ER.IdCampaign								'CampaignDescription'				-- Campana
        ,ER.IdInteraction							'InteractionId'						-- Grabacion
        ,ER.InteractionType							'InteractionType'					-- Tipo interaccion
        ,ER.InteractionDateini						'InteractionDateIni'				-- Fecha inicio de la interaccion
		,ER.[InteractionDatefin]					'InteractionDateFin'				-- Fecha fin de la interaccion
        ,ER.InteractionAddress						'Contacto'							-- Telefono
        ,ER.EvaluationDate							'EvaluationDate'					-- Fecha monitoreo
        ,AEP.Score									'TotalScore'						-- Puntaje total
        ,G.Id										'GroupId'							-- Grupo
        ,G.Description								'Group'								-- Grupo
        ,SG.Id										'SubGroupId'						-- Subgrupo
        ,SG.Description								'SubGroup'							-- Subgrupo
        ,AB.Id										'AbilityId'							-- Habilidad
        ,AB.Title									'Ability'							-- Habilidad
		,AB.[Detail]								'AbilityDetail'						-- Habilidad
        ,ER.Comment									'Observacion'						-- Observacion de la habilidad
        ,ER.MaxAbilityScore							'Puntaje'							-- Puntaje
        ,ER.ScoreDescription						'Eval'								-- Eval
        ,ER.Qualification							'Nota'								-- Nota
        ,ER.NotApplies								'NotApplies'
        ,ER.AbilityOrder							'Order'
        ,ER.Conditional                             'conditionalSelected'
    FROM [EvaluationResult] ER (NOLOCK)
    INNER JOIN	[EvaluationFormat] EF (NOLOCK)
	--LEFT JOIN [EvaluationFormat] EF (NOLOCK)
		ON (ER.Instance = EF.Instance 
			AND	ER.IdEvaluationFormat = EF.ID)
    LEFT JOIN [User] U (NOLOCK)
		ON (EF.Instance = U.VCC
			AND EF.CreatedByUserId = U.ID)
    --INNER JOIN [User] UA (NOLOCK)
	LEFT JOIN [User] UA (NOLOCK)
		ON (ER.Instance = UA.VCC 
			AND ER.IdEvaluator = UA.ID)
    --INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
	LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
		ON (ER.IdEvaluationPlan	= AEP.IdEvaluationPlan
			AND ER.IdEvaluator = AEP.IdAuditor
			AND ER.IdInteraction = AEP.IdInteraction
			AND ER.InteractionType = AEP.InteractionType
			AND ER.IdAgent = AEP.IdAgent)
    LEFT JOIN [Group] G (NOLOCK)
		ON (ER.Instance = G.Instance
			AND ER.IdGroup = G.ID)
    LEFT JOIN [SubGroup] SG (NOLOCK)
		ON (ER.Instance = SG.Instance 
			AND ER.IdSubGroup = SG.ID)
    LEFT JOIN [Ability] AB (NOLOCK)
		ON (ER.Instance = AB.Instance 
			AND ER.IdAbility = AB.ID)
    WHERE ER.Instance = @Instance
		AND ER.IdEvaluationPlan	= @EvaluationPlanId
		AND ER.IdInteraction = @InteractionId
		AND ER.InteractionType = @InteractionType
		--AND ER.IdEvaluator = @AuditorId
		AND ER.IdAgent = @AgentId
    ORDER BY ER.AbilityOrder ASC;

    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetUniqueNLUByIntents]...';


GO
ALTER PROCEDURE [dbo].[GetUniqueNLUByIntents]
(
	@VCC					VARCHAR(50),
	@TemplateId				VARCHAR(50),
	@Intents				VARCHAR(MAX)
)
AS
BEGIN
	SET NOCOUNT ON

	-- ESTA FUNCION ES USADA SOLO PARA FORMATOS DE EVALUACION
	SELECT DISTINCT F.[AppId]			'appId' 
		FROM [dbo].[EvaluationFormat] EF (NOLOCK)
		INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
			ON EF.[Instance] = AEF.[Instance] 
				AND EF.[ID] = AEF.[IdEvaluationFormat]
		INNER JOIN [dbo].[Ability] A (NOLOCK) 
			ON A.[Instance] = EF.[Instance]
				AND A.[ID] = AEF.IdAbility 
				AND A.[AnalysisType] IS NOT NULL 
		INNER JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
			ON AQ.[VCC] = A.[Instance] 
				AND AQ.[AbilityId] = A.[ID] 
		INNER JOIN (
			SELECT DISTINCT
					N.[VCC]									'vcc'
					,N.[Name] + '|'+ I.[Name]				'cognitiveId'
					,N.[Name]								'nluId'
					,N.[AppId]								'appId'
					,I.[IntentId]							'intentId'
					, I.[Name]
				FROM [dbo].[NLU] N (NOLOCK)
				INNER JOIN [dbo].[Intent] I (NOLOCK) 
					ON N.[VCC] = I.[VCC]
						AND I.[AppId] = N.[AppId]
				WHERE N.[VCC] = @VCC
					AND I.[IntentId] IN (SELECT Value FROM dbo.[SplitString](@Intents, ','))
		) F 
			ON F.[VCC] = EF.[Instance] 
				AND F.[cognitiveId] = AQ.[QueryContent] 
				AND F.[intentId] = AQ.[QueryId] 
		WHERE EF.[Instance] = @VCC
			AND EF.[templateId] = @TemplateId

	/* DEPRECATED
	-- ESTA FUNCION ES USADA SOLO PARA FORMATOS DE EVALUACION
	SELECT DISTINCT F.[AppId]			'appId' 
		FROM [dbo].[EvaluationFormat] EF (NOLOCK)
		INNER JOIN [AbilityEvaluationFormat] AEF (NOLOCK)
			ON EF.[Instance] = AEF.[Instance] 
				AND EF.[ID] = AEF.[IdEvaluationFormat]
		INNER JOIN [Ability] A (NOLOCK) 
			ON EF.[Instance] = A.[Instance] 
				AND AEF.IdAbility = A.[ID] 
				AND A.[QueryName] IS NOT NULL
		INNER JOIN (SELECT DISTINCT
					N.[VCC]									'vcc'
					,N.[Name] + '|'+ I.[Name]				'cognitiveId'
					,N.[Name]								'nluId'
					,N.[AppId]								'appId'
					,I.[IntentId]							'intentId'
					, I.[Name]
				FROM [dbo].[NLU] N (NOLOCK)
				INNER JOIN [dbo].[Intent] I (NOLOCK) 
					ON N.[VCC] = I.[VCC]
						AND I.[AppId] = N.[AppId]
				WHERE N.[VCC] = @VCC
					AND I.[IntentId] IN (SELECT Value FROM dbo.[SplitString](@Intents, ','))) F 
			ON EF.[Instance] = F.[VCC] 
				--AND E.ID = F.cognitiveId
				AND A.[Query] = F.[cognitiveId]
				AND A.[QueryName] = F.[intentId]
		WHERE EF.[Instance] = @VCC
			AND EF.[templateId] = @TemplateId
	*/
	/*
	SELECT
		DISTINCT I.[AppId]			'appId'
	FROM
		[dbo].[Intent] I (NOLOCK) 
	WHERE
		I.[VCC] = @VCC
		AND I.[IntentId] IN (SELECT Value FROM dbo.[SplitString](@Intents, ','))
	*/

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveAbility]...';


GO
ALTER PROCEDURE [dbo].[SaveAbility] (
	@Instance Varchar(50) = NULL, 				
	@ID Varchar(50) = NULL,
	@Title Varchar(100) = NULL,					
	@Detail Varchar(500) = NULL,
	@Type VARCHAR(25) = NULL,
	@Binary Bit = NULL,
	@NotApply Bit = NULL,
	@AcceptComments Bit = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@Enabled bit = NULL,
	@AnalysisType VARCHAR(25) = NULL,
	@Language VARCHAR(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [Ability]
	SET [Title] = @Title,
		[Detail] = @Detail,
		[Type] = @Type,
		[Binary] = @Binary,
		[NotApply] = @NotApply, [AcceptComments] = @AcceptComments,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[Enabled] = CASE WHEN @Enabled IS NULL THEN 1 ELSE @Enabled END,
		[TimeStamp] = GETUTCDATE(),
		[AnalysisType] = @AnalysisType,
		[Language] = @Language
	WHERE [Instance] = @Instance
    AND [ID] = @ID

    IF @@ROWCOUNT = 0
		INSERT INTO [Ability] (
			[Instance], [ID],
			[Title], [Detail], 
			[Type], [Binary],
			[NotApply], [AcceptComments],
			[CreatedDate],
			[CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
			[Enabled], [TimeStamp], 
			[AnalysisType], [Language]
			)
		VALUES (
			@Instance, @ID,
			@Title, @Detail, 
			@Type, @Binary,
			@NotApply, @AcceptComments,
			@CreatedDate,
			@CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
			1, GETUTCDATE(), 
			@AnalysisType, @Language
		)

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetProcessEvaluationPlanTask]...';


GO
--exec [GetProcess] 'inconcert','test'
ALTER PROCEDURE [dbo].[GetProcessEvaluationPlanTask] (
	@VCC Varchar(50) = NULL, @ID Varchar(50) = NULL, @EvaluationPlanId Varchar(200) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		A.[VCC]						    'vcc',
		A.[Name]						'processId',
		A.[Status]						'status',
		A.[Type]						'type',
		B.[ID]							'evaluationPlanId',
		B.[IdEvaluationFormat]			'evaluationFormatId',
		B.[Status]						'evaluationPlanStatus',
		B.[Evaluation_Mode]				'evaluationPlanType'
	FROM [Process] A (NOLOCK)
	INNER JOIN [EvaluationPlan] B (NOLOCK) 
		ON A.vcc = B.Instance 
			AND  A.[Name] = B.ProcessId 
	WHERE A.[VCC] = @VCC
		AND A.[Name] = @ID
		AND B.Id = @EvaluationPlanId

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetTemplateThemeModels]...';


GO
-- exec [GetTemplateThemeModels] 'allegro','Test1234'
ALTER PROCEDURE [dbo].[GetTemplateThemeModels] (
	@VCC Varchar(50) = NULL, 
	@TemplateId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA DETERMINAR SI ES UN FORMATO O PLANTILLA
	DECLARE @TEMPLATE_TYPE VARCHAR(50) = NULL

	-- BUSCAMOS POR EL ID SI SE TRATA DE UNA PLANTILLA O FORMATO
	IF EXISTS (
		SELECT 1 
			FROM [dbo].[Template] T (NOLOCK)
			INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = T.[VCC]
					AND EF.[templateId] = T.[Name]
			WHERE T.[VCC] = @VCC
				AND T.[Name] = @TemplateId
	)
		SET @TEMPLATE_TYPE = 'EVALUATION_FORMAT'
	ELSE 
		SET @TEMPLATE_TYPE = 'TEMPLATE'

	-- 
	SELECT 
		A.vcc,
		A.[TemplateId]					'templateId',
		A.[TemplateThemeId]				'templateThemeId',
		A.[ID]							'id',
		-- CASE WHEN ISNULL(B.[Query],'') = ISNULL(NULL,'') THEN A.[ID] ELSE B.[Query] END	'query',
		A.[ID]							'query',
		@TEMPLATE_TYPE					'templateType',
		A.[CreatedDate]					'createdDate',
		A.[CreatedByUserId]				'createdByUserId',
		A.[LastModifiedDate]			'lastModifiedDate',
		A.[LastModifiedByUserId]		'lastModifiedByUserId'
	FROM [TemplateThemeItem] A (NOLOCK)
	LEFT JOIN [dbo].[GenericQuery] B (NOLOCK) 
		ON A.[ID] = B.[Name] 
			AND A.[VCC] = B.[VCC]
	WHERE A.[VCC] = @VCC
		AND A.[TemplateId] = CASE WHEN ISNULL(@TemplateId, '') = '' THEN [TemplateId] ELSE @TemplateId END
		AND B.[Name] IS NULL

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[DeleteAbilityQueries]...';


GO
CREATE PROCEDURE [dbo].[DeleteAbilityQueries] (
	@VCC VARCHAR(50) = NULL, 
	@AbilityId VARCHAR(100) = NULL
) AS
BEGIN
	SET XACT_ABORT, NOCOUNT ON;

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS VCC QUE ACTUALIZAREMOS
		DECLARE RECURRENT_CURSOR CURSOR 
		LOCAL STATIC READ_ONLY FORWARD_ONLY
			FOR 
			-- SELECCIONAMOS LOS ABILITY_QUERY RELACIONADOS AL ABILITY
			SELECT AQ.[ID]
				FROM [dbo].[AbilityQuery] AQ (NOLOCK) 
				WHERE AQ.[VCC] = @VCC 
					AND AQ.[AbilityId] = @AbilityId

		-- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS ACTUALIZANDO
		DECLARE @CURRENT_ABILITY_ID VARCHAR(50) = ''

		-- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
		OPEN RECURRENT_CURSOR
		FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_ABILITY_ID
		WHILE @@FETCH_STATUS = 0
		BEGIN 

			-- ELIMINAMOS LOS ABILITY_QUERY_ENTITY QUE COINCIDEN CON EL ABILITY_QUERY_ID ACTUAL
			DELETE FROM [dbo].[AbilityQueryEntity]
				WHERE [AbilityQueryId] = @CURRENT_ABILITY_ID

			FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_ABILITY_ID
		END
		CLOSE RECURRENT_CURSOR
		DEALLOCATE RECURRENT_CURSOR

		-- SP PARA ELIMINAR TODAS LAS ABILITY_QUERIES
		DELETE FROM [dbo].[AbilityQuery] 
			WHERE [VCC] = @VCC 
				AND [AbilityId] = @AbilityId
		
		SELECT 1 AS 'result'
    
		SET NOCOUNT OFF

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	SET NOCOUNT OFF

END
GO
PRINT N'Creando [dbo].[GetAbilityQueries]...';


GO
CREATE PROCEDURE [dbo].[GetAbilityQueries] (
	@VCC VARCHAR(50) = NULL, 
	@AbilityId VARCHAR(100) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	--
	SELECT [AQ].[ID]									'id',
			[AQ].[QueryId]								'queryId',
			[AQ].[QueryContent]							'queryContent',
			[AQ].[AcceptancePercentage]					'acceptancePercentage',
			[AQ].[Order]								'order'
		FROM [dbo].[AbilityQuery] AQ (NOLOCK)
		WHERE [AQ].[VCC] = @VCC
			AND [AQ].[AbilityId] = @AbilityId
		ORDER BY [AQ].[Order] ASC

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetAbilityQueryEntities]...';


GO
CREATE PROCEDURE [dbo].[GetAbilityQueryEntities] (
	@VCC VARCHAR(50) = NULL, 
	@AbilityQueryId VARCHAR(100) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	--
	SELECT [AQE].[EntityId]								'entityId',
			[AQE].[EntityName]                          'entityName',
			[AQE].[AcceptancePercentage]				'acceptancePercentage',
			[AQE].[Order]								'order'
		FROM [dbo].[AbilityQueryEntity] AQE (NOLOCK)
		WHERE [AQE].[VCC] = @VCC
			AND [AQE].[AbilityQueryId] = @AbilityQueryId
		ORDER BY [AQE].[Order] ASC

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[SaveAbilityQuery]...';


GO
Create PROCEDURE [dbo].[SaveAbilityQuery] (
	@VCC							VARCHAR(50) = NULL,
	@ID								VARCHAR(50) = NULL,
	@AbilityId						VARCHAR(50) = NULL,
	@QueryId						VARCHAR(50) = NULL,
	@QueryContent					VARCHAR(50) = NULL,
	@AcceptancePercentage			DECIMAL(18, 2) = NULL,
	@Order							INT = NULL,
	@CreatedByUserId				VARCHAR(50) = NULL,
	@LastModifiedByUserId			VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	UPDATE [AbilityQuery]
		SET [AcceptancePercentage] = @AcceptancePercentage,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[LastModifiedDate] = GETUTCDATE(),
			[TimeStamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [ID] = @ID

	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [AbilityQuery] (
			[VCC], [ID], [AbilityId], [QueryId], [QueryContent],
			[AcceptancePercentage], [Order], [CreatedDate], [CreatedByUserId], [LastModifiedDate], 
			[LastModifiedByUserId], [TimeStamp]
		)
		VALUES (
			@VCC, @ID, @AbilityId, @QueryId, @QueryContent, 
			@AcceptancePercentage, @Order, GETUTCDATE(), @CreatedByUserId, GETUTCDATE(), 
			@LastModifiedByUserId, GETUTCDATE()
		)
	END

	SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[SaveAbilityQueryEntity]...';


GO
CREATE PROCEDURE [dbo].[SaveAbilityQueryEntity] (
	@VCC							VARCHAR(50) = NULL,
	@AbilityQueryId					VARCHAR(50) = NULL,
	@EntityId						VARCHAR(50) = NULL,
	@EntityName						VARCHAR(50) = NULL,
	@AcceptancePercentage			DECIMAL(18, 2) = NULL,
	@Order							INT = NULL,
	@CreatedByUserId				VARCHAR(50) = NULL,
	@LastModifiedByUserId			VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	UPDATE [AbilityQueryEntity]
		SET [AcceptancePercentage] = @AcceptancePercentage,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[LastModifiedDate] = GETUTCDATE(),
			[TimeStamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [AbilityQueryId] = @AbilityQueryId
			AND [EntityId] = @EntityId

	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [AbilityQueryEntity] (
			[VCC], [AbilityQueryId], [EntityId], [EntityName], [AcceptancePercentage], 
			[Order], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], 
			[TimeStamp]
		)
		VALUES (
			@VCC, @AbilityQueryId, @EntityId, @EntityName, @AcceptancePercentage, 
			@Order, GETUTCDATE(), @CreatedByUserId, GETUTCDATE(), @LastModifiedByUserId, 
			GETUTCDATE()
		)
	END

	SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[BulkAbilityCognitive]...';


GO
ALTER PROCEDURE [dbo].[BulkAbilityCognitive]
AS
BEGIN
	SET NOCOUNT ON
	--select * from Dummy 
	--truncate table Dummy
	/*
	CREATE TABLE TMP_EVALUATIONPLANABILITY(
		VCC VARCHAR(50),
		ProcessId VARCHAR(50),
		EvaluationPlanId  VARCHAR(200),
		ID VARCHAR(250),
		Section  VARCHAR(50),
		Part VARCHAR(50),
		QueryId VARCHAR(50),
		TranscriptionId VARCHAR(200),
		NluId VARCHAR(50),
		IntentName VARCHAR(50),
		EndDate VARCHAR(50),
		Channel VARCHAR(50),
		Campaign VARCHAR(50)
	)
	*/

	/*insert into DummyEvaluationPlanAbility ([VCC]) values ('BULK')
	insert into TMP_EVALUATIONPLANABILITY ([VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign])  
	SELECT [VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign]
	  FROM [dbo].[#AbilityCognitiveTemp]
	*/  

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT ACTMP.[VCC],
							ACTMP.[EvaluationPlanId] 'EVALUATION_PLAN_ID'
						FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
						WHERE ACTMP.[VCC] IS NOT NULL 
							AND ACTMP.[EvaluationPlanId] IS NOT NULL

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'
			
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	
	/* Script para actualizar a puntaje 100 la calificacion de cada habilidad retornada por luis */
	/*
	SELECT EP.[Description],
			ACTMP.[ID],
			I.[IntentId],
			I.[Name],
			A.[Title],
			AEP.Completed,
			ER.[Qualification],
			I.[AppId]
			*/

	UPDATE ER
		SET ER.[Qualification] = (AEF.[Score] * S.[Value])/100,
			ER.[ScoreDescription] = S.[Description]
		FROM [#AbilityCognitiveTemp] ACTMP 
		INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
			ON EP.[ID] = ACTMP.[EvaluationPlanId]
		INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
			ON AEF.[Instance] = EP.[Instance]
				AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				AND AEF.[IdAbility] = ACTMP.[AbilityId]
		INNER JOIN EvaluationResult ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance] 
				AND ER.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				AND ER.[IdInteraction] = ACTMP.[ID]
		INNER JOIN [dbo].[Score] S (NOLOCK)
			ON S.[IdAbility] = ACTMP.[AbilityId]
				AND S.[Value] = 100
		WHERE AEF.[IdAbility] = ER.[IdAbility]
			AND ER.[IdAuditor] = 'SPEECH'


	/* DEPRECATED 
	UPDATE ER 
		SET ER.[Qualification] = (AEF.[Score] * S.[Value])/100,
			ER.[ScoreDescription] = S.[Description]
		FROM EvaluationPlan EP (NOLOCK)
		LEFT JOIN InteractionEvaluationPlan IEP (NOLOCK)
			ON IEP.[Instance] = EP.[Instance]
				AND IEP.[IdEvaluationPlan] = EP.[ID]
		LEFT JOIN EvaluationFormat EF (NOLOCK) 
			ON EF.[Instance] = EP.[Instance]
				AND EF.[ID] = EP.[IdEvaluationFormat]
		LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK)
			ON AEF.[Instance] = EP.[Instance]
				AND AEF.[IdEvaluationFormat] = EF.[ID] --EP.[IdEvaluationFormat]
		LEFT JOIN Score S (NOLOCK)
			ON S.[IdAbility] = AEF.[IdAbility]
				AND S.[Value] = 100
		LEFT JOIN Ability A (NOLOCK) 
			ON A.[Instance] = EP.[Instance]
				AND A.[ID] = AEF.[IdAbility]
		LEFT JOIN Intent I (NOLOCK) 
			ON I.[VCC] = EP.[Instance]
				AND I.[IntentId] = A.[QueryName]
		LEFT JOIN AuditorEvaluationPlan AEP (NOLOCK)
			ON AEP.[IdEvaluationPlan] = EP.[ID]
				AND AEP.[IdInteraction] = IEP.[IdInteraction]
		LEFT JOIN EvaluationResult ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance] 
				AND ER.[IdEvaluationFormat] = EF.[ID]
				AND ER.[IdInteraction] = IEP.[IdInteraction]
		INNER JOIN [#AbilityCognitiveTemp] ACTMP 
			ON ACTMP.[VCC] = EP.[Instance] 
				AND ACTMP.[EvaluationPlanId] = EP.[ID]
				AND ACTMP.[ID] = IEP.[IdInteraction]
				AND ACTMP.[IntentName] = I.[Name]
		WHERE ACTMP.[EvaluationPlanId] = EP.[ID]
			AND ACTMP.[ID] = IEP.[IdInteraction]
			AND ACTMP.[IntentName] = I.[Name]
			AND AEF.[IdAbility] = ER.[IdAbility]
			AND A.[ID] IS NOT NULL
			AND ER.[IdAuditor] = 'SPEECH'
	*/

	/* Script para actualizar la tabla AuditorEvaluationPlan a Completed y Suma de Scores de la evaluacion */
	UPDATE AEP
		SET --AEP.[Completed] = '1',
			AEP.[Completed] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN '0' ELSE '1' END,
			AEP.[Score] = AEPR.[SCORE],
			AEP.[AutomaticScore] = AEPR.[SCORE],
			AEP.[ManualScore] = AEPR.[SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN (
			SELECT AEP.[Instance],
				AEP.[IdEvaluationPlan],
				AEP.[IdInteraction],
				EP.[Evaluation_Mode],
				EF.[MinAutomaticQualification],
				SUM(ER.[Qualification]) AS SCORE
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN EvaluationPlan EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.[ID] = AEP.[IdEvaluationPlan] 
			LEFT JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = AEP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			LEFT JOIN EvaluationResult ER (NOLOCK)
				ON ER.[Instance] = AEP.[Instance]
					AND ER.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND ER.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK) 
				ON AEF.[Instance] = EP.[Instance]
					AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			LEFT JOIN (SELECT DISTINCT ACTMP.[VCC],
									ACTMP.[EvaluationPlanId]
								FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
								WHERE ACTMP.[VCC] IS NOT NULL 
									AND ACTMP.[EvaluationPlanId] IS NOT NULL) TMP 
				ON TMP.[VCC] = AEP.[Instance]
					AND TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
			WHERE TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = 'SPEECH'
			GROUP BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction], EP.[Evaluation_Mode], EF.[MinAutomaticQualification]
		) AEPR 
		ON AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
		WHERE AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
	
	;
	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[Qualification] = 0 AND AEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				AEF.[Penalizes],
				CASE AEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[Qualification] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE AEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
				ON AEF.[Instance] = ER.[Instance] 
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp]) 
				AND ER.[Qualification] = 0 
				AND AEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				SUM(ER.[Qualification]) 'TOTAL_SCORE',
				SUM(ER.[Qualification] * CASE WHEN FP.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE'
		
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP
				ON FP.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP.[IdEvaluationPlan]
					AND CASE FP.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP.[PenalizedOn]
					AND FP.[Penalized] = 1
			--WHERE ER.[Instance] = 'multisalud'
			WHERE ER.[Instance] = FP.[Instance]
				AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp])
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP 
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
	
	DROP TABLE [dbo].[#AbilityCognitiveTemp];
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[BulkEvaluationPlanAbility]...';


GO
ALTER PROCEDURE [dbo].[BulkEvaluationPlanAbility]
AS
BEGIN
	SET NOCOUNT ON
	-- ESTE PROCEDURE RECIBE COMO RESULTADO LAS INTERACCIONES QUE COINCIDEN CON UN QUERY
	--SELECT * FROM DummyEvaluationPlanAbility
	--TRUNCATE TABLE DummyEvaluationPlanAbility
	--DROP TABLE DummyEvaluationPlanAbility
	--DELETE FROM DummyEvaluationPlanAbility WHERE EvaluationPlanId = 'bab2b1df-6cfb-49c2-bc9d-2725d455e769'
	/*
	drop table [dbo].[DummyEvaluationPlanAbility]
	CREATE TABLE [dbo].[DummyEvaluationPlanAbility](
		[VCC] [varchar](50) NULL,
		[ProcessId] [varchar](50) NULL,
		[EvaluationPlanId] [varchar](50) NULL,
		[AudioId] [varchar](250) NULL,
		[Section] [int] NULL,
		[Part] [int] NULL,
		[QueryId][varchar](1000) NULL,
		[EndDate] [varchar](100) NULL,
		[Channel] [varchar](100) NULL,
		[Campaign] [varchar](100) NULL
	)
	
	insert into DummyEvaluationPlanAbility ([VCC]) values ('BULK')
	insert into DummyEvaluationPlanAbility ([VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[AudioId]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign])  
	SELECT [VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[AudioId]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign]
	  FROM [dbo].[#EvaluationPlanAbilityTemp]
	

	*/
	--ASEGURAMOS QUE SE INSERTEN TODAS LAS INTERACIONES POR HABILIDAD
	/*
	INSERT INTO [dbo].[EvaluationResult]
		(
			[Instance]
			,[IdCampaign]
			,[IdInteraction]
			,[IdAgent]
			,[IdEvaluationFormat]
			,[MinQualificationAcceptable]
			,[IdGroup]
			,[IdSubGroup]
			,[IdAbility]
			,[Qualification]
			,[IdEvaluator]
			,[EvaluationDate]
			,[MaxAbilityScore]
			,[IdEvaluationPlan]
			,[CreatedDate]
			,[CreatedByUserId]
			,[LastModifiedDate]
			,[LastModifiedByUserId]
			,[TimeStamp]
			,[Comment]
			,[NotApplies]
			,[ScoreDescription]
			,[CampaignDescription]
			,[AgentDescription]
			,[InteractionDateini]
			,[InteractionDatefin]
			,[InteractionAddress]
			,[AbilityOrder]
			,[InteractionType]
			,[IdAbilityEvaluationFormat]
			,[IdAuditor]
			,[Conditional]
		)
	SELECT DISTINCT
		IEP.[Instance]
		,IEP.[IdCampaign]
		,IEP.[IdInteraction]
		,IEP.[IdAgent]
		,EP.[IdEvaluationFormat]
		,EF.[MinQualificationAcceptable]
		,AEF.[IdGroup]
		,AEF.[IdSubGroup]
		,AEF.[IdAbility]
		,0
		,'SPEECH'
		,GETUTCDATE()
		,'100'
		,EP.[ID]
		,GETUTCDATE()
		,'SPEECH'
		,GETUTCDATE()
		,'SPEECH'
		,GETUTCDATE()
		,NULL
		,'0'
		,S.[Description]
		,IEP.[IdCampaign]
		,IEP.[IdAgent]
		,IEP.[InteractionDateStart]
		,MAX(IEP.[InteractionDateEnd])
		,NULL
		,AEF.[Order]
		,IEP.[InteractionType]
		,AEF.[ID]
		,'SPEECH'
		,AEF.[Conditional] 
	FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
	INNER JOIN [EvaluationPlan] EP (NOLOCK)
		ON EP.[Instance] = IEP.[Instance]
		AND EP.[ID] = IEP.[IdEvaluationPlan]
	INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
		ON EF.[Instance] = IEP.[Instance]
		AND EF.[ID] = EP.[IdEvaluationFormat]
	INNER JOIN [dbo].[#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)
	--INNER JOIN [dbo].[DummyEvaluationPlanAbility] EPATMP (NOLOCK)
		ON IEP.[Instance] = EPATMP.[VCC]
		AND IEP.[IdEvaluationPlan] = EPATMP.[EvaluationPlanId]
		-- AND IEP.[IdInteraction] = EPATMP.[AudioId] -- REMOVER ESTA LINEA IMPIDE INICIALIZAR TODAS LAS INTERACTION-RESULT COMO 0
	INNER JOIN [dbo].[AbilityEvaluationFormat]  AEF (NOLOCK)
		ON AEF.[Instance] = IEP.[Instance]
		AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
	INNER JOIN [dbo].[Ability] A
		ON A.[Instance] = IEP.[Instance]
		AND A.[ID] = AEF.[IdAbility]
		AND A.[QueryName] = EPATMP.[QueryId]
	LEFT JOIN [dbo].[Score] S (NOLOCK) 
		ON S.[Instance] = A.[Instance] 
		AND S.[IdAbility] = A.[ID]
		AND S.[Value] = 0
	LEFT JOIN [EvaluationResult] ER (NOLOCK)
		ON ER.[Instance] = EPATMP.[VCC]
		AND ER.[IdEvaluationPlan] = EPATMP.[EvaluationPlanId]
		AND ER.[IdInteraction] = EPATMP.[AudioId]
		AND ER.[IdAbility] = AEF.[IdAbility]
	WHERE ER.[IdAbility] IS NULL
	GROUP BY IEP.[Instance]
		,IEP.[IdCampaign]
		,IEP.[IdInteraction]
		,IEP.[IdAgent]
		,EP.[IdEvaluationFormat]
		,EF.[MinQualificationAcceptable]
		,AEF.[IdGroup]
		,AEF.[IdSubGroup]
		,AEF.[IdAbility]
		,EP.[ID]
		,S.[Description]
		,IEP.[IdCampaign]
		,IEP.[IdAgent]
		,IEP.[InteractionDateStart]
		,AEF.[Order]
		,IEP.[InteractionType]
		,AEF.[ID]
		,AEF.[Conditional] 
	order by IEP.[IdInteraction]
	*/



	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT
				EPATMP.[VCC]						'VCC', 
				EPATMP.[EvaluationPlanId]			'EVALUATION_PLAN_ID'
			FROM [dbo].[#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'
		
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	-- FIN MEDIDA PARA PLANES FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS

	
	
	
	--ACTUALIZAR LOS SCORES DE LAS HABILIDADES RETORNADAS EN LA TABLA TEMPORAL
	UPDATE ER 
	SET ER.[Qualification] = (S.[Value] * AEF.[Score] / 100), 
		ER.[ScoreDescription] = S.[Description]
	FROM [dbo].[EvaluationResult] ER (NOLOCK)
	INNER JOIN [dbo].[#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)
	--INNER JOIN [dbo].[DummyEvaluationPlanAbility] EPATMP (NOLOCK)
		ON ER.[Instance] = EPATMP.[VCC]
		AND ER.[IdEvaluationPlan] = EPATMP.[EvaluationPlanId]
		AND ER.[IdInteraction] = EPATMP.[AudioId] 
	LEFT JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
		ON AEF.[Instance] = ER.[Instance] 
		AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
		AND AEF.[IdAbility] = ER.[IdAbility]
	--INNER JOIN [dbo].[Ability] A (NOLOCK) 
	--	ON A.[Instance] = ER.[Instance] 
	--	AND A.[ID] = ER.[IdAbility]
	INNER JOIN [dbo].[AbilityQuery] AB (NOLOCK)
		ON AB.[VCC] = ER.[Instance] 
			AND AB.[AbilityId] = AEF.[IdAbility]
			AND AB.[QueryId] = EPATMP.[QueryId]
	LEFT JOIN [dbo].[Score] S (NOLOCK) 
		ON S.[Instance] = ER.[Instance] 
		AND S.[IdAbility] = ER.[IdAbility]
		AND S.[Value] = 100;

	WITH 
	-- DECLARAMOS UNA CTE PARA DEPOSITAR LOS RESULTADOS DE LA SUMA DE HABILIDADES PARA LA EVALUACION
	CteEvaluationScoreResult AS (
		-- ESTE BLOQUE ACTUALIZA LAS NOTAS DE EVALUACIONES AUTOMATICAS SEGUN LOS PLANES CONTENIDOS EN LA TEMPORAL
		SELECT ER.[Instance], ER.[IdEvaluationPlan], ER.[IdEvaluator], ER.[IdInteraction], SUM(ER.[Qualification]) TOTAL
			FROM EvaluationResult ER 
			INNER JOIN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp) EPATMP 
			--INNER JOIN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility) EPATMP 
				ON EPATMP.[EvaluationPlanId] = ER.[IdEvaluationPlan] 
			LEFT JOIN AbilityEvaluationFormat AEF 
				ON AEF.[Instance] = ER.[Instance]
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
					AND AEF.[ID] = ER.[IdAbilityEvaluationFormat]
			WHERE ER.[IdAuditor] = 'SPEECH'
			GROUP BY ER.[Instance], ER.[IdEvaluationPlan], ER.[IdEvaluator], ER.[IdInteraction]
	)
	
	-- SE ACTUALIZA LAS EVALUACIONES QUE COINCIDEN CON LOS RESULTADOS
	UPDATE AEP 
		SET AEP.[Score] = ESR.[TOTAL],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		INNER JOIN CteEvaluationScoreResult ESR 
			ON AEP.[Instance] = ESR.[Instance]
				AND AEP.[IdEvaluationPlan] = ESR.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = ESR.[IdEvaluator]
				AND AEP.[IdInteraction] = ESR.[IdInteraction]

	;
	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[Qualification] = 0 AND AEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				AEF.[Penalizes],
				CASE AEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[Qualification] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE AEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
				ON AEF.[Instance] = ER.[Instance] 
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp) 
			--WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility) 
				AND ER.[Qualification] = 0 
				AND AEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),
	--SELECT * FROM CTEFP

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				SUM(ER.[Qualification]) 'TOTAL_SCORE',
				--SUM(ER.[Qualification] * CASE WHEN FP2.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE',
				SUM(ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1) THEN 0 ELSE 1 END
				)) 'PENALIZED_SCORE'
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[IdInteraction], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP2
				ON FP2.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP2.[IdEvaluationPlan]
					AND ER.[IdInteraction] = FP2.[IdInteraction]
					/*
					AND CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
					AND FP2.[Penalized] = 1
					*/
			--WHERE ER.[Instance] = 'multisalud'
			WHERE ER.[Instance] = FP2.[Instance]
				AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp)
				--AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility)
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
	

	-- ELIMINAMOS LA TABLA TEMPORAL
	DROP TABLE [dbo].[#EvaluationPlanAbilityTemp]
	
	SET NOCOUNT OFF
END
GO
PRINT N'Actualizando [dbo].[DeleteAbility]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteAbility]';


GO
PRINT N'Actualizando [dbo].[GetAbilitys]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAbilitys]';


GO
PRINT N'Actualizando [dbo].[GetAbilityTitle]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAbilityTitle]';


GO
PRINT N'Actualizando [dbo].[GetAverageGroupRating]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAverageGroupRating]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationFormats]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationFormats]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationPlanAbilityTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanAbilityTask]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationPlanCognitiveTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveTask]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationResults]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationResults]';


GO
PRINT N'Actualizando [dbo].[GetGenericQueryUsage]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetGenericQueryUsage]';


GO
PRINT N'Actualizando [dbo].[GetReportByDetailAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetReportByDetailAgent]';


GO
PRINT N'Actualizando [dbo].[GetReportBySummaryAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetReportBySummaryAgent]';


GO
PRINT N'Actualizando [dbo].[ReportAuditsByAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportAuditsByAgent]';


GO
PRINT N'Actualizando [dbo].[ReportByDetailAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportByDetailAgent]';


GO
PRINT N'Actualizando [dbo].[ReportBySummaryAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportBySummaryAgent]';


GO
PRINT N'Actualizando [dbo].[ReportBySummaryFormat]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportBySummaryFormat]';


GO
PRINT N'Actualizando [dbo].[SaveEvaluationBaseResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationBaseResult]';


GO
PRINT N'Actualizando [dbo].[BulkProgress]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkProgress]';


GO
PRINT N'Actualización completada.';


GO
