/*
El tipo de la columna UtteranceId de la tabla [dbo].[Utterance] es actualmente  INT NOT NULL pero se está cambiando a  NUMERIC (18) NOT NULL. Puede que se pierdan datos.
*/

IF EXISTS (select top 1 1 from [dbo].[Utterance])
    RAISERROR (N'Se detectaron filas. La actualización del esquema va a terminar debido a una posible pérdida de datos.', 16, 127) WITH NOWAIT

GO
PRINT N'Iniciando recompilación de la tabla [dbo].[Utterance]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_Utterance] (
    [VCC]                  VARCHAR (50)  NOT NULL,
    [AppId]                VARCHAR (50)  NOT NULL,
    [IntentId]             VARCHAR (50)  NOT NULL,
    [AudioId]              VARCHAR (50)  NOT NULL,
    [Section]              NUMERIC (5)   NOT NULL,
    [Part]                 NUMERIC (5)   NOT NULL,
    [Speaker]              VARCHAR (3)   NOT NULL,
    [AnchorOffset]         INT           NOT NULL,
    [FocusOffset]          INT           NOT NULL,
    [CurrentTime]          FLOAT (53)    NOT NULL,
    [EndCurrentTime]       FLOAT (53)    NOT NULL,
    [UtteranceId]          NUMERIC (18)  NOT NULL,
    [TextContent]          VARCHAR (500) NOT NULL,
    [CreatedDate]          DATETIME      NULL,
    [CreatedByUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]     DATETIME      NULL,
    [LastModifiedByUserId] VARCHAR (50)  NULL,
    [TimeStamp]            DATETIME      NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_Utterance1] PRIMARY KEY CLUSTERED ([VCC] ASC, [AppId] ASC, [IntentId] ASC, [AudioId] ASC, [Section] ASC, [Part] ASC, [Speaker] ASC, [AnchorOffset] ASC, [FocusOffset] ASC, [CurrentTime] ASC, [EndCurrentTime] ASC, [UtteranceId] ASC, [TextContent] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[Utterance])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_Utterance] ([VCC], [AppId], [IntentId], [AudioId], [Section], [Part], [Speaker], [AnchorOffset], [FocusOffset], [CurrentTime], [EndCurrentTime], [UtteranceId], [TextContent], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp])
        SELECT   [VCC],
                 [AppId],
                 [IntentId],
                 [AudioId],
                 [Section],
                 [Part],
                 [Speaker],
                 [AnchorOffset],
                 [FocusOffset],
                 [CurrentTime],
                 [EndCurrentTime],
                 [UtteranceId],
                 [TextContent],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp]
        FROM     [dbo].[Utterance]
        ORDER BY [VCC] ASC, [AppId] ASC, [IntentId] ASC, [AudioId] ASC, [Section] ASC, [Part] ASC, [Speaker] ASC, [AnchorOffset] ASC, [FocusOffset] ASC, [CurrentTime] ASC, [EndCurrentTime] ASC, [UtteranceId] ASC, [TextContent] ASC;
    END

DROP TABLE [dbo].[Utterance];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_Utterance]', N'Utterance';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_Utterance1]', N'PK_Utterance', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Modificando [dbo].[SaveUtterance]...';


GO
-- [dbo].[SaveUtterance] 'allegro', '4bad9174-ea84-45ee-ab2f-b17c73c43734', '45799dd8-17e7-49a1-9bd8-cb74f00a788c', '{f2c9e160-8eeb-11e9-8562-b65bb2fb6bcb}', 0, 1, 'in', 10, 14, 1.23, 1.38, 0, 'hola', '2019-08-02 15:30:00.000', 'analytic', NULL, NULL
ALTER PROCEDURE [dbo].[SaveUtterance]
(
	@VCC						VARCHAR(50),
	@AppId						VARCHAR(50),
	@IntentId					VARCHAR(50),
	@AudioId					VARCHAR(50),
	@Section					NUMERIC(5, 0),
	@Part						NUMERIC(5, 0),
	@Speaker					VARCHAR(3),
	@AnchorOffset				INT,
	@FocusOffset				INT,
	@CurrentTime				FLOAT,
	@EndCurrentTime				FLOAT,
	@UtteranceId				NUMERIC(18, 0),
	@TextContent				VARCHAR(500),
	@CreatedDate				DATETIME,
	@CreatedByUserId			VARCHAR(50),
	@LastModifiedDate			DATETIME,
	@LastModifiedByUserId		VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [dbo].[Utterance] SET
		[VCC] = @VCC,
		[AppId] = @AppId,
		[IntentId] = @IntentId,
		[AudioId] = @AudioId,
		[Section] = @Section,
		[Part] = @Part,
		[Speaker] = @Speaker,
		[AnchorOffset] = @AnchorOffset,
		[FocusOffset] = @FocusOffset,
		[CurrentTime] = @CurrentTime,
		[EndCurrentTime] = @EndCurrentTime,
		[UtteranceId] = @UtteranceId,
		[TextContent] = @TextContent,
		[CreatedDate] = @CreatedDate,
		[CreatedByUserId] = @CreatedByUserId,
		[LastModifiedDate] = @LastModifiedDate,
		[LastModifiedByUserId] = @LastModifiedByUserId,
		[TimeStamp] = GETUTCDATE()
	WHERE
		[VCC] = @VCC
		AND [AppId] = @AppId
		AND [IntentId] = @IntentId
		AND [AudioId] = @AudioId
		AND [Section] = @Section
		AND [Part] = @Part
		AND [Speaker] = @Speaker
		AND [AnchorOffset] = @AnchorOffset
		AND [FocusOffset] = @FocusOffset
		AND [CurrentTime] = @CurrentTime
		AND [EndCurrentTime] = @EndCurrentTime
		AND [UtteranceId] = @UtteranceId
		AND [TextContent] = @TextContent

	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [dbo].[Utterance] (
			[VCC],
			[AppId],
			[IntentId],
			[AudioId],
			[Section],
			[Part],
			[Speaker],
			[AnchorOffset],
			[FocusOffset],
			[CurrentTime],
			[EndCurrentTime],
			[UtteranceId],
			[TextContent],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
			[TimeStamp]
		)
		VALUES(
			@VCC,
			@AppId,
			@IntentId,
			@AudioId,
			@Section,
			@Part,
			@Speaker,
			@AnchorOffset,
			@FocusOffset,
			@CurrentTime,
			@EndCurrentTime,
			@UtteranceId,
			@TextContent,
			@CreatedDate,
			@CreatedByUserId,
			@LastModifiedDate,
			@LastModifiedByUserId,
			GETUTCDATE()
		)
	END

	SELECT 1 AS 'result'

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAbilityEvaluationFormats]...';


GO


ALTER PROCEDURE [dbo].[GetAbilityEvaluationFormats] (
	@Instance Varchar(50) = NULL, 
	@IdEvaluationFormat Varchar(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	SELECT
		AEF.[ID]						'id',
		AEF.[IdEvaluationFormat]		'idEvaluationFormat',
		AEF.[IdAbility]					'idAbility',
		A.[Title]						'titleAbility',
		A.[Detail]						'detailAbility',
		A.[Type]						'abilityType',
		A.[AnalysisType]				'abilityAnalysisType',
		A.[Query]						'abilityQuery',
		AEF.[IdGroup]					'idGroup',
		G.[Description]                 'descriptionGroup',
		AEF.[IdSubGroup]				'idSubGroup',
		SG.[Description]                 'descriptionSubGroup',
		AEF.[Penalizes]					'penalizes',
		AEF.[Score]						'score',
		AEF.[Order]						'order',
		A.[NotApply]					'acceptNotApplies',
		A.[AcceptComments]				'acceptComments',
		A.[Detail]						'descriptionAbility',
		AEF.[Conditional]				'conditional',
        A.QueryName						'query'
	FROM [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
	INNER JOIN [dbo].[Group] G (NOLOCK)
		ON G.[Instance] = AEF.[Instance]
			AND G.[ID] = AEF.[IdGroup]
	INNER JOIN [dbo].[SubGroup] SG (NOLOCK)
		ON SG.[Instance] = AEF.[Instance]
			AND SG.[ID] = AEF.[IdSubGroup]
	INNER JOIN [dbo].[Ability] A (NOLOCK)
		ON A.[Instance] = AEF.[Instance]
			AND A.[ID] = AEF.[IdAbility]
	WHERE AEF.[Instance] = @Instance
		AND AEF.[IdEvaluationFormat]= @IdEvaluationFormat
	ORDER BY [Order] ASC
	
	/* DEPRECATED
	SELECT
		A.[ID]							'id',
		A.[IdEvaluationFormat]			'idEvaluationFormat',
		A.[IdAbility]					'idAbility',
		AB.[Title]						'titleAbility',
		AB.[Detail]						'detailAbility',
		AB.[Type]						'abilityType',
		AB.[Query]						'abilityQuery',
		A.[IdGroup]						'idGroup',
		G.[Description]                 'descriptionGroup',
		A.[IdSubGroup]					'idSubGroup',
		S.[Description]                 'descriptionSubGroup',
		A.[Penalizes]					'penalizes',
		A.[Score]						'score',
		A.[Order]						'order',
		AB.[NotApply]					'acceptNotApplies',
		AB.[AcceptComments]				'acceptComments',
		AB.[Detail]						'descriptionAbility',
		A.[Conditional]					'conditional',
        AB.QueryName					'query'
	FROM [SubGroup] S (NOLOCK)
	full join [AbilityEvaluationFormat] A (NOLOCK)
		on S.ID=A.IdSubGroup, [Ability] AB (NOLOCK),
		 [Group] G (NOLOCK)
	WHERE A.[Instance] = @Instance
		AND S.[Instance] = @Instance
		AND G.[Instance] = @Instance
		AND AB.[Instance] = @Instance
		AND A.IdAbility=AB.ID
		AND A.IdGroup=G.ID
		AND A.[IdEvaluationFormat]= @IdEvaluationFormat
	ORDER BY [Order] ASC
	*/
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAudiosTranscriptions]...';


GO
ALTER PROCEDURE [dbo].[GetAudiosTranscriptions]
(
	@PageSize				INT,
	@PageNumber				INT,
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@ID						VARCHAR(50),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				INT,
	@StartMinute			INT,
	@EndHour				INT,
	@EndMinute				INT,
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX)
)
AS
BEGIN
	DECLARE @SQL NVARCHAR(MAX)
	DECLARE @SQL_WHERE NVARCHAR(MAX)
	SET @SQL = 'SET NOCOUNT ON
	DECLARE @rows INT
	SET @rows = (SELECT COUNT(A.ID)
		FROM [dbo].[Audio] A (NOLOCK)
		INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON PA.[VCC] = A.[VCC]
				AND A.ID = PA.AudioId 
				AND A.Section = PA.Section 
				AND A.Part = PA.Part
		LEFT JOIN [dbo].[Process] P (NOLOCK)
			-- ON P.[Description] = PA.[ProcessId]
			ON P.[VCC] = A.[VCC]
				AND P.[Name] = PA.[ProcessId]
		WHERE A.[VCC] = ''' + @VCC + ''' 
			AND A.[IsTranscribed] = 1 
			AND P.[TYPE] = ''SPEECH'' '
			IF(@ProcessId IS NOT NULL)
			BEGIN
				SET @SQL += '
				AND PA.[ProcessId]= ''' + @ProcessId + ''' '
			END

	SET @SQL_WHERE = ''

	BEGIN
		IF(@ID IS NOT NULL)
		BEGIN
			SET @SQL_WHERE += '
				AND CONCAT(A.[ID], ''_'', A.[Section], ''_'', A.[Part]) LIKE ''%' + @ID + '%''
			'
		END
		IF(@Campaign IS NOT NULL AND LEN(@Campaign) > 0)
		BEGIN
			SET @SQL_WHERE += '
				AND A.[Campaign] IN(''' + @Campaign + ''')
			'
		END
		IF(@Agent IS NOT NULL AND LEN(@Agent) > 0)
		BEGIN
			SET @SQL_WHERE += '
				AND A.[Agent] IN(''' + @Agent + ''')
			'
		END
		IF(@ResultCode IS NOT NULL AND LEN(@ResultCode) > 0)
		BEGIN
			SET @SQL_WHERE += '
				AND CONCAT(A.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), A.[DispositionCode]), '''')) IN (''' + @ResultCode + ''')
			'
		END
		IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
		BEGIN
			SET @SQL_WHERE += '
				AND A.[EndDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
			'
		END
		IF(@StartHour IS NOT NULL AND @EndHour IS NOT NULL)
		BEGIN
			SET @SQL_WHERE += '
				AND DATEPART(HOUR, A.[EndDate]) >= ' + CONVERT(VARCHAR, @StartHour) + ' AND DATEPART(HOUR, A.[EndDate]) <= ' + CONVERT(VARCHAR, @EndHour) + '
			'
		END
		IF(@StartMinute IS NOT NULL AND @EndMinute IS NOT NULL)
		BEGIN
			SET @SQL_WHERE += '
				AND DATEPART(MINUTE, A.[EndDate]) >= ' + CONVERT(VARCHAR, @StartMinute) + ' AND DATEPART(MINUTE, A.[EndDate]) <= ' + CONVERT(VARCHAR, @EndMinute) + '
			'
		END

	END
	SET @SQL += @SQL_WHERE
	SET @SQL += ') '
	SET @SQL += 'SELECT @rows AS total'

	SET @SQL += '
		SELECT
			A.[ID]						''id'',
			A.[Section]					''section'',
			A.[Part]					''part'',
			PA.[ProcessId]				''processId'',
			A.[Number]					''number'',
			B.[Name]					''name'',
			A.[SilenceTime]				''silenceTime'',
			A.[DurationTime]			''durationTime'',
			A.[DurationLinguisticTime]	''durationLinguisticTime'',
			A.[Category1]				''category1'',
			A.[Category2]				''category2'',
			A.[Category3]				''category3'',
			A.[Agent]					''agent'',
			A.[Description]				''description'',
			B.[Environment]				''environment'',
			E.[Type]					''environmentType'',
			A.[IsTranscribed]			''isTranscribed'',
			COUNT(U.[TextContent])				''isSubrayed'',
			A.[CreatedDate]				''createdDate'',
			A.[EndDate]					''endDate''
		FROM [dbo].[Audio] A (NOLOCK)
		INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON PA.[VCC] = A.[VCC]
				AND A.ID = PA.AudioId 
				AND A.Section = PA.Section 
				AND A.Part = PA.Part
		INNER JOIN [dbo].[Process] B (NOLOCK) 
			ON B.[VCC] = PA.[VCC]
				AND PA.[ProcessId] = B.[Name]
		inner JOIN [dbo].[Environment] E (NOLOCK) 
			ON E.[VCC] = B.[VCC]
				AND B.[Environment] = E.[Name] 
				AND B.VCC = E.VCC
		LEFT JOIN [dbo].[Utterance] U (NOLOCK) 
			ON U.[VCC] = A.[VCC]
				AND A.ID = U.AudioId 
				AND A.Section = U.Section 
				AND A.Part = U.Part
		WHERE
			A.[VCC] = ''' + @VCC + ''' AND A.[IsTranscribed] = 1 '
			IF(@ProcessId IS NOT NULL)
			BEGIN
				SET @SQL += '
				AND PA.[ProcessId] = ''' + @ProcessId + ''' '
			END
			SET @SQL += '
	'
	SET @SQL += @SQL_WHERE
	SET @SQL += '
		AND B.[TYPE] = ''SPEECH''
		GROUP BY A.[ID], A.[Section], A.[Part], PA.[ProcessId], A.[Number],
				B.[Name], A.[SilenceTime], A.[DurationTime], A.[DurationLinguisticTime], A.[Category1],     
				A.[Category2], A.[Category3], A.[Agent], A.[Description], B.[Environment], 
				E.[Type], A.[IsTranscribed], A.[CreatedDate], A.[EndDate]
		ORDER BY A.[ID], PA.[ProcessId], A.[Agent], A.[Description], B.[Environment], A.[DurationTime], A.[CreatedDate]
		OFFSET ' + CONVERT(VARCHAR(50), @PageSize) + ' * (' + CONVERT(VARCHAR(50), @PageNumber) + ' - 1) ROWS
		FETCH NEXT ' + CONVERT(VARCHAR(50), @PageSize) + ' ROWS ONLY;
	'
	SET @SQL += ' SET NOCOUNT OFF'
	
	EXEC(@SQL)
END
GO
PRINT N'Actualizando [dbo].[DeleteIntent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteIntent]';


GO
PRINT N'Actualizando [dbo].[DeleteNLU]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteNLU]';


GO
PRINT N'Actualizando [dbo].[GetUtterancesByIntentId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetUtterancesByIntentId]';


GO
PRINT N'Actualizando [dbo].[GetUtterancesByInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetUtterancesByInteraction]';


GO
PRINT N'Actualización completada.';


GO
