-- ARCHIVO CON LAS ACTUALIZACIONES DE ESQUEMA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
PRINT N'Altering [dbo].[EvaluationPlan]...';


GO
ALTER TABLE [dbo].[EvaluationPlan]
    ADD [BatchStatus] VARCHAR (50) NULL;


GO
PRINT N'Starting rebuilding table [dbo].[Study]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_Study] (
    [VCC]                  VARCHAR (50)  NOT NULL,
    [ProcessId]            VARCHAR (50)  NOT NULL,
    [TemplateId]           VARCHAR (50)  NOT NULL,
    [Name]                 VARCHAR (200) NOT NULL,
    [Description]          VARCHAR (100) NULL,
    [Total]                INT           NULL,
    [Progress]             INT           NULL,
    [Error]                INT           NULL,
    [Percentage]           FLOAT (53)    NULL,
    [StatusDescription]    VARCHAR (MAX) NULL,
    [Status]               FLOAT (53)    NULL,
    [Type]                 VARCHAR (50)  NULL,
    [LastQueryId]          VARCHAR (50)  NULL,
    [ErrorMessage]         VARCHAR (800) NULL,
    [BatchStatus]          VARCHAR (50)  NULL,
    [CreatedDate]          DATETIME      NULL,
    [CreatedByUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]     DATETIME      NULL,
    [LastModifiedByUserId] VARCHAR (50)  NULL,
    [TimeStamp]            DATETIME      NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_Study_11] PRIMARY KEY CLUSTERED ([VCC] ASC, [ProcessId] ASC, [TemplateId] ASC, [Name] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[Study])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_Study] ([VCC], [ProcessId], [TemplateId], [Name], [Description], [Total], [Progress], [Error], [Percentage], [StatusDescription], [Status], [Type], [LastQueryId], [ErrorMessage], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp])
        SELECT   [VCC],
                 [ProcessId],
                 [TemplateId],
                 [Name],
                 [Description],
                 [Total],
                 [Progress],
                 [Error],
                 [Percentage],
                 [StatusDescription],
                 [Status],
                 [Type],
                 [LastQueryId],
                 [ErrorMessage],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp]
        FROM     [dbo].[Study]
        ORDER BY [VCC] ASC, [ProcessId] ASC, [TemplateId] ASC, [Name] ASC;
    END

DROP TABLE [dbo].[Study];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_Study]', N'Study';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_Study_11]', N'PK_Study_1', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Starting rebuilding table [dbo].[Version]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_Version] (
    [Id]                   VARCHAR (50)  NOT NULL,
    [InstallationId]       VARCHAR (50)  NOT NULL,
    [ServicePack]          VARCHAR (100) NOT NULL,
    [BuildVersion]         VARCHAR (50)  NULL,
    [TimeStamp]            DATETIME      NULL,
    [ServicePackTimeStamp] DATETIME      NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_Version1] PRIMARY KEY CLUSTERED ([Id] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[Version])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_Version] ([Id], [InstallationId], [ServicePack], [TimeStamp], [ServicePackTimeStamp])
        SELECT   [Id],
                 [InstallationId],
                 [ServicePack],
                 [TimeStamp],
                 [ServicePackTimeStamp]
        FROM     [dbo].[Version]
        ORDER BY [Id] ASC;
    END

DROP TABLE [dbo].[Version];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_Version]', N'Version';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_Version1]', N'PK_Version', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Altering [dbo].[BulkProgress]...';


GO
ALTER PROCEDURE [dbo].[BulkProgress]
AS
BEGIN
	INSERT INTO [Progress] ([Key]
		  ,[VCC]
		  ,[ProcessId]
		  ,[Type]
		  ,[TypeId]
		  ,[Total]
		  ,[Progress]
		  ,[Error]
		  ,[Percentage]
		  ,[StatusDescription])  
	SELECT [Key]
		  ,[VCC]
		  ,[ProcessId]
		  ,[Type]
		  ,[TypeId]
		  ,[Total]
		  ,[Progress]
		  ,[Error]
		  ,[Percentage]
		  ,[StatusDescription]
	  FROM [dbo].[#ProgressTemp]

	------------Estados de procesos --------------
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = CASE WHEN B.[Total] > 0 THEN B.[Percentage] ELSE 0 END
		,[StatusDescription] = CASE WHEN B.[Total] > 0 AND B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Total] > 0 AND B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
	FROM Process AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[vcc] = B.[vcc] 
			AND A.[Name] = B.ProcessId 
			AND B.[Type] IS NULL 

	UPDATE A
	SET [Status] = CASE 
		WHEN B.total > 0 AND B.total <= B.transcription + B.cancel AND B.cancel > B.transcription THEN 'FAILED' 
		WHEN B.total > 0 AND B.total <= B.transcription + B.cancel THEN 'COMPLETE' 
		ELSE 'INPROCESS_TRANSCRIPTION' 
		END
	FROM Process AS A
	INNER JOIN (
		  SELECT 
			COUNT(1)					total
			,COUNT(C.isCancel)			cancel
			,COUNT(C.IsTranscribed)		transcription 
			,B.ProcessId				processId
			,B.vcc						vcc
		  FROM [ProcessAudio] A (NOLOCK)
		  INNER JOIN [#ProgressTemp] B 
			ON A.[vcc] = B.[vcc] 
				AND A.ProcessId = B.ProcessId 
				AND B.[Type] IS NULL 
				AND B.[Percentage] = 1
		  INNER JOIN Audio C (NOLOCK) 
			ON A.VCC = C.VCC 
				AND A.AudioId =C.ID 
				AND ISNULL(A.Section,0) = ISNULL(C.Section,0) 
				AND ISNULL(A.Part,0) = ISNULL(C.Part,0)
		  GROUP BY B.ProcessId, B.vcc
	  ) B ON A.[vcc] = B.[vcc] 
		AND A.[Name] = B.ProcessId

	UPDATE P
		SET P.[Status] = CASE WHEN TMPP.[totalFailed] > TMPP.[totalSucced] THEN 'FAILED'
								ELSE 'COMPLETE' END,
			P.[StatusDescription] = CASE WHEN TMPP.[totalFailed] > 0 THEN 'COMPLETED_WITH_ERROR' 
											ELSE 'COMPLETED' END,
			P.[Percentage] = 1
		FROM [dbo].[Process] P (NOLOCK)
		INNER JOIN (SELECT P.[Name] 'processId',
							COUNT(*) 'totalAudio',
							COUNT(CASE WHEN ISNULL(A.[IsTranscribed], 0) = 1 THEN 1 ELSE NULL END) 'totalSucced',
							COUNT(CASE WHEN ISNULL(A.[IsCancel], 0) = 1 THEN 1 ELSE NULL END) 'totalFailed'
						FROM [dbo].[Process] P (NOLOCK) 
						INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
							ON PA.[ProcessId] = P.[Name]
						INNER JOIN [dbo].[Audio] A (NOLOCK) 
							ON A.[ID] = PA.[AudioId]
								AND A.[Section] = PA.[Section]
								AND A.[Part] = PA.[Part]
						WHERE (P.[StatusDescription] <> 'COMPLETED' AND P.[Status] <> 'COMPLETED')
							OR (P.[StatusDescription] = 'COMPLETED' AND P.[Status] <> 'COMPLETED')
							OR (P.[Total] = 0 AND P.[Percentage] = 0)
							-- AND P.[Status] = 'INPROCESS_TRANSCRIPTION'
							--AND P.[StatusDescription] = 'IN_PROGRESS'
						GROUP BY P.[Name]) TMPP
			ON TMPP.[processId] = P.[Name]
				AND TMPP.[totalAudio] = (ISNULL(TMPP.[totalSucced], 0) + ISNULL(TMPP.[totalFailed], 0))


	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	-- SI EL PROCESS SE MARCA COMO FAILED TUVO MUCHO FRACASOS, PERO AUN ASI TUVO EXITOS QUE DEBERERIA COBRARSE
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [LastModifiedDate])
		SELECT PTMP.[vcc], 'TRANSCRIPTION', PTMP.[ProcessId], 1, GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[Process] P 
				ON P.[vcc] = PTMP.[vcc] 
					AND P.[Name] = PTMP.[ProcessId] 
					AND PTMP.[Type] IS NULL
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] IS NULL
	
	------------ESTADOS DE ESTUDIOS --------------
	UPDATE A
		SET [Total] = B.[Total]
			,[progress] = B.[Progress]
			,[error] = B.[Error]
			,[percentage] = B.[Percentage]
			,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
										WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
										ELSE  'IN_PROGRESS' END
			,[Status] = B.[Percentage]
			--,[BatchStatus] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'FINISHED_WITH_ERROR' 
				--					WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'FINISHED' 
					--				ELSE 'RUNNING' END
		FROM Study AS A
		INNER JOIN [dbo].[#ProgressTemp] B 
			ON A.[vcc] = B.[vcc] 
				AND A.[ProcessId] = B.ProcessId 
				AND A.[Name] = B.[TypeId] 
				AND B.[Type] = 'study'

	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [LastModifiedDate])
		SELECT PTMP.[vcc], 'STUDY', PTMP.[TypeId], 1, GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[Study] S 
				ON S.[vcc] = PTMP.[vcc] 
					AND S.[ProcessId] = PTMP.[ProcessId] 
					AND S.[Name] = PTMP.[TypeId]
					AND PTMP.[Type] = 'study'
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] = 'study'

	------------Estados de plan de evaluacion --------------

	-- UPDATE PARA LA PARTE DE TRANSCRIPCION
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE 'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 3 ELSE 2 END
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B ON A.[Instance] = B.[vcc] 
	AND A.[ProcessId] = B.ProcessId 
	AND B.[Type] IS NULL 
	AND A.[FilterByContentQueryName] IS NOT NULL 
	AND A.[FilterByContentQuery] IS NOT NULL

	-- UPDATE CONTEMPLADO PARA PLAN DE EVALUACION CON PASO 3 (FILTRO DE CONTENIDO)
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 5 ELSE 4 END
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B ON A.[Instance] = B.[vcc] AND A.[ProcessId] = B.ProcessId AND A.Id = B.[TypeId] AND B.[Type] = 'evaluationPlan'

	-- UPDATE PARA LA PARTE DE ANALISIS SEMANTICO/COGNITIVO
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 5 ELSE 2 END
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B ON A.[Instance] = B.[vcc] 
	AND A.[ProcessId] = B.ProcessId 
	AND B.[Type] IS NULL 
	AND A.[FilterByContentQueryName] IS NULL 
	AND A.[FilterByContentQuery] IS NULL 
	AND A.[Evaluation_Mode] = 'A' 

	-- 
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 7 ELSE 6 END
		--,[BatchStatus] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'FINISHED_WITH_ERROR' 
			--					WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'FINISHED' 
				--				ELSE 'RUNNING' END
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[Instance] = B.[vcc] 
			AND A.[ProcessId] = B.ProcessId 
			AND A.Id = B.[TypeId] 
			AND B.[Type] = 'ability'

	-- EN UNA TABLA ADICIONAL PODRIA INSERTAR LOS RP STATUS 7 PARA LUEGO ENVIARLOS A CERRAR EN EL SC
	UPDATE AEP 
		SET AEP.[Completed] = 1
	FROM dbo.[AuditorEvaluationPlan] AEP 
	INNER JOIN dbo.[EvaluationPlan] EP 
		ON EP.[ID] = AEP.[IdEvaluationPlan]
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON EP.[Instance] = B.[vcc] 
			AND EP.[ProcessId] = B.ProcessId 
			AND EP.Id = B.[TypeId] 
			AND B.[Type] = 'ability'
	WHERE EP.[Status] = 7

	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [LastModifiedDate])
		SELECT PTMP.[vcc], 'EVALUATION_PLAN', PTMP.[TypeId], 1, GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[EvaluationPlan] EP 
				ON EP.[Instance] = PTMP.[vcc] 
					AND EP.[ProcessId] = PTMP.[ProcessId] 
					AND EP.[Id] = PTMP.[TypeId]
					AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')
			WHERE PTMP.[Percentage] = 1 
				AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')

	SELECT * FROM dbo.[AuditorEvaluationPlan]

	-----------------------------------------------------

	DROP TABLE [dbo].[#ProgressTemp]

END
GO
PRINT N'Altering [dbo].[GetEvaluationPlans]...';


GO
ALTER  PROCEDURE [dbo].[GetEvaluationPlans] (
@Instance           Varchar(50) = NULL,
@SearchCriteria     Varchar(50) = NULL,
@SearchExpression   Varchar(50) = NULL,
@Disabled			bit = NULL
)
AS
BEGIN
SET NOCOUNT ON

    SELECT
    e.[ID]							'id',
    e.[Modality]					'modality',
    e.[DateFin]						'dateFin',
    e.CreatedDate					'createdDate',
    e.CreatedByUserId				'createdByUserId',
    e.LastModifiedDate				'lastModifiedDate',
    e.LastModifiedByUserId			'lastModifiedByUserId',
    e.Description					'description',
    e.IdEvaluationFormat            'idEvaluationFormat',
    e.Enabled						'enabled',
    e.Status						'status',
    e.Evaluation_Mode				'evaluation_mode',
    e.processId    				    'processId',
    ef.templateId    				'templateId',
    count(a.IdInteraction)			'totalEvaluations',
    ISNULL(sum(cast(a.Completed as int)), 0)   'completedEvaluations',
    ISNULL(ROUND(sum(cast(a.Completed as numeric(5,2)))*100/count(a.IdInteraction),2), 0) 'completedPercentage',
	e.[Percentage]					'percentage',
	e.[StatusDescription]			'statusDescription',
	e.[BatchStatus]					'batchStatus'
FROM EvaluationPlan e (NOLOCK)
LEFT JOIN AuditorEvaluationPlan a (NOLOCK) 
	ON a.[Instance] = e.[Instance]
		AND a.[IdEvaluationPlan] = e.[ID]
LEFT JOIN EvaluationFormat ef (NOLOCK)
	ON ef.[Instance] = e.[Instance]
		AND ef.[ID] = e.[IdEvaluationFormat]
WHERE e.Instance = @Instance
	AND ISNULL(e.Description, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
    AND ISNULL(e.Modality, '') LIKE CASE WHEN @SearchCriteria = 'modality' THEN '%' + @SearchExpression + '%' ELSE '%' END
    AND ISNULL(@Disabled, 0) <> e.Enabled
GROUP BY e.[ID],e.[Modality],e.[DateFin],e.CreatedDate,e.CreatedByUserId,
         e.LastModifiedDate,e.LastModifiedByUserId,e.Description,e.IdEvaluationFormat,
		 e.Enabled, e.Status, e.Evaluation_Mode,e.processId,ef.templateId, 
		 e.Percentage, e.StatusDescription, e.[BatchStatus]	
/*
    , AuditorEvaluationPlan a, EvaluationFormat ef (NOLOCK)
WHERE
    e.Instance = @Instance
    AND e.IdEvaluationFormat=ef.id
    AND a.IdEvaluationPlan=e.ID
    -- AND ISNULL(e.Status, '') LIKE CASE WHEN @SearchCriteria = 'status' THEN '%' + @SearchExpression + '%' ELSE '%' END
    AND ISNULL(e.Description, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
    AND ISNULL(e.Modality, '') LIKE CASE WHEN @SearchCriteria = 'modality' THEN '%' + @SearchExpression + '%' ELSE '%' END
    AND ISNULL(@Disabled, 0) <> e.Enabled
GROUP BY e.[ID],e.[Modality],e.[DateFin],e.CreatedDate,e.CreatedByUserId,
         e.LastModifiedDate,e.LastModifiedByUserId,e.Description,e.IdEvaluationFormat,e.Enabled, e.Status, e.Evaluation_Mode,e.processId,ef.templateId
*/
    SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[SaveSQLStudyDetail]...';


GO
-- [dbo].[SaveSQLStudyDetail] 'default', '36375C91-8874-4D13-A410-CBB675E1D83F', '8798F2D7-7BE1-40C6-831C-F17683B90929', '/* Sintaxis SQL */', 0
ALTER PROCEDURE [dbo].[SaveSQLStudyDetail]
(
	@VCC					VARCHAR(50),
	@StudyId				VARCHAR(200),
	@TemplateId				VARCHAR(50),
	@SQL					VARCHAR(MAX),
	@Restart				INT

)
AS
BEGIN
	SET NOCOUNT ON

	-- Si llega el parametro que indica que debe reprocesar estudio.
	IF(@Restart = 1)
	BEGIN
		-- Restablecer tablas:
		-- Study
		-- StudyDetail
		-- StudyResultSummary
		-- StudyResultSummaryDetail
		BEGIN
			UPDATE [dbo].[Study] SET
			[Status] = NULL
			WHERE VCC = @VCC
			AND [Name] = @StudyId
		END

		BEGIN
			DELETE FROM [dbo].[StudyDetail]
			WHERE VCC = @VCC
			AND StudyId = @StudyId
		END

		BEGIN
			DELETE FROM [dbo].[StudyResultSummary]
			WHERE VCC = @VCC
			AND StudyId = @StudyId
		END

		BEGIN
			DELETE FROM [dbo].[StudyResultSummaryDetail]
			WHERE VCC = @VCC
			AND StudyId = @StudyId
		END
	END

	-- ContinÃºa ejecucion normal.
	BEGIN
		EXEC(@SQL)
	END
	BEGIN
		INSERT INTO [dbo].[StudyResultSummary] ([VCC], [StudyId], [TemplateId], [TemplateThemeId], [ID], [Description], [Category1], [Category2], [Total], [Duration], [Silence], [Confidence], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp])
		SELECT B.VCC, B.StudyId, A.TemplateId, A.ID TemplateThemeId, CONVERT(VARCHAR(50), NEWID()) ID, A.Description, A.Category1, A.Category2, 
		COUNT(B.Total) Total, SUM(B.Duration) Duration, SUM(B.Silence) Silence, AVG(B.Confidence) Confidence, A.CreatedDate, A.CreatedByUserId, A.LastModifiedDate, A.LastModifiedByUserId, GETUTCDATE()
		FROM [dbo].[TemplateTheme] A (NOLOCK)
		INNER JOIN [dbo].[StudyDetail] B (NOLOCK) ON A.ID = B.TemplateThemeId
		INNER JOIN [dbo].[Study] S (NOLOCK) ON S.[VCC] = B.[VCC] AND S.[Name] = B.[StudyId]
		LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) ON S.[VCC] = PA.[VCC] AND S.[ProcessId] = PA.[ProcessId] AND B.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
		WHERE
			A.VCC IN ('system', @VCC)
			AND B.StudyId = @StudyId
			AND A.TemplateId = @TemplateId
		GROUP BY B.VCC, B.StudyId, A.TemplateId, A.ID, A.Description, A.Category1, A.Category2, A.CreatedDate, A.CreatedByUserId, A.LastModifiedDate, A.LastModifiedByUserId, A.TimeStamp
	END
	BEGIN
		UPDATE [dbo].[Study] SET
		[Status] = 1
		WHERE 
			VCC = @VCC
			AND [Name] = @StudyId
	END
	SELECT 1 AS 'result'

	SET NOCOUNT OFF

END
GO
PRINT N'Altering [dbo].[GetProcessCSVResult]...';


GO
ALTER PROCEDURE [dbo].[GetProcessCSVResult] (
	@VCC VARCHAR(50) = NULL,
	@SecondsPerRequest DECIMAL(18, 5),
	@StartDate DATETIME = '1980-01-01T00:00:00',
    @EndDate DATETIME = '2050-01-01T23:59:59',
	@Campaigns VARCHAR(MAX) = '',
 	@Agents VARCHAR(MAX) = '',
   	@Origins VARCHAR(100) = NULL,
	@StartHour VARCHAR(50) = NULL,
	@EndHour VARCHAR(50) = NULL,
	@MinDuration INT = 0,
    @MaxDuration INT = 100000,
    @Results VARCHAR(MAX) = NULL
) 
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOASUN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @INTERACTION_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_ACTOR_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_MULTIMEDIA_PARTS_TABLE NVARCHAR(100)
	DECLARE @CAMPAIGN_GOAL_RESULT_MANAGEMENT_TABLE NVARCHAR(100)

	-- SETTEAMOS LOS VALORES DE DURACION MINIMA Y MAXIMA A UNO VALIDO
	IF @MinDuration = @MaxDuration AND @MaxDuration = 0 SET @MaxDuration = 100000
	IF @MinDuration IS NULL SET @MinDuration = 0
	IF @MaxDuration IS NULL SET @MaxDuration = 100000

	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '

	SET @SQL_SELECT_1 += '
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN 1 ELSE 0 END) ''alreadyTranscribedAudio'',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN PCT.[DurationTime] ELSE 0 END) ''alreadyTranscribedDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL) THEN 1 ELSE 0 END) ''inProcessAudio'',
				SUM(CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL) THEN PCT.[DurationTime] ELSE 0 END) ''inProcessDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)) THEN 1 ELSE 0 END) ''notTranscribedAudio'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)) THEN PCT.[DurationTime] ELSE 0 END) ''notTranscribedDurationTime'', 
				SUM(PCT.[DurationTime] / ' + (SELECT CONVERT(varchar(10), @SecondsPerRequest)) + ') ''averageModelResquest'' '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [#ProcessCsvTemp] PCT
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
				-- ON CONCAT(A.[ID], ''_'', A.[Section], ''_'', A.[Part]) = PCT.[ID]
				ON A.[ID] = PCT.[ID]
					AND A.[VCC] = ''' + @VCC + ''' '

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE PCT.[ID] IS NOT NULL 
				AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' '

	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') SET @SQL_FILTER += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	IF (@Origins IS NOT NULL AND @Origins != '') SET @SQL_FILTER += 'AND PCT.[Type] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	IF (@Results IS NOT NULL AND @Results != '') SET @SQL_FILTER += 'AND PCT.[DispositionCode] IN (SELECT Value FROM [dbo].[split](''' + @Results + ''','','')) ';
	
	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	SET @SQL_EXTRA += 'DROP TABLE [#ProcessCsvTemp]'
	
	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	-- EJECUTAMOS LA CONSULTA
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Altering [dbo].[GetProcessValidDurationTime]...';


GO
ALTER  PROCEDURE [dbo].[GetProcessValidDurationTime](
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50)
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE RETORNAR LA CANTIDAD DE SEGUNDOS DE TRANSCRIPCION DE AUDIO CORRESPONDIENTE A UN PROCESS
	SET XACT_ABORT, NOCOUNT ON
	
	SELECT P.[Name] 'name',
			SUM(A.[DurationLinguisticTime]) 'validDurationTime'
		FROM Process P (NOLOCK)
		LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON PA.[ProcessId] = P.[Name]
		LEFT JOIN [dbo].[Audio] A (NOLOCK) 
			ON A.[ID] = PA.[AudioId]
				AND A.[Section] = PA.[Section]
				AND A.[Part] = PA.[Part]
		WHERE P.[VCC] = @VCC 
			AND P.[Name] = @ProcessId
		GROUP BY P.[Name] 

	SET XACT_ABORT, NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetStudies]...';


GO
ALTER PROCEDURE [dbo].[GetStudies]
(
	@VCC Varchar(50) = NULL,
	@SearchCriteria Varchar(50) = NULL,
	@SearchExpression Varchar(50) = NULL,
	@StartDate DATETIME, 
	@EndDate DATETIME,
	@Type VARCHAR(50)
)
AS
BEGIN
	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
	SET NOCOUNT ON

	SELECT
		[VCC]							''vcc'',
		[ProcessId]						''processId'',
		[TemplateId]					''templateId'',
		[Name]							''name'',
		[Description]					''description'',
		[Status]						''status'',
		[Error]							''error'',
		[Percentage]					''percentage'',
		[StatusDescription]				''statusDescription'',
		[Type]							''type'',
		[LastQueryId]					''lastQueryId'',
		[ErrorMessage]					''errorMessage'',
		[BatchStatus]					''batchStatus'',
		[CreatedDate]					''createdDate'',
		[CreatedByUserId]				''createdByUserId'',
		[LastModifiedDate]				''lastModifiedDate'',
		[LastModifiedByUserId]			''lastModifiedByUserId''
	FROM [dbo].[Study] (NOLOCK)
	WHERE [VCC] = ''' + @VCC + '''
	AND [Type] = ''' + @Type + '''
	AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
	AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
	AND ISNULL([Status], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''status'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'

	IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
	BEGIN
		SET @SQL += '
			AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
		'
	END
	SET @SQL += '
	ORDER BY [Status] desc, [CreatedDate] desc 

	SET NOCOUNT OFF
	'
	EXEC(@SQL)
END
GO
PRINT N'Creating [dbo].[GetBatchDetail]...';


GO
CREATE PROCEDURE [dbo].[GetBatchDetail](
	@VCC VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- VERIFICAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
	IF @VCC IS NULL OR @BatchTypeName IS NULL OR @BatchTypeId IS NULL 
		-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
		RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

	-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
	IF @BatchTypeName <> 'TRANSCRIPTION' AND @BatchTypeName <> 'STUDY' AND @BatchTypeName <> 'EVALUATION_PLAN'
		-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
		RAISERROR('DATABASE_ERROR_UNKNOWN_BATCH_TYPENAME', 16, 16)

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		
		-- DEPENDIENDO DEL BATCHTYPENAME CONSULTAMOS A UNA TABLA DIFERENTE
		IF @BatchTypeName = 'TRANSCRIPTION'
		BEGIN
			-- HACEMOS LA BUSQUEDA EN LA TABLA CORRESPONDIENTE SEGUN EL TIPO DE BATCH
			SELECT P.[VCC]						'vcc',
					@BatchTypeName				'batchTypeName',
					P.[Name]					'batchTypeId',
					P.[Description]				'description',
					p.[Percentage]				'percentage',
					P.[Status]					'status',
					P.[StatusDescription]		'statusDescription' 
				FROM [dbo].[Process] P (NOLOCK)
				WHERE P.[VCC] = @VCC 
					AND P.[Name] = @BatchTypeId
		END 
		ELSE IF @BatchTypeName = 'STUDY'
		BEGIN
			SELECT S.[VCC]						'vcc',
					@BatchTypeName				'batchTypeName',
					S.[Name]					'batchTypeId',
					S.[Description]				'description',
					S.[Percentage]				'percentage',
					S.[Status]					'status',
					S.[StatusDescription]		'statusDescription' ,
					S.[BatchStatus]				'batchStatus'
				FROM [dbo].[Study] S (NOLOCK)
				WHERE S.[VCC] = @VCC 
					AND S.[Name] = @BatchTypeId
		END 
		ELSE IF @BatchTypeName = 'EVALUATION_PLAN'
		BEGIN
			SELECT EP.[Instance]				'vcc',
					@BatchTypeName				'batchTypeName',
					EP.[ID]						'batchTypeId',
					EP.[Description]			'description',
					EP.[Percentage]				'percentage',
					EP.[Status]					'status',
					EP.[StatusDescription]		'statusDescription' ,
					EP.[BatchStatus]			'batchStatus'
				FROM [dbo].[EvaluationPlan] EP (NOLOCK)
				WHERE EP.[Instance] = @VCC 
					AND EP.[ID] = @BatchTypeId
		END 

	END TRY
    BEGIN CATCH
        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
END
GO
PRINT N'Creating [dbo].[SaveBatchStatus]...';


GO
-- ESTA FUNCION CAMBIA EL ESTADO DE UN BATCH DEL SISTEMA
CREATE PROCEDURE [dbo].[SaveBatchStatus] (
	@VCC VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(100) = NULL,
	@SystemService VARCHAR(50) = NULL,
	@Status VARCHAR(50) = NULL
	)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		
		-- VALIDAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
		IF @VCC IS NULL 
			OR @BatchTypeId IS NULL 
			OR @Status IS NULL
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

		-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
		IF @SystemService <> 'TRANSCRIPTION' AND @SystemService <> 'SEMANTIC_ANALYSIS' AND @SystemService <> 'COGNITIVE_ANALYSIS'
			-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
			RAISERROR('DATABASE_ERROR_UNKNOWN_SYSTEM_SERVICE', 16, 16)

		-- DECLARAMOS UNA VARIABLE PARA TIPO DE BATCH CORRESPONDIENTE AL BATCHTYPEID
		DECLARE @BATCH_TYPE_NAME VARCHAR(50) = NULL

		-- IDENTIFICAMOS EL TIPO BATCH SEGUN EL BATCHTYPEID Y SERVICIO DEL SISTEMA
		IF @SystemService = 'TRANSCRIPTION'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO PROCESS
			IF EXISTS (SELECT 1 FROM [dbo].[Process] P WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'TRANSCRIPTION'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'EVALUATION_PLAN'
		END
		ELSE IF @SystemService = 'SEMANTIC_ANALYSIS'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO STUDY
			IF EXISTS (SELECT 1 FROM [dbo].[Study] P WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'STUDY'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'EVALUATION_PLAN'
		END
		ELSE IF @SystemService = 'COGNITIVE_ANALYSIS'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO STUDY
			IF EXISTS (SELECT 1 FROM [dbo].[Study] P WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'STUDY'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'EVALUATION_PLAN'
		END
		
		-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
		IF @BATCH_TYPE_NAME <> 'TRANSCRIPTION' AND @BATCH_TYPE_NAME <> 'STUDY' AND @BATCH_TYPE_NAME <> 'EVALUATION_PLAN'
			-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
			RAISERROR('DATABASE_ERROR_UNKNOWN_BATCH_TYPE', 16, 16)

		-- ACTUALIZAMOS EL BATCH SEGUN EL SERVICIO DEL SISTEMA
		IF @BATCH_TYPE_NAME = 'TRANSCRIPTION'
		BEGIN
			-- ACTUALIZAMOS EL REGISTRO DE PROCESS
			UPDATE [dbo].[Process] 
				SET [StatusDescription] = @Status, 
					[Status] = @Status 
				WHERE [VCC] = @VCC
					AND [Name] = @BatchTypeId
		END 
		ELSE IF @BATCH_TYPE_NAME = 'STUDY'
		BEGIN
			-- ACTUALIZAMOS EL REGISTRO DE STUDY
			UPDATE [dbo].[Study] 
				SET [StatusDescription] = @Status, 
					[BatchStatus] = @Status,
					[LastModifiedDate] = CURRENT_TIMESTAMP,
					[TimeStamp] = CURRENT_TIMESTAMP 
				WHERE [VCC] = @VCC
					AND [Name] = @BatchTypeId
		END
		ELSE IF @BATCH_TYPE_NAME = 'EVALUATION_PLAN'
		BEGIN
			-- ACTUALIZAMOS EL REGISTRO DE EVALUATION_PLAN
			UPDATE [dbo].[EvaluationPlan] 
				SET [StatusDescription] = @Status, 
					[Status] = @Status, 
					[LastModifiedDate] = CURRENT_TIMESTAMP,
					[TimeStamp] = CURRENT_TIMESTAMP
				WHERE [Instance] = @VCC
					AND [ID] = @BatchTypeId
		END

		-- VERIFICAMOS SI SE ACTUALIZO EL REGISTRO
		IF @@ROWCOUNT = 0
			RAISERROR('DATABASE_ERROR_BATCH_SUMMARY_STATUS_UPDATE_FAILED', 16, 16)

		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

	END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
PRINT N'Refreshing [dbo].[BulkAbilityCognitive]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkAbilityCognitive]';


GO
PRINT N'Refreshing [dbo].[BulkEvaluationPlanAbility]...';


GO
SET ANSI_NULLS ON;

SET QUOTED_IDENTIFIER OFF;


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkEvaluationPlanAbility]';


GO
SET ANSI_NULLS, QUOTED_IDENTIFIER ON;


GO
PRINT N'Refreshing [dbo].[BulkEvaluationPlanQuery]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkEvaluationPlanQuery]';


GO
PRINT N'Refreshing [dbo].[BulkInteractionProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkInteractionProcess]';


GO
PRINT N'Refreshing [dbo].[DeleteAuditorEvaluationPlanByInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteAuditorEvaluationPlanByInteraction]';


GO
PRINT N'Refreshing [dbo].[DeleteEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteEvaluationPlan]';


GO
PRINT N'Refreshing [dbo].[EvaluateProcessStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[EvaluateProcessStatus]';


GO
PRINT N'Refreshing [dbo].[GetAuditorEvaluationPlanEvaluation]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAuditorEvaluationPlanEvaluation]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlan]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanAbilityGenericQueryTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanAbilityGenericQueryTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanAbilityTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanAbilityTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanByName]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanByName]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanByProcessId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanByProcessId]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanCognitiveInteractionTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveInteractionTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanCognitiveTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlansByStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlansByStatus]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationsOfInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationsOfInteraction]';


GO
PRINT N'Refreshing [dbo].[GetGenericQueryUsage]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetGenericQueryUsage]';


GO
PRINT N'Refreshing [dbo].[GetProcessEvaluationPlanTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessEvaluationPlanTask]';


GO
PRINT N'Refreshing [dbo].[GetReportByDetailAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetReportByDetailAgent]';


GO
PRINT N'Refreshing [dbo].[GetReportBySummaryAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetReportBySummaryAgent]';


GO
PRINT N'Refreshing [dbo].[ReportByDetailAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportByDetailAgent]';


GO
PRINT N'Refreshing [dbo].[ReportBySummaryAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportBySummaryAgent]';


GO
PRINT N'Refreshing [dbo].[ReportBySummaryFormat]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportBySummaryFormat]';


GO
PRINT N'Refreshing [dbo].[SaveEvaluationFormat]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationFormat]';


GO
PRINT N'Refreshing [dbo].[SaveEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationPlan]';


GO
PRINT N'Refreshing [dbo].[SaveEvaluationPlanAbilityStatusTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationPlanAbilityStatusTask]';


GO
PRINT N'Refreshing [dbo].[SaveEvaluationPlanCompleted]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationPlanCompleted]';


GO
PRINT N'Refreshing [dbo].[DeleteStudy]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteStudy]';


GO
PRINT N'Refreshing [dbo].[GetExecuteTemplateProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetExecuteTemplateProcess]';


GO
PRINT N'Refreshing [dbo].[GetInteractionsCognitive]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionsCognitive]';


GO
PRINT N'Refreshing [dbo].[GetProcessUsage]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessUsage]';


GO
PRINT N'Refreshing [dbo].[GetStudiesInProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudiesInProcess]';


GO
PRINT N'Refreshing [dbo].[GetStudy]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudy]';


GO
PRINT N'Refreshing [dbo].[GetStudyByName]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyByName]';


GO
PRINT N'Refreshing [dbo].[GetStudyCognitiveInteractionsTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyCognitiveInteractionsTask]';


GO
PRINT N'Refreshing [dbo].[GetStudyGenericQueryTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyGenericQueryTask]';


GO
PRINT N'Refreshing [dbo].[GetStudyQuery]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyQuery]';


GO
PRINT N'Refreshing [dbo].[GetStudyResultSummary]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyResultSummary]';


GO
PRINT N'Refreshing [dbo].[SaveStudy]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveStudy]';


GO
PRINT N'Refreshing [dbo].[SaveStudyStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveStudyStatus]';


GO
PRINT N'Refreshing [dbo].[GetVersion]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetVersion]';


GO
PRINT N'Update complete.';


GO
