PRINT N'Dropping [dbo].[DF_Batch_ID]...';


GO
ALTER TABLE [dbo].[Batch] DROP CONSTRAINT [DF_Batch_ID];


GO
PRINT N'Dropping [dbo].[DF_Batch_IsFinished]...';


GO
ALTER TABLE [dbo].[Batch] DROP CONSTRAINT [DF_Batch_IsFinished];


GO
PRINT N'Dropping [dbo].[DF_Batch_IsReported]...';


GO
ALTER TABLE [dbo].[Batch] DROP CONSTRAINT [DF_Batch_IsReported];


GO
PRINT N'Dropping [dbo].[DF_Batch_CreatedDate]...';


GO
ALTER TABLE [dbo].[Batch] DROP CONSTRAINT [DF_Batch_CreatedDate];


GO
PRINT N'Starting rebuilding table [dbo].[Batch]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_Batch] (
    [ID]               VARCHAR (100) CONSTRAINT [DF_Batch_ID] DEFAULT (newid()) NULL,
    [VCC]              VARCHAR (50)  NULL,
    [BatchTypeName]    VARCHAR (50)  NOT NULL,
    [BatchTypeId]      VARCHAR (50)  NULL,
    [StartReported]    BIT           NULL,
    [IsFinished]       BIT           CONSTRAINT [DF_Batch_IsFinished] DEFAULT ((0)) NULL,
    [FinishReported]   BIT           CONSTRAINT [DF_Batch_IsReported] DEFAULT ((0)) NULL,
    [CreatedDate]      DATETIME      CONSTRAINT [DF_Batch_CreatedDate] DEFAULT (getutcdate()) NULL,
    [ClosedDate]       DATETIME      NULL,
    [LastModifiedDate] DATETIME      NULL
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[Batch])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_Batch] ([ID], [VCC], [BatchTypeName], [BatchTypeId], [StartReported], [IsFinished], [FinishReported], [CreatedDate], [LastModifiedDate])
        SELECT [ID],
               [VCC],
               [BatchTypeName],
               [BatchTypeId],
               [StartReported],
               [IsFinished],
               [FinishReported],
               [CreatedDate],
               [LastModifiedDate]
        FROM   [dbo].[Batch];
    END

DROP TABLE [dbo].[Batch];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_Batch]', N'Batch';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Altering [dbo].[BulkProgress]...';


GO
ALTER PROCEDURE [dbo].[BulkProgress]
AS
BEGIN
	INSERT INTO [Progress] ([Key]
		  ,[VCC]
		  ,[ProcessId]
		  ,[Type]
		  ,[TypeId]
		  ,[Total]
		  ,[Progress]
		  ,[Error]
		  ,[Percentage]
		  ,[StatusDescription])  
	SELECT [Key]
		  ,[VCC]
		  ,[ProcessId]
		  ,[Type]
		  ,[TypeId]
		  ,[Total]
		  ,[Progress]
		  ,[Error]
		  ,[Percentage]
		  ,[StatusDescription]
	  FROM [dbo].[#ProgressTemp]

	------------Estados de procesos --------------
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = CASE WHEN B.[Total] > 0 THEN B.[Percentage] ELSE 0 END
		,[StatusDescription] = CASE WHEN B.[Total] > 0 AND B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Total] > 0 AND B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
	FROM Process AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[vcc] = B.[vcc] 
			AND A.[Name] = B.ProcessId 
			AND B.[Type] IS NULL 

	UPDATE A
	SET [Status] = CASE 
		WHEN B.total > 0 AND B.total <= B.transcription + B.cancel AND B.cancel > B.transcription THEN 'FAILED' 
		WHEN B.total > 0 AND B.total <= B.transcription + B.cancel THEN 'COMPLETE' 
		ELSE 'INPROCESS_TRANSCRIPTION' 
		END
	FROM Process AS A
	INNER JOIN (
		  SELECT 
			COUNT(1)					total
			,COUNT(C.isCancel)			cancel
			,COUNT(C.IsTranscribed)		transcription 
			,B.ProcessId				processId
			,B.vcc						vcc
		  FROM [ProcessAudio] A (NOLOCK)
		  INNER JOIN [#ProgressTemp] B 
			ON A.[vcc] = B.[vcc] 
				AND A.ProcessId = B.ProcessId 
				AND B.[Type] IS NULL 
				AND B.[Percentage] = 1
		  INNER JOIN Audio C (NOLOCK) 
			ON A.VCC = C.VCC 
				AND A.AudioId =C.ID 
				AND ISNULL(A.Section,0) = ISNULL(C.Section,0) 
				AND ISNULL(A.Part,0) = ISNULL(C.Part,0)
		  GROUP BY B.ProcessId, B.vcc
	  ) B ON A.[vcc] = B.[vcc] 
		AND A.[Name] = B.ProcessId

	UPDATE P
		SET P.[Status] = CASE WHEN TMPP.[totalFailed] > TMPP.[totalSucced] THEN 'FAILED'
								ELSE 'COMPLETE' END,
			P.[StatusDescription] = CASE WHEN TMPP.[totalFailed] > 0 THEN 'COMPLETED_WITH_ERROR' 
											ELSE 'COMPLETED' END,
			P.[Percentage] = 1
		FROM [dbo].[Process] P (NOLOCK)
		INNER JOIN (SELECT P.[Name] 'processId',
							COUNT(*) 'totalAudio',
							COUNT(CASE WHEN ISNULL(A.[IsTranscribed], 0) = 1 THEN 1 ELSE NULL END) 'totalSucced',
							COUNT(CASE WHEN ISNULL(A.[IsCancel], 0) = 1 THEN 1 ELSE NULL END) 'totalFailed'
						FROM [dbo].[Process] P (NOLOCK) 
						INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
							ON PA.[ProcessId] = P.[Name]
						INNER JOIN [dbo].[Audio] A (NOLOCK) 
							ON A.[ID] = PA.[AudioId]
								AND A.[Section] = PA.[Section]
								AND A.[Part] = PA.[Part]
						WHERE (P.[StatusDescription] <> 'COMPLETED' AND P.[Status] <> 'COMPLETED')
							OR (P.[StatusDescription] = 'COMPLETED' AND P.[Status] <> 'COMPLETED')
							OR (P.[Total] = 0 AND P.[Percentage] = 0)
							-- AND P.[Status] = 'INPROCESS_TRANSCRIPTION'
							--AND P.[StatusDescription] = 'IN_PROGRESS'
						GROUP BY P.[Name]) TMPP
			ON TMPP.[processId] = P.[Name]
				AND TMPP.[totalAudio] = (ISNULL(TMPP.[totalSucced], 0) + ISNULL(TMPP.[totalFailed], 0))


	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	-- SI EL PROCESS SE MARCA COMO FAILED TUVO MUCHO FRACASOS, PERO AUN ASI TUVO EXITOS QUE DEBERERIA COBRARSE
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], 'TRANSCRIPTION', PTMP.[ProcessId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[Process] P 
				ON P.[vcc] = PTMP.[vcc] 
					AND P.[Name] = PTMP.[ProcessId] 
					AND PTMP.[Type] IS NULL
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] IS NULL
	
	------------ESTADOS DE ESTUDIOS --------------
	UPDATE A
		SET [Total] = B.[Total]
			,[progress] = B.[Progress]
			,[error] = B.[Error]
			,[percentage] = B.[Percentage]
			,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
										WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
										ELSE  'IN_PROGRESS' END
			,[Status] = B.[Percentage]
			--,[BatchStatus] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'FINISHED_WITH_ERROR' 
				--					WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'FINISHED' 
					--				ELSE 'RUNNING' END
		FROM Study AS A
		INNER JOIN [dbo].[#ProgressTemp] B 
			ON A.[vcc] = B.[vcc] 
				AND A.[ProcessId] = B.ProcessId 
				AND A.[Name] = B.[TypeId] 
				AND B.[Type] = 'study'

	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], 'STUDY', PTMP.[TypeId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[Study] S 
				ON S.[vcc] = PTMP.[vcc] 
					AND S.[ProcessId] = PTMP.[ProcessId] 
					AND S.[Name] = PTMP.[TypeId]
					AND PTMP.[Type] = 'study'
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] = 'study'

	------------Estados de plan de evaluacion --------------

	-- UPDATE PARA LA PARTE DE TRANSCRIPCION
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE 'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 3 ELSE 2 END
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B ON A.[Instance] = B.[vcc] 
	AND A.[ProcessId] = B.ProcessId 
	AND B.[Type] IS NULL 
	AND A.[FilterByContentQueryName] IS NOT NULL 
	AND A.[FilterByContentQuery] IS NOT NULL

	-- UPDATE CONTEMPLADO PARA PLAN DE EVALUACION CON PASO 3 (FILTRO DE CONTENIDO)
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 5 ELSE 4 END
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B ON A.[Instance] = B.[vcc] AND A.[ProcessId] = B.ProcessId AND A.Id = B.[TypeId] AND B.[Type] = 'evaluationPlan'

	-- UPDATE PARA LA PARTE DE ANALISIS SEMANTICO/COGNITIVO
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 5 ELSE 2 END
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B ON A.[Instance] = B.[vcc] 
	AND A.[ProcessId] = B.ProcessId 
	AND B.[Type] IS NULL 
	AND A.[FilterByContentQueryName] IS NULL 
	AND A.[FilterByContentQuery] IS NULL 
	AND A.[Evaluation_Mode] = 'A' 

	-- 
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 7 ELSE 6 END
		--,[BatchStatus] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'FINISHED_WITH_ERROR' 
			--					WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'FINISHED' 
				--				ELSE 'RUNNING' END
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[Instance] = B.[vcc] 
			AND A.[ProcessId] = B.ProcessId 
			AND A.Id = B.[TypeId] 
			AND B.[Type] = 'ability'

	-- EN UNA TABLA ADICIONAL PODRIA INSERTAR LOS RP STATUS 7 PARA LUEGO ENVIARLOS A CERRAR EN EL SC
	UPDATE AEP 
		SET AEP.[Completed] = 1
	FROM dbo.[AuditorEvaluationPlan] AEP 
	INNER JOIN dbo.[EvaluationPlan] EP 
		ON EP.[ID] = AEP.[IdEvaluationPlan]
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON EP.[Instance] = B.[vcc] 
			AND EP.[ProcessId] = B.ProcessId 
			AND EP.Id = B.[TypeId] 
			AND B.[Type] = 'ability'
	WHERE EP.[Status] = 7

	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], 'EVALUATION_PLAN', PTMP.[TypeId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[EvaluationPlan] EP 
				ON EP.[Instance] = PTMP.[vcc] 
					AND EP.[ProcessId] = PTMP.[ProcessId] 
					AND EP.[Id] = PTMP.[TypeId]
					AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')
			WHERE PTMP.[Percentage] = 1 
				AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')

	SELECT * FROM dbo.[AuditorEvaluationPlan]

	-----------------------------------------------------

	DROP TABLE [dbo].[#ProgressTemp]

END
GO
PRINT N'Altering [dbo].[GetFinishedBatch]...';


GO
ALTER PROCEDURE [dbo].[GetFinishedBatch] 
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE RETORNAR LOS BATCH QUE HAN SIDO FINALIZADOS HACE MAS DE 5 MINUTOS
	SET NOCOUNT ON

	SELECT B.[VCC]				'vcc',
		B.[BatchTypeName]		'batchTypeName',
		B.[BatchTypeId]			'batchTypeId',
		B.[CreatedDate]			'closedDate'
	FROM [dbo].[Batch] B (NOLOCK)
	WHERE B.[IsFinished] = 1 
		AND B.[FinishReported] = 0
		AND B.[LastModifiedDate] < DATEADD(MINUTE, -5, GETUTCDATE())

	SET NOCOUNT OFF
END
GO
PRINT N'Refreshing [dbo].[FinishedBatchClose]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[FinishedBatchClose]';


GO
PRINT N'Update complete.';


GO
