-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '0.4.1'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '0.4.2'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION


    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION



    -- ACTUALIZAMOS EL TYPE DE LOS REPORTES PARA TODOS LOS VCC EXISTENTES
    PRINT 'UPDATING_REPORTS_TYPE'
    UPDATE [dbo].[Report] SET [Type] = 'BUSINESS', [LastModifiedByUserId] = 'admin', [LastModifiedDate] = GETUTCDATE() WHERE [ID] = 'REPORTBYVCCBALANCEDETAIL' AND [Type] = 'BILLING'
    UPDATE [dbo].[Report] SET [Type] = 'BUSINESS', [LastModifiedByUserId] = 'admin', [LastModifiedDate] = GETUTCDATE() WHERE [ID] = 'REPORTBYVCCBALANCEBYPERIOD' AND [Type] = 'BILLING'
    UPDATE [dbo].[Report] SET [Type] = 'BUSINESS', [LastModifiedByUserId] = 'admin', [LastModifiedDate] = GETUTCDATE() WHERE [ID] = 'REPORTSUMMARYOFEXPENSESBYPERIOD' AND [Type] = 'BILLING'
    PRINT 'UPDATED_REPORTS_TYPE'

    -- ELIMINAMOS EL INTERACTIONTYPE QUE NO ESTAN IMPLEMENTADOS AUN
    PRINT 'DELETING_INTERACTION_TYPES'
    DELETE FROM [InteractionType] WHERE [ID] = 'CHAT'
    DELETE FROM [InteractionType] WHERE [ID] = 'FACEBOOK'
    DELETE FROM [InteractionType] WHERE [ID] = 'MAIL'
    DELETE FROM [InteractionType] WHERE [ID] = 'TWITTER'
    PRINT 'DELETED_INTERACTION_TYPES'


    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH

    