PRINT N'Dropping [dbo].[GetProcessCSVResult]...';


GO
DROP PROCEDURE [dbo].[GetProcessCSVResult];


GO
PRINT N'Starting rebuilding table [dbo].[VCC]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_VCC] (
    [VCC]                  VARCHAR (50) NOT NULL,
    [ID]                   VARCHAR (50) NOT NULL,
    [Type]                 VARCHAR (50) CONSTRAINT [DF_VCC_Type] DEFAULT ('ALLEGRO') NOT NULL,
    [Description]          VARCHAR (50) NULL,
    [Country]              VARCHAR (50) NULL,
    [Language]             VARCHAR (50) NULL,
    [TimeZone]             VARCHAR (50) NULL,
    [CreatedDate]          DATETIME     NULL,
    [CreatedByUserId]      VARCHAR (50) NULL,
    [LastModifiedDate]     DATETIME     NULL,
    [LastModifiedByUserId] VARCHAR (50) NULL,
    [TimeStamp]            DATETIME     NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_VCC1] PRIMARY KEY CLUSTERED ([VCC] ASC, [ID] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[VCC])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_VCC] ([VCC], [ID], [Description], [Country], [Language], [TimeZone], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp])
        SELECT   [VCC],
                 [ID],
                 [Description],
                 [Country],
                 [Language],
                 [TimeZone],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp]
        FROM     [dbo].[VCC]
        ORDER BY [VCC] ASC, [ID] ASC;
    END

DROP TABLE [dbo].[VCC];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_VCC]', N'VCC';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_VCC1]', N'PK_VCC', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Creating [dbo].[AsyncInteraction]...';


GO
CREATE TABLE [dbo].[AsyncInteraction] (
    [VCC]                  VARCHAR (50)  NOT NULL,
    [ID]                   VARCHAR (250) NOT NULL,
    [Folder]               VARCHAR (50)  NULL,
    [ExportedContent]      VARCHAR (250) NULL,
    [Channel]              VARCHAR (50)  NULL,
    [Campaign]             VARCHAR (50)  NULL,
    [StartDate]            DATETIME      NULL,
    [EndDate]              DATETIME      NOT NULL,
    [Account]              VARCHAR (50)  NULL,
    [Initiative]           VARCHAR (50)  NULL,
    [ContactName]          VARCHAR (300) NULL,
    [FirstTakedAgent]      VARCHAR (50)  NULL,
    [LastTakedAgent]       VARCHAR (50)  NULL,
    [IsTaken]              VARCHAR (10)  NULL,
    [TotalMessages]        INT           NULL,
    [DurationTime]         VARCHAR (50)  NULL,
    [AttentionTime]        VARCHAR (50)  NULL,
    [DispositionCode]      VARCHAR (150) NULL,
    [DispositionTreePath]  VARCHAR (250) NULL,
    [IsProcess]            BIT           NULL,
    [IsCancel]             BIT           NULL,
    [IsTranscribed]        BIT           NULL,
    [FileName]             VARCHAR (250) NULL,
    [ViewFileName]         VARCHAR (250) NULL,
    [ErrorMessage]         VARCHAR (MAX) NULL,
    [RawChar]              INT           NULL,
    [ValidChar]            INT           NULL,
    [TotalPhrases]         INT           NULL,
    [CharsPerPhrase]       INT           NULL,
    [CreatedDate]          DATETIME      NULL,
    [CreatedByUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]     DATETIME      NULL,
    [LastModifiedByUserId] VARCHAR (50)  NULL,
    [TimeStamp]            DATETIME      NULL,
    CONSTRAINT [PK_Interaction] PRIMARY KEY CLUSTERED ([VCC] ASC, [ID] ASC, [EndDate] ASC)
);


GO
PRINT N'Creating [dbo].[ProcessAsyncInteraction]...';


GO
CREATE TABLE [dbo].[ProcessAsyncInteraction] (
    [VCC]                  VARCHAR (50)  NOT NULL,
    [ProcessId]            VARCHAR (50)  NOT NULL,
    [InteractionType]      VARCHAR (50)  NOT NULL,
    [Campaign]             VARCHAR (50)  NULL,
    [InteractionId]        VARCHAR (250) NOT NULL,
    [EndDate]              DATETIME      NOT NULL,
    [FormattedEndDate]     VARCHAR (100) NULL,
    [CreatedDate]          DATETIME      NULL,
    [CreatedByUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]     DATETIME      NULL,
    [LastModifiedByUserId] VARCHAR (50)  NULL,
    [TimeStamp]            DATETIME      NULL,
    CONSTRAINT [PK_ProcessAsyncInteraction_1] PRIMARY KEY CLUSTERED ([VCC] ASC, [ProcessId] ASC, [InteractionType] ASC, [InteractionId] ASC, [EndDate] ASC)
);


GO
PRINT N'Creating [dbo].[DF_Interaction_RawWords]...';


GO
ALTER TABLE [dbo].[AsyncInteraction]
    ADD CONSTRAINT [DF_Interaction_RawWords] DEFAULT ((0)) FOR [RawChar];


GO
PRINT N'Creating [dbo].[DF_AsyncInteraction_ValidChar]...';


GO
ALTER TABLE [dbo].[AsyncInteraction]
    ADD CONSTRAINT [DF_AsyncInteraction_ValidChar] DEFAULT ((0)) FOR [ValidChar];


GO
PRINT N'Creating [dbo].[DF_Interaction_ProcessedWords]...';


GO
ALTER TABLE [dbo].[AsyncInteraction]
    ADD CONSTRAINT [DF_Interaction_ProcessedWords] DEFAULT ((0)) FOR [TotalPhrases];


GO
PRINT N'Creating [dbo].[DF_Interaction_CreatedDate]...';


GO
ALTER TABLE [dbo].[AsyncInteraction]
    ADD CONSTRAINT [DF_Interaction_CreatedDate] DEFAULT (getdate()) FOR [CreatedDate];


GO
PRINT N'Creating [dbo].[DF_ProcessAsyncInteraction_CreatedDate]...';


GO
ALTER TABLE [dbo].[ProcessAsyncInteraction]
    ADD CONSTRAINT [DF_ProcessAsyncInteraction_CreatedDate] DEFAULT (getdate()) FOR [CreatedDate];


GO
PRINT N'Altering [dbo].[GetVCC]...';


GO
ALTER PROCEDURE [dbo].[GetVCC](
	@ID varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[VCC]							'vcc',
		[ID]							'id',
		[TYPE]							'type',
		[Description]					'description',
		[Country]						'country',
		[Language]						'language',
		[TimeZone]						'timeZone',
		[CreatedDate]					'createdDate',
		[CreatedByUserId]				'createdByUserId',
		[LastModifiedDate]				'lastModifiedDate',
		[LastModifiedByUserId]			'lastModifiedByUserId'
	FROM [VCC] (NOLOCK)
	WHERE [ID] = @ID

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetVCCs]...';


GO
ALTER PROCEDURE [dbo].[GetVCCs] (
	@VCC Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[ID]							'id',
		[Description]					'description',
		[Type]							'type',
		[Country]						'country',
		[Language]						'language',
		[TimeZone]						'timeZone',
		[CreatedDate]					'createdDate',
		[CreatedByUserId]				'createdByUserId',
		[LastModifiedDate]				'lastModifiedDate',
		[LastModifiedByUserId]			'lastModifiedByUserId'
	FROM [VCC] (NOLOCK)
	WHERE [VCC] <> 'system'
	AND [VCC] <> 'default'
	AND ISNULL([ID], '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
	AND ISNULL([Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
	AND ISNULL([Country], '') LIKE CASE WHEN @SearchCriteria = 'country' THEN '%' + @SearchExpression + '%' ELSE '%' END

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[SaveVcc]...';


GO
ALTER PROCEDURE [dbo].[SaveVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	
	UPDATE [VCC]
		SET [Description] = @Description,
			[Type] = @Type,
			[Country] = @Country,
			[Language] = @Language,
			[TimeZone] = @TimeZone,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[TimeStamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [ID] = @ID

    IF @@ROWCOUNT = 0
		INSERT INTO [VCC] (
			[VCC], [ID], [Description], [Type], [Country], 
			[Language], [TimeZone], [CreatedDate], [CreatedByUserId], [LastModifiedDate], 
			[LastModifiedByUserId], [TimeStamp]
			)
		VALUES (
			@VCC, @ID, @Description, @Type, @Country, 
			@Language, @TimeZone, @CreatedDate, @CreatedByUserId, @LastModifiedDate, 
			@LastModifiedByUserId, GETUTCDATE()
		)
		
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[BulkAudio]...';


GO
ALTER PROCEDURE [dbo].[BulkAudio]
AS
BEGIN
	-- EMULAMOS UNA NUEVA TABLA EN BASE A #AudioTemp DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	WITH CTE AS (
	   SELECT A.[VCC], A.[ID], A.[Section], A.[Part], A.[Number],
				A.[Gender], A.[SilenceTime], A.[DurationTime], A.[Category1], A.[Category2],
				A.[Category3], A.[Description], A.[Campaign], A.[Agent], A.[Type],
				A.[Init], A.[StartDate], A.[EndDate], A.[DispositionCode], A.[CreatedDate],
				A.[CreatedByUserId], A.[LastModifiedDate], A.[LastModifiedByUserId], RN = ROW_NUMBER() OVER(PARTITION BY A.[VCC], A.[ID], A.[Section], A.[Part] ORDER BY A.[ID])
	   FROM #AudioTemp A (NOLOCK)
	)
	-- LA TABLA TEMPORAL #AudioTemp LLEGA CON ALGUNOS REGISTROS DUPLICADOS DEBIDO A LOS CRUCES AL APLICAR LOR FILTROS, POR ELLO DEBEMOS 
	-- IDENTIFICAR LOS REPETIDOS, RN = ROW_NUMBER() OVER(PARTITION BY ...) <- NUMERA CADA REGISTRO SEGUN EL(LOS) VALOR(ES) DE ...

	-- EL CTE SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	--DELETE FROM CTE WHERE RN > 1

	INSERT INTO dbo.Audio(
			[VCC]
			,[ID]
			,[Section]
			,[Part]
			,[Number]
			,[Gender]
			,[SilenceTime]
			,[DurationTime]
			,[Category1]
			,[Category2]
			,[Category3]
			,[Description]
			,[Campaign]
			,[Agent]
			,[Type]
			,[Init]
			,[StartDate]
			,[EndDate]
			,[DispositionCode]
			,[CreatedDate]
			,[CreatedByUserId]
			,[LastModifiedDate]
			,[LastModifiedByUserId]
			,[TimeStamp]
			) 
		SELECT
			 A.[VCC]
			,A.[ID]
			,A.[Section]
			,A.[Part]
			,A.[Number]
			,A.[Gender]
			,A.[SilenceTime]
			,A.[DurationTime]
			,A.[Category1]
			,A.[Category2]
			,A.[Category3]
			,A.[Description]
			,A.[Campaign]
			,A.[Agent]
			,A.[Type]
			,A.[Init]
			,A.[StartDate]
			,A.[EndDate]
			,A.[DispositionCode]
			,A.[CreatedDate]
			,A.[CreatedByUserId]
			,A.[LastModifiedDate]
			,A.[LastModifiedByUserId]
			,GETUTCDATE()
		FROM CTE A (NOLOCK)
		WHERE A.RN = 1
			AND NOT EXISTS (
			SELECT * FROM Audio B (NOLOCK)
			WHERE B.[VCC] = A.[VCC]
			AND B.[ID] = A.[ID]
			AND B.[Section] = A.[Section]
			AND B.[Part] = A.[Part]
		);

	-- EMULAMOS UNA NUEVA TABLA EN BASE A #AudioTemp DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	WITH CTE_PAT AS (
	   SELECT PAT.[VCC], PAT.[ProcessId], PAT.[AudioId], PAT.[Section], PAT.[Part]
			,PAT.[CreatedDate], PAT.[CreatedByUserId], PAT.[LastModifiedDate], PAT.[LastModifiedByUserId], RN = ROW_NUMBER() OVER(PARTITION BY PAT.[VCC], PAT.[ProcessId], PAT.[AudioId], PAT.[Section], PAT.[Part] ORDER BY PAT.[AudioId])
	   FROM #ProcessAudioTemp PAT (NOLOCK)
	)
	-- EL CTE_PAT SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	--DELETE FROM CTE_PAT WHERE RN > 1
		
	-- Insertamos registros en la tabla ProcessAudio
	INSERT INTO dbo.ProcessAudio
			([VCC]
			,[ProcessId]
			,[AudioId]
			,[Section]
			,[Part]
			,[CreatedDate]
			,[CreatedByUserId]
			,[LastModifiedDate]
			,[LastModifiedByUserId]
			,[TimeStamp]
			) 
		SELECT
			 PAT.[VCC]
			,PAT.[ProcessId]
			,PAT.[AudioId]
			,PAT.[Section]
			,PAT.[Part]
			,PAT.[CreatedDate]
			,PAT.[CreatedByUserId]
			,PAT.[CreatedDate]
			,PAT.[CreatedByUserId]
			,GETUTCDATE()
		FROM CTE_PAT PAT (NOLOCK)
		WHERE PAT.RN = 1
			AND NOT EXISTS (
			SELECT * FROM ProcessAudio PA (NOLOCK)
			WHERE PA.[VCC] = PAT.[VCC]
			AND PA.[ProcessId] = PAT.[ProcessId]
			AND PA.[AudioId] = PAT.[AudioId]
			AND PA.[Section] = PAT.[Section]
			AND PA.[Part] = PAT.[Part]
		)
		GROUP BY 
			PAT.[VCC]
			,PAT.[ProcessId]
			,PAT.[AudioId]
			,PAT.[Section]
			,PAT.[Part]
			,PAT.[CreatedByUserId]
			,PAT.[CreatedDate]

		DROP TABLE #AudioTemp
		DROP TABLE #ProcessAudioTemp

END
GO
PRINT N'Altering [dbo].[BulkProcessInteraction]...';


GO

ALTER PROCEDURE [dbo].[BulkProcessInteraction]
AS
BEGIN
	-- ACTUALIZAMOS LOS AUDIOS CON EL RESULTADO EN LA TABLA
	UPDATE [dbo].[Audio] SET
		[dbo].[Audio].DurationLinguisticTime = [dbo].[#ProcessInteractionTemp].DurationLinguisticTime,
		[dbo].[Audio].IsTranscribed = [dbo].[#ProcessInteractionTemp].IsTranscribed,
		[dbo].[Audio].IsCancel = [dbo].[#ProcessInteractionTemp].IsCancel,
		[dbo].[Audio].[FileName] = [dbo].[#ProcessInteractionTemp].[FileName],
		[dbo].[Audio].[ErrorMessage] = [dbo].[#ProcessInteractionTemp].[ErrorMessage],
		[dbo].[Audio].LastModifiedDate = GETUTCDATE()
	FROM [dbo].[#ProcessInteractionTemp]
	WHERE
		[dbo].[Audio].VCC = [dbo].[#ProcessInteractionTemp].VCC
		AND [dbo].[Audio].ID = [dbo].[#ProcessInteractionTemp].ID
		AND [dbo].[Audio].Section = [dbo].[#ProcessInteractionTemp].Section
		AND [dbo].[Audio].Part = [dbo].[#ProcessInteractionTemp].Part
		AND [dbo].[#ProcessInteractionTemp].[Channel] = 'CALL'

	-- ACTUALIZAMOS LOS TEXT CON EL RESULTADO DE LA TABLA
	UPDATE [dbo].[AsyncInteraction] 
		SET [dbo].[AsyncInteraction].IsTranscribed = [dbo].[#ProcessInteractionTemp].IsTranscribed,
			[dbo].[AsyncInteraction].IsCancel = [dbo].[#ProcessInteractionTemp].IsCancel,
			[dbo].[AsyncInteraction].[FileName] = [dbo].[#ProcessInteractionTemp].[FileName],
			[dbo].[AsyncInteraction].[ViewFileName] = [dbo].[#ProcessInteractionTemp].[ViewFileName],
			[dbo].[AsyncInteraction].[ErrorMessage] = [dbo].[#ProcessInteractionTemp].[ErrorMessage],
			[dbo].[AsyncInteraction].LastModifiedDate = GETUTCDATE()
	FROM [dbo].[#ProcessInteractionTemp]
	WHERE [dbo].[AsyncInteraction].[VCC] = [dbo].[#ProcessInteractionTemp].VCC
		AND [dbo].[AsyncInteraction].Campaign = [dbo].[#ProcessInteractionTemp].[Campaign]
		AND [dbo].[AsyncInteraction].Channel = [dbo].[#ProcessInteractionTemp].[Channel]
		AND [dbo].[AsyncInteraction].ID = [dbo].[#ProcessInteractionTemp].ID
		AND [dbo].[AsyncInteraction].Folder = [dbo].[#ProcessInteractionTemp].Folder

	DROP TABLE [dbo].[#ProcessInteractionTemp]
END
GO
PRINT N'Altering [dbo].[FinishedBatchClose]...';


GO
ALTER PROCEDURE [dbo].[FinishedBatchClose](
	@VCC VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET NOCOUNT ON

	-- VERIFICAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
	IF @VCC IS NULL OR @BatchTypeName IS NULL OR @BatchTypeId IS NULL
		-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
		RAISERROR('DATABABASE_ERROR_MISSING_PARAMETERS', 16, 16)

	--SELECT * FROM [dbo].[Batch] 
	UPDATE [dbo].[Batch] 
		SET [FinishReported] = 1
		WHERE [VCC] = @VCC
			AND [BatchTypeName] = @BatchTypeName 
			AND [BatchTypeId] = @BatchTypeId

	-- SEGUN EL BATCHTYPENAME ACTUALIZAMOS EL STATUS DE LA TABLA DEL BATCH
	IF @BatchTypeName = 'TRANSCRIPTION'
	BEGIN
		UPDATE [dbo].[Process] 
			SET [Status] = 'COMPLETE'
			WHERE [VCC] = @VCC
				AND [Name] = @BatchTypeId
	END
	ELSE IF @BatchTypeName = 'STUDY'
	BEGIN
		UPDATE [dbo].[Study] 
			SET [Status] = 'COMPLETED'
			WHERE [VCC] = @VCC
				AND [Name] = @BatchTypeId
	END
	ELSE IF @BatchTypeName = 'EVALUATION_PLAN'
	BEGIN 
		UPDATE [dbo].[EvaluationPlan] 
			SET [StatusDescription] = 'COMPLETED'
			WHERE [Instance] = @VCC
				AND [ID] = @BatchTypeId
	END

	SELECT 1 'result'

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetAllegroBillingInteractions]...';


GO
-- ESTE SP RETORNA UN RESUMEN DE LA BUSQUEDA DE INTERACCIONES DE ALLEGRO PARA INDETIFICAR LOS YA TRANSCRITOS O INPROCESS SEGUN LOS FILTROS RECIBIDOS 
-- FUNCIONA IGUAL QUE LA FUNCION EN KNEX
ALTER PROCEDURE [dbo].[GetAllegroBillingInteractions] (
   	@VCC VARCHAR(50) = NULL,
	@IP VARCHAR(50), 
	@Type INT,
	@SecondsPerRequest DECIMAL(18, 5),
   	@StartDate DATETIME = '1980-01-01T00:00:00',
    @EndDate DATETIME = '2050-01-01T23:59:59',
	@Campaigns VARCHAR(MAX) = '',
 	@Agents VARCHAR(MAX) = '',
   	@Origins VARCHAR(100) = NULL,
	@StartHour VARCHAR(50) = NULL,
	@EndHour VARCHAR(50) = NULL,
	@MinDuration INT = 0,
    @MaxDuration INT = 100000,
    @Results VARCHAR(MAX) = NULL,
	@Formats VARCHAR(50) = NULL
)
AS 
BEGIN 
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOASUN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @INTERACTION_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_ACTOR_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_MULTIMEDIA_PARTS_TABLE NVARCHAR(100)
	DECLARE @CAMPAIGN_GOAL_RESULT_MANAGEMENT_TABLE NVARCHAR(100)

	-- SETTEAMOS LOS VALORES DE DURACION MINIMA Y MAXIMA A UNO VALIDO
	IF @MinDuration = @MaxDuration AND @MaxDuration = 0 SET @MaxDuration = 100000
	IF @MinDuration IS NULL SET @MinDuration = 0
	IF @MaxDuration IS NULL SET @MaxDuration = 100000

	-- EL PARAMETRO TYPE DEFINE SI LA BD ALLEGRO SE ENCUENTRA LOCAL O REMOTO
	IF (@Type = 0)  
	BEGIN  
		SET @INTERACTION_DETAIL_TABLE = '[' + @Ip + ']' + '.HistoricalData.dbo.[InteractionDetail]'
		SET @INTERACTION_ACTOR_DETAIL_TABLE = '[' + @Ip + ']' + '.HistoricalData.dbo.[InteractionActorDetail]'
		SET @INTERACTION_MULTIMEDIA_PARTS_TABLE = '[' + @Ip + ']' + '.HistoricalData.dbo.[InteractionMultimediaParts]'
		SET @CAMPAIGN_GOAL_RESULT_MANAGEMENT_TABLE = '[' + @Ip + ']' + '.mmprodat.dbo.[CampaignGoalResultManagement]'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @INTERACTION_DETAIL_TABLE = 'HistoricalData.dbo.[InteractionDetail]';
		SET @INTERACTION_ACTOR_DETAIL_TABLE = 'HistoricalData.dbo.[InteractionActorDetail]'
		SET @INTERACTION_MULTIMEDIA_PARTS_TABLE = 'HistoricalData.dbo.[InteractionMultimediaParts]';
		SET @CAMPAIGN_GOAL_RESULT_MANAGEMENT_TABLE = 'mmprodat.dbo.[CampaignGoalResultManagement]';
	END  

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN 1 ELSE 0 END) ''alreadyTranscribedAudio'',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN ID.[AttentionTime] ELSE 0 END) ''alreadyTranscribedDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL) THEN 1 ELSE 0 END) ''inProcessAudio'',
				SUM(CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL) THEN ID.[AttentionTime] ELSE 0 END) ''inProcessDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)) THEN 1 ELSE 0 END) ''notTranscribedAudio'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)) THEN ID.[AttentionTime] ELSE 0 END) ''notTranscribedDurationTime'',
				SUM(ID.[AttentionTime] / ' + (SELECT CONVERT(varchar(10), @SecondsPerRequest)) + ') ''averageModelRequest'' 
			'
				
	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM ' + @INTERACTION_MULTIMEDIA_PARTS_TABLE + ' IMP (NOLOCK)
			LEFT JOIN ' + @INTERACTION_DETAIL_TABLE + ' ID (NOLOCK) 
				ON ID.[Id] = IMP.[Id]
			LEFT JOIN ' + @INTERACTION_ACTOR_DETAIL_TABLE + ' IAD (NOLOCK) 
				ON IAD.[Id] = ID.[id]
			LEFT JOIN [dbo].[Audio] A (NOLOCK) 
				ON A.[ID] = ID.[Id]
					AND A.[Section] = IMP.[Section]
					AND A.[Part] = IMP.[Part] 
			'

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE ID.[VirtualCC] = ''' + @VCC + '''
				AND ID.[Id] IS NOT NULL 
				AND ID.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND ID.[AttentionTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' 
				'
	
	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') SET @SQL_FILTER += 'AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND IAD.[Actor] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	IF (@Origins IS NOT NULL AND @Origins != '') SET @SQL_FILTER += 'AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	IF (@Results IS NOT NULL AND @Results != '') SET @SQL_FILTER += 'AND ID.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @Results + ''','','')) ';
	IF (@Formats IS NOT NULL AND @Formats != '') SET @SQL_FILTER += 'AND IMP.[Format] IN (SELECT Value FROM [dbo].[split](''' + @Formats + ''','','')) ';
	
	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(ID.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(ID.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END
	
	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	-- EJECUTAMOS LA CONSULTA
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Altering [dbo].[GetAllegroFilterInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetAllegroFilterInteractions]
(
	@Ip						VARCHAR(50),
	@VCC					VARCHAR(50),
	@StartDate				DATETIME = '1980-01-01T00:00:00',
	@EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@Campaign				NVARCHAR(MAX),
	@Agent					NVARCHAR(MAX),
	@ResultCode				NVARCHAR(MAX),
	@Type					INT,
	@Origin					NVARCHAR(MAX),
	@MinDuration			Int,
	@MaxDuration			Int
)
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS CADENAS PARA EL QUERY FINAL
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	
	DECLARE @Sql NVARCHAR(MAX)

	-- CREAMOS LAS VARIABLES QUE HARAN REFERENCIA A LAS TABLAS QUE PUEDEN SER EXTERNAS
	DECLARE @TblHistoricalDataRef NVARCHAR(50) = '';
	DECLARE @TblMmprodataRef NVARCHAR(50) = '';

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@Type = 0)  
	BEGIN  
		SET @TblHistoricalDataRef = '[' + @Ip + ']' + '.[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TblHistoricalDataRef = '[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[MMProDat].[dbo].'
	END


	IF(@Type = 0 OR @Type = 1)  
	BEGIN  
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA DE RESUMEN
		SET @SQL_SELECT_0 += '
			SET NOCOUNT ON
			SELECT COUNT(DISTINCT ID.[Id])								''totalInteractions'',
					COUNT(*)											''totalAudios'',
					SUM(ID.[AttentionTime])								''totalAttentionTime'' 
				'

		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA DE CONTENIDO
		SET @SQL_SELECT_1 += '
			SET NOCOUNT ON
			SELECT ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)			''ID'',
					CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''Number'',
					''''																									''Gender'',
					ID.[HoldTime]																							''SilenceTime'',
					ID.[AttentionTime]																						''DurationTime'', -- ESTO SE DEBE CORREGIR
					ID.[AttentionTime]																						''AttentionTime'', -- SE AGREGO CAMPO PARA AMBOS EXISTAN
					ISNULL(CGRM.[Category1], '''')																			''Category1'',
					ISNULL(CGRM.[Category2], '''')																			''Category2'',
					ISNULL(CGRM.[Category3], '''')																			''Category3'',
					ISNULL(CGRM.[Description], '''')																		''Description'',
					ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')															''DispositionCode'',
					ID.[Campaign]																							''Campaign'',
					ID.[LastAgent]																							''Agent'',
					ID.[Direction]																							''Type'',
					CONVERT(VARCHAR, ID.[StartDate], 120)																	''StartDate'',
					CONVERT(VARCHAR, ID.[EndDate], 120)																		''EndDate'' 
				'
		-- ARMAMOS LA PARTE DE TABLAS 
		SET @SQL_FROM += '
				FROM ' + @TblHistoricalDataRef + '[InteractionMultimediaParts] IMP (NOLOCK)
				LEFT JOIN ' + @TblHistoricalDataRef + '[InteractionDetail] ID (NOLOCK) 
					ON ID.Id = IMP.Id
				LEFT JOIN (
					SELECT TOP 1 VCC, CampaignID, [Order], [Code], 
									[Description], Category1, Category2, Category3 
						FROM ' + @TblMmprodataRef + '[CampaignGoalResultManagement] (NOLOCK)
				) CGRM  
					ON CGRM.VCC = ID.VirtualCC 
						AND CGRM.CampaignId = ID.Campaign 
						AND CGRM.[Description] = ID.ManagementResult
				INNER JOIN ' + @TblHistoricalDataRef + '[CallInteractionDetail] CID (NOLOCK) 
					ON ID.Id = CID.Id 
				'

		-- ARMAMOS LA PARTE BASE DE FILTROS
		SET @SQL_FILTER += '
				WHERE ID.[VirtualCC] = ''' + @VCC + '''
					AND ID.Id IS NOT NULL
					AND id.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + '''
					AND IMP.[Format] in (''mp3'', ''wav'')
					'

		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @SQL_FILTER += 'AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @SQL_FILTER += 'AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
		IF(@Campaign IS NOT NULL AND @Campaign <> '') SET @SQL_FILTER += 'AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) ';

		IF(@Agent IS NOT NULL AND @Agent <> '') SET @SQL_FILTER += 'AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) ';

		IF(@Origin IS NOT NULL AND @Origin <> '') SET @SQL_FILTER += 'AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) ';

		IF(@MinDuration IS NOT NULL) SET @SQL_FILTER += 'AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' ';

		IF(@MaxDuration IS NOT NULL) SET @SQL_FILTER += 'AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' ';

		IF(@ResultCode IS NOT NULL AND @ResultCode <> '') SET @SQL_FILTER += 'AND CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','','')) '

		SET @SQL_EXTRA = '
			SET NOCOUNT OFF '

		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT_0 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
		SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

		-- EJECUTAMOS LA CONSULTA
		EXEC (@SQL_SELECT_0)
		EXEC (@SQL_SELECT_1)
	END
	ELSE
	BEGIN
		SET @Sql = 'SELECT 1 AS ''result'''
		EXEC (@Sql)
	END

	

	

	/*
	SET @Sql = ''

	IF(@Type = 0 OR @Type = 1)  
	BEGIN  
		SET @Sql = 'SET NOCOUNT ON
		SELECT
			ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)			''ID'',
			CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''Number'',
			''''																									''Gender'',
			ID.[HoldTime]																							''SilenceTime'',
			ID.[AttentionTime]																						''DurationTime'', -- ESTO SE DEBE CORREGIR
			ID.[AttentionTime]																						''AttentionTime'', -- SE AGREGO CAMPO PARA AMBOS EXISTAN
			ISNULL(CGRM.[Category1], '''')																			''Category1'',
			ISNULL(CGRM.[Category2], '''')																			''Category2'',
			ISNULL(CGRM.[Category3], '''')																			''Category3'',
			ISNULL(CGRM.[Description], '''')																		''Description'',
			ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')															''DispositionCode'',
			ID.[Campaign]																							''Campaign'',
			ID.[LastAgent]																							''Agent'',
			ID.[Direction]																							''Type'',
			CONVERT(VARCHAR, ID.[StartDate], 120)																	''StartDate'',
			CONVERT(VARCHAR, ID.[EndDate], 120)																		''EndDate''
		FROM ' + @TblHistoricalDataRef + '[InteractionMultimediaParts] IMP (NOLOCK)
		LEFT JOIN ' + @TblHistoricalDataRef + '[InteractionDetail] ID (NOLOCK) 
			ON ID.Id = IMP.Id
		LEFT JOIN (
			SELECT TOP 1 VCC, CampaignID, [Order], [Code], 
							[Description], Category1, Category2, Category3 
				FROM ' + @TblMmprodataRef + '[CampaignGoalResultManagement] (NOLOCK)
		) CGRM  
			ON CGRM.VCC = ID.VirtualCC 
				AND CGRM.CampaignId = ID.Campaign 
				AND CGRM.[Description] = ID.ManagementResult
		INNER JOIN ' + @TblHistoricalDataRef + '[CallInteractionDetail] CID (NOLOCK) 
			ON ID.Id = CID.Id
		WHERE ID.[VirtualCC] = ''' + @VCC + '''
			AND ID.Id IS NOT NULL
			AND ID.[EndDate] >= ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + '''
			AND ID.[EndDate] <= ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
			AND IMP.[Format] in (''mp3'', ''wav'') '
		
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @Sql += 'AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @Sql += 'AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
		IF(@Campaign IS NOT NULL AND @Campaign <> '')
		SET @Sql += 'AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) ';

		IF(@Agent IS NOT NULL AND @Agent <> '')
		SET @Sql += 'AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) ';

		IF(@Origin IS NOT NULL AND @Origin <> '')
		SET @Sql += 'AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) ';

		IF(@MinDuration IS NOT NULL)
		SET @Sql += 'AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' ';

		IF(@MaxDuration IS NOT NULL)
		SET @Sql += 'AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' ';

		IF(@ResultCode IS NOT NULL AND @ResultCode <> '')
		SET @Sql += '
		AND CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','',''))'

 		SET @Sql += '
		SET NOCOUNT OFF '
	END
	ELSE
	BEGIN
		SET @Sql = 'SELECT 1 AS ''result'''
	END

	EXEC (@Sql)
	*/
END
GO
PRINT N'Altering [dbo].[GetAllegroSummaryInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetAllegroSummaryInteractions]
(
	@Ip						VARCHAR(50),
	@VCC					VARCHAR(50),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				VARCHAR(50),
	@EndHour				VARCHAR(50),
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					Int,
	@TypeInteraction		VARCHAR(MAX),
	@Origin					VARCHAR(MAX),
	@MinDuration			Int,
	@MaxDuration			Int,
	@EvaluationFormat		VARCHAR(50) = NULL,
	@Format					VARCHAR(50) = NULL
)
AS
BEGIN

	DECLARE @Sql NVARCHAR(MAX)

	-- SETTEAMOS UN VALOR POR DEFECTO AL FORMAT
	IF @Format IS NULL SET @Format = 'mp3, wav'

	-- CREAMOS LAS VARIABLES QUE HARAN REFERENCIA A LAS TABLAS QUE PUEDEN SER EXTERNAS
	DECLARE @TblHistoricalDataRef NVARCHAR(50) = '';
	DECLARE @TblMmprodataRef NVARCHAR(50) = '';

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@Type = 0)  
	BEGIN  
		SET @TblHistoricalDataRef = '[' + @Ip + ']' + '.[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TblHistoricalDataRef = '[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[MMProDat].[dbo].'
	END

	SET @Sql = ''

	
	-- SE ARMA EL QUERY PRINCIPAL PARA LA BUSQUEDA DE INTERACCIONES Y TIEMPO TOTAL
	SET @Sql = 'SELECT ISNULL(COUNT(DISTINCT ID.[Id]), 0)								''totalInteraction'',	--TOTAL DE INTEACCIONES
						ISNULL(COUNT(*), 0)												''quantity'',			-- TOTAL DE AUDIOS
						ISNULL(SUM(ID.[AttentionTime]), 0)								''timeQuantity'',		-- TIEMPO TOTAL DE LOS AUDIOS
						ISNULL(dbo.[ConvertHourMin](SUM(ID.[AttentionTime])), 0)		''time''				-- TIEMPO TOTAL DE LOS AUDIOS EN FORMATO HH:MM:SS
		FROM  ' + @TblHistoricalDataRef + '[InteractionMultimediaParts] IMP (NOLOCK)
		LEFT JOIN ' + @TblHistoricalDataRef + '[InteractionDetail] ID (NOLOCK) 
			ON ID.[Id] = IMP.[Id]
		LEFT JOIN (SELECT TOP 1 VCC, [CampaignID], [Order], [Code], [Description], [Category1], [Category2], [Category3 ]
					FROM ' + @TblMmprodataRef + '[CampaignGoalResultManagement] (NOLOCK)) CGRM  
			ON CGRM.[VCC] = ID.[VirtualCC] 
				AND CGRM.[CampaignId] = ID.[Campaign] 
				AND CGRM.[Description] = ID.[ManagementResult] 
		WHERE ID.[VirtualCC] = ''' + @VCC + '''
			AND ID.Id IS NOT NULL
			AND ID.[EndDate] >= ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + '''
			AND ID.[EndDate] <= ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
			-- AND IMP.[Format] in (''mp3'', ''wav'') 
			AND IMP.[Format] IN (SELECT Value FROM [dbo].[split](''' + @Format + ''','','')) '
		
	IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
		SET @Sql += '
			AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
	
	IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
		SET @Sql += '
			AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
	IF(@Campaign IS NOT NULL AND @Campaign <> '') 
		SET @Sql += '
			AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) ';

	IF(@Agent IS NOT NULL AND @Agent <> '') 
		SET @Sql += '
			AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) ';

	IF(@Origin IS NOT NULL AND @Origin <> '') 
		SET @Sql += '
			AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) ';

	IF(@MinDuration IS NOT NULL) 
		SET @Sql += '
			AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' ';

	IF(@MaxDuration IS NOT NULL) 
		SET @Sql += '
			AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' ';

	IF(@ResultCode IS NOT NULL AND @ResultCode <> '')
		SET @Sql += ' 
			AND CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','',''))'

 	-- ARMAMOS EL QUERY FINAL PARA LOS RESULTADOS
	--SET @Sql = 'select count(HDD.Id) as ''quantity'',
	--					dbo.[ConvertHourMin](SUM(HDD.AttentionTime)) as ''time'' 
	--				from (' + @Sql + ') HDD '

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@TblHistoricalDataRef = '')  
	BEGIN
		-- SI SE TRATA DE UN TYPE DESCONOCIDO SE ENVIA UN RESULT 1
		SET @Sql = 'SELECT 1 AS ''result'''  
	END

	SET @Sql = 'SET NOCOUNT ON 
		' + @Sql + ' 
		SET NOCOUNT OFF'

	-- EJECUTAMOS LA CONSULTA
	-- SELECT @Sql

	EXEC (@Sql)
END
GO
PRINT N'Altering [dbo].[GetAudiosProcess]...';


GO
-- [dbo].[GetAudiosProcess] 5, 1, 'allegro', 'proceso1', '', '2019-04-11 00:00:00.000', '2019-06-06 04:59:59.997', 22, 26, 23, 59, 'entrantes,PruebasJair,VideoCall', 'icagente', NULL, 'allegro', '', ''
ALTER PROCEDURE [dbo].[GetAudiosProcess]
(
	@PageSize				INT,
	@PageNumber				INT,
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@ID						VARCHAR(250),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				INT,
	@StartMinute			INT,
	@EndHour				INT,
	@EndMinute				INT,
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					VARCHAR(50),
	@IdathaResults			NVARCHAR(MAX),
	@TotalIdathaResults		INT,
	@InteractionType		VARCHAR(50),
	@Folder					VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- DEFINIMOS UNA TABLE TEMPORAL PARA DEPOSITAR LA TODOS LAS INTERACCIONES DEL PROCESS
	CREATE TABLE #PROCESS_INTERACTIONS(
		vcc VARCHAR(50),
		interactionType VARCHAR(100),
		id VARCHAR(250),
		section VARCHAR(100),
		part VARCHAR(100),
		processId VARCHAR(100),
		number VARCHAR(100),
		name VARCHAR(100),
		silenceTime INT,
		durationTime INT,
		durationLinguisticTime INT,
		category1 VARCHAR(100),
		category2 VARCHAR(100),
		category3 VARCHAR(100),
		agent VARCHAR(100),
		description VARCHAR(100),
		environment VARCHAR(100),
		isTranscribed VARCHAR(100),
		createdDate DATETIME,
		endDate DATETIME,
		campaign VARCHAR(50),
		dispositionCode VARCHAR(250),
		folder VARCHAR(50)
	)

	-- INSERTAMOS LOS REGISTROS CALL
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT A.[VCC]						'vcc',
				'CALL'						'interactionType',
				A.[ID]						'id',
				A.[Section]					'section',
				A.[Part]					'part',
				PA.[ProcessId]				'processId',
				A.[Number]					'number',
				P.[Name]					'name',
				A.[SilenceTime]				'silenceTime',
				A.[DurationTime]			'durationTime',
				A.[DurationLinguisticTime]	'durationLinguisticTime',
				A.[Category1]				'category1',
				A.[Category2]				'category2',
				A.[Category3]				'category3',
				A.[Agent]					'agent',
				A.[Description]				'description',
				P.[Environment]				'environment',
				A.[IsTranscribed]			'isTranscribed',
				A.[CreatedDate]				'createdDate',
				A.[EndDate]					'endDate',
				A.[Campaign]				'campaign',
				A.[DispositionCode]			'dispositionCode',
				NULL						'folder'
			FROM [dbo].[Audio] A (NOLOCK)
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON A.ID = PA.AudioId 
					AND A.Section = PA.Section 
					AND A.Part = PA.Part
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON PA.[ProcessId] = P.[Name]
			WHERE A.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'

	-- INSERTAMOS LOS REGISTROS DE INTERACCIONES DE OTROS CANALES
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT AI.[VCC]						'vcc',
				AI.[Channel]				'interactionType',
				AI.[ID]						'id',
				NULL						'section',
				NULL						'part',
				PAI.[ProcessId]				'processId',
				NULL						'number',
				PAI.[ProcessId]				'name',
				NULL						'silenceTime',
				NULL						'durationTime',
				NULL						'durationLinguisticTime',
				NULL						'category1',
				NULL						'category2',
				NULL						'category3',
				NULL						'agent',
				NULL						'description',
				NULL						'environment',
				AI.[IsTranscribed]			'isTranscribed',
				AI.[CreatedDate]			'createdDate',
				AI.[EndDate]				'endDate',
				AI.[Campaign]				'campaign',
				AI.[DispositionTreePath]	'dispositionCode',
				AI.[Folder]					'folder'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
					--AND AI.[Campaign] = PAI.[Campaign]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON P.[Name] = PAI.[ProcessId]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
		
	-- DECLARAMOS VARIABLE PARA LA CONSULTA ACUMULADA QUE LANZAREMOS
	DECLARE @SQL NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE_IDATHA NVARCHAR(MAX) = ''
	
	SET @SQL_WHERE = ''
	SET @SQL_WHERE_IDATHA = ''

	-- HACEMOS EL PRIMER QUERY PARA SACAR EL NUMERO DE REGISTROS DEL PROCESS
	SET @SQL = ' SET NOCOUNT ON
	DECLARE @rows INT
	DECLARE @SYNC_INTERACTIONS INT
	DECLARE @ASYNC_INTERACTIONS INT
	DECLARE @maxDurationTime Numeric(12,3)

	SELECT @SYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] = ''CALL''
	SELECT @ASYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] <> ''CALL''
	SELECT @maxDurationTime = MAX([durationTime]) FROM #PROCESS_INTERACTIONS 
	'

	SET @SQL += '
		SET @rows = (
			SELECT COUNT(PI.[id])
				FROM #PROCESS_INTERACTIONS PI (NOLOCK)
				WHERE PI.[vcc] = ''' + @VCC + ''' 
					'
	IF (@ProcessId IS NOT NULL) 
			SET @SQL += 'AND PI.[ProcessId]= ''' + @ProcessId + ''' 
						'

	IF(@Type = 'query')
	BEGIN
		SET @SQL_WHERE_IDATHA += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) IN (''' + @IdathaResults + '''))
						OR (PI.[id] IN (''' + @IdathaResults + ''')))
					'
	
		SET @SQL += @SQL_WHERE_IDATHA

	END
	ELSE IF(@Type = 'allegro' OR @Type = 'ftp' OR @Type = 'sftp' OR @Type = 'fileSystem')
	BEGIN
		IF (@ID IS NOT NULL) 
			SET @SQL_WHERE += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) LIKE ''%' + @ID + '%'')
						OR (PI.[id] = ''' + @ID + '''))
					'
		
		IF (@Campaign IS NOT NULL AND LEN(@Campaign) > 0) 
			SET @SQL_WHERE += 'AND PI.[campaign] IN (''' + @Campaign + ''')
						'
		
		IF (@Agent IS NOT NULL AND LEN(@Agent) > 0) 
			SET @SQL_WHERE += 'AND (PI.[agent] IN (''' + @Agent + '''))
							OR (PI.[agent] IS NULL)
						'
		
		IF (@ResultCode IS NOT NULL AND LEN(@ResultCode) > 0) 
			SET @SQL_WHERE += 'AND (CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), '''')) IN (''' + @ResultCode + '''))
							OR (PI.[dispositionCode] IN (''' + @ResultCode + ''')) '
		
		IF (@InteractionType IS NOT NULL AND LEN(@InteractionType) > 0) 
			SET @SQL_WHERE += 'AND PI.[interactionType] = ''' + @InteractionType + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 
			SET @SQL_WHERE += 'AND PI.[folder] = ''' + @Folder + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 

		IF (@StartDate IS NOT NULL AND @EndDate IS NOT NULL) 
			SET @SQL_WHERE += 'AND PI.[endDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' 
						AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
						'
		
		IF (@StartHour IS NOT NULL AND @EndHour IS NOT NULL) 
			SET @SQL_WHERE += 'AND DATEPART(HOUR, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartHour) + ' 
						AND DATEPART(HOUR, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndHour) + '
						'
		
		IF (@StartMinute IS NOT NULL AND @EndMinute IS NOT NULL) 
			SET @SQL_WHERE += 'AND DATEPART(MINUTE, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartMinute) + ' 
						AND DATEPART(MINUTE, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndMinute) + '
						'
		
	END

	SET @SQL += @SQL_WHERE
	SET @SQL += ') '
	SET @SQL += 'SELECT @rows AS total, 
						@maxDurationTime AS maxDurationTime,
						@ASYNC_INTERACTIONS AS asyncDetails, 
						@SYNC_INTERACTIONS AS audios'
		
	SET @SQL += '
		SELECT PI.[interactionType],
				PI.[id],
				PI.[section],
				PI.[part],
				PI.[processId],
				PI.[folder],
				PI.[campaign],
				PI.[number],
				PI.[name],
				PI.[silenceTime],
				PI.[durationTime],
				PI.[durationLinguisticTime],
				PI.[category1],
				PI.[category2],
				PI.[category3],
				PI.[agent],
				PI.[description],
				PI.[environment],
				PI.[isTranscribed],
				PI.[createdDate],
				PI.[endDate]
			FROM #PROCESS_INTERACTIONS PI
			WHERE PI.[vcc] = ''' + @VCC + ''' 
				'

	IF(@ProcessId IS NOT NULL) SET @SQL += 'AND PI.[processId] = ''' + @ProcessId + ''' '
			
	SET @SQL += ' '

	SET @SQL += @SQL_WHERE
	SET @SQL += @SQL_WHERE_IDATHA
	SET @SQL += 'ORDER BY PI.[ID], 
						PI.[ProcessId], 
						PI.[Agent], 
						PI.[Description], 
						PI.[Environment], 
						PI.[DurationTime], 
						PI.[CreatedDate]
			OFFSET ' + CONVERT(VARCHAR(50), @PageSize) + ' * (' + CONVERT(VARCHAR(50), @PageNumber) + ' - 1) ROWS
			FETCH NEXT ' + CONVERT(VARCHAR(50), @PageSize) + ' ROWS ONLY
			'

	SET @SQL += ' SET NOCOUNT OFF'
	--print @SQL
	EXEC(@SQL)
	
	DROP TABLE #PROCESS_INTERACTIONS
END
GO
PRINT N'Altering [dbo].[GetInteractionsResult]...';


GO
ALTER PROCEDURE [dbo].[GetInteractionsResult]
(
	@VCC				VARCHAR(50),
	@ProcessId			VARCHAR(50),
	@Channels			VARCHAR(100)
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS UN QUERY DEPENDIENDO DEL CANAL
	IF @Channels = 'CALL' 
	BEGIN
		-- HACEMOS LA BUSQUEDA PARA LAS INTERACCIONES SINCRONAS(CALL)
		SELECT 'CALL'																'interactionType', 
				COUNT(DISTINCT CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]))		'quantity',
				SUM(A.[DurationTime])												'timeQuantity',
				COUNT(DISTINCT A.[ID])												'totalSyncInteractions'
				--COUNT(DISTINCT A.[ID])												'timeQuantity'
			FROM [dbo].[Process] P (NOLOCK)
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK)
				ON PA.[ProcessId] = P.[Name]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
				ON A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE P.[VCC] = @VCC
				AND P.[Name] = @ProcessId

	END
	ELSE 
	BEGIN
		-- HACEMOS LA BUSQUEDA PARA LAS INTERACCIONES SINCRONAS(OTROS CANALES)
		SELECT PAI.[InteractionType]												'interactionType',
				COUNT(DISTINCT CONCAT(PAI.[InteractionId], PAI.[EndDate]))			'totalInteractionDetails',
				COUNT(DISTINCT PAI.[InteractionId])									'totalInteractions'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK) 
			WHERE PAI.[VCC] = @VCC 
				AND PAI.[ProcessId] = @ProcessId
				AND PAI.[InteractionType] IN (SELECT VALUE FROM [dbo].[split](@Channels, ','))
			GROUP BY PAI.[InteractionType]
	END

	/* -- ESTA FUNCION RETORNA SOLO EL TOTAL Y TIEMPO DE LOS AUDIOS QUE NO HAN SIDO TRANSCRITOS
	SELECT
		COUNT(PA.[AudioId])						'interactionsTotal',
		ISNULL(SUM(A.[DurationTime]), 0)		'timeInSeconds'
	FROM ProcessAudio PA (NOLOCK)
	INNER JOIN Audio A (NOLOCK) 
		ON CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part]) = CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) 
			AND PA.[VCC] = A.[VCC]
	WHERE
		PA.[VCC] = @VCC
		AND [ProcessId] = @ProcessId
		AND A.[IsTranscribed] IS NULL
	*/
	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetProcessInteractionsHistory]...';


GO
ALTER PROCEDURE [dbo].[GetProcessInteractionsHistory](
	@VCC		VARCHAR(50),
	@ProcessId	VARCHAR(50),
	@SecondsPerRequest DECIMAL(18, 5) = 1
) AS
BEGIN
	SET NOCOUNT ON

	BEGIN

		-- RECUPERAMOS LA INFORMACION DE LOS AUDIOS DEL PROCESS QUE YA HAN SIDO TRANSCRITOS 
		SELECT 'CALL'																															'interactionType',
				COUNT(*)																														'totalAudio',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN 1 ELSE 0 END)																			'alreadyTranscribedAudio',
				SUM(CASE WHEN A.[IsCancel] = 1 THEN 1 ELSE 0 END)																				'alreadyCanceledAudio',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN A.[DurationTime] ELSE 0 END)															'alreadyTranscribedDurationTime',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN (CEILING(A.[DurationTime] / 60) * 60) ELSE 0 END)										'alreadyTranscribedRoundedDurationTime',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN A.[DurationLinguisticTime] ELSE 0 END)													'alreadyTranscribedValidDurationTime',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN (CEILING(A.[DurationLinguisticTime] / 60) * 60) ELSE 0 END)							'alreadyTranscribedRoundedValidDurationTime',
				SUM(CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL) THEN 1 ELSE 0 END)						'inProcessAudio',
				SUM(CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL) THEN A.[DurationTime] ELSE 0 END)		'inProcessDurationTime',
				SUM(CASE WHEN (A.[IsProcess] IS NULL OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)) THEN 1 ELSE 0 END)							'notTranscribedAudio',
				SUM(CASE WHEN (A.[IsProcess] IS NULL OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)) THEN A.[DurationTime] ELSE 0 END)				'notTranscribedDurationTime',
				SUM(A.[DurationTime] / @SecondsPerRequest)																						'averageModelRequest'
			FROM [dbo].[ProcessAudio] PA (NOLOCK)
			LEFT JOIN [dbo].[Audio] A (NOLOCK) 
				ON A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE PA.[VCC] = @VCC
				AND PA.[ProcessID] = @ProcessId
				-- AND A.[IsTranscribed] = 1 
				-- AND ISNULL(A.[IsProcess], 0) = 0

		SELECT PAI.[InteractionType]																											'interactionType',
				COUNT(*)																														'totalAsyncInteraction',
				SUM(CASE WHEN AI.[IsTranscribed] = 1 THEN 1 ELSE 0 END)																			'alreadyTranscribedAsyncInteraction',
				SUM(CASE WHEN AI.[IsCancel] = 1 THEN 1 ELSE 0 END)																				'alreadyCanceledAsyncInteraction',
				SUM(CASE WHEN AI.[IsTranscribed] = 1 THEN AI.[RawChar] ELSE 0 END)																'alreadyTranscribedRawChar',
				SUM(CASE WHEN AI.[IsTranscribed] = 1 THEN AI.[ValidChar] ELSE 0 END)															'alreadyTranscribedValidChar',
				SUM(CASE WHEN (AI.[IsProcess] = 1 AND AI.[IsTranscribed] IS NULL AND AI.[IsCancel] IS NULL) THEN 1 ELSE 0 END)					'inProcessAsyncInteraction',
				SUM(CASE WHEN AI.[IsProcess] = 1 THEN AI.[RawChar] ELSE 0 END)																	'alreadyTranscribedRawChar',
				SUM(CASE WHEN (AI.[IsProcess] IS NULL OR (AI.[IsProcess] = 1 AND AI.[IsCancel] = 1)) THEN 1 ELSE 0 END)							'notTranscribedAsyncInteraction',
				SUM(CASE WHEN AI.[IsTranscribed] = 1 THEN AI.[RawChar] ELSE 0 END)																'notTranscribedRawChar',
				--SUM(A.[DurationTime] / @SecondsPerRequest)																					'averageModelRequest'
				0																																'averageModelRequest'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[Channel] = PAI.[InteractionType]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			WHERE PAI.[ProcessId] = @ProcessId
			GROUP BY PAI.[InteractionType]
		
	END

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetProcessInteractionsTask]...';


GO

ALTER PROCEDURE [dbo].[GetProcessInteractionsTask]
(
	@VCC		VARCHAR(50),
	@ProcessId	VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	BEGIN
		-- ACTUALIZAMOS LOS REGISTROS DE INTERACCIONES SINCRONAS(CALL) Y RETORNAMOS LOS DETALLES DE LAS QUE SE VAN A TRANSCRIBIR

		-- Actualiza en el primer momento que se consulta a estos registros, con el valor 1 en el campo IsProcess. Indica que se encuentra utilizado por un proceso.
		UPDATE [dbo].[Audio] SET
			[dbo].[Audio].[IsProcess] = 1,	-- Indicar que se esta tomando como procesando para que ningun otro procesamiento en parelelo pueda utilizar el registro.
			[dbo].[Audio].[IsCancel] = null -- Limpiamos el campo isCancel para retomar los audios que fallaron en procesos pasados
		-- Retornamos todas las columnas a listar.
		OUTPUT INSERTED.[VCC]							'vcc',
				PA.[ProcessId]							'processId',
				'CALL'									'interactionType',
				INSERTED.[ID]							'id',
				INSERTED.[Section]						'section',
				INSERTED.[Part]							'part',
				INSERTED.[StartDate]					'startDate',
				INSERTED.[EndDate]						'endDate',
				INSERTED.[Campaign]						'campaign',
				INSERTED.[DispositionCode]				'dispositionCode',
				INSERTED.[Agent]						'agent',
				INSERTED.[Type]							'origin',
				E.[Name]								'name',
				E.[Type]								'environmentType',
				E.[Description]							'description',
				E.[FTPDirectory]						'ftpDirectory',
				E.[ApiHost]								'apiHost',
				E.[ApiPort]								'apiPort',
				E.[ApiUser]								'apiUser',
				E.[ApiPassword]							'apiPassword',
				E.[DbDisabled]							'dbDisabled',
				E.[DbServer]							'dbServer',
				E.[DbPort]								'dbPort',
				E.[DbUser]								'dbUser',
				E.[DbPassword]							'dbPassword',
				E.[PbxDisabled]							'pbxDisabled',
				E.[PbxServer]							'pbxServer',
				E.[PbxPort]								'pbxPort',
				E.[PbxUser]								'pbxUser',
				E.[PbxPassword]							'pbxPassword',
				INSERTED.[DurationTime]					'durationTime'
		FROM [dbo].[ProcessAudio] PA (NOLOCK)
		INNER JOIN [dbo].[Audio] A (NOLOCK) 
			ON CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
		INNER JOIN [dbo].[Process] P (NOLOCK) 
			ON PA.ProcessId = P.[Name]
		INNER JOIN [dbo].[Environment] E (NOLOCK) 
			ON P.[Environment] = E.[Name]
		WHERE A.[VCC] = @VCC
			AND PA.[ProcessId] = @ProcessId
			AND ((ISNULL(A.[IsProcess], 0) = 0				
					AND ISNULL(A.[IsTranscribed], 0) = 0)	-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				OR (A.[IsProcess] = 1						
					AND A.[IsCancel] = 1))					-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS

		-- ACTUALIZAMOS LOS REGISTROS DE INTERACCIONES ASINCRONAS Y RETORNAMOS LOS DETALLES DE LAS QUE SE VAN A TRANSCRIBIR
		UPDATE [dbo].[AsyncInteraction] 
		SET [dbo].[AsyncInteraction].[IsProcess] = 1,
			[dbo].[AsyncInteraction].[IsCancel] = NULL
		OUTPUT INSERTED.[VCC]														'vcc',
				P.[Name]															'processId',
				INSERTED.[Channel]													'interactionType',
				INSERTED.[ID]														'id',
				INSERTED.[EndDate]													'endDate',
				INSERTED.[Folder]													'folder',
				INSERTED.[Campaign]													'campaign',
				INSERTED.[DispositionCode]											'dispositionCode',
				ISNULL(INSERTED.[LastTakedAgent], INSERTED.[FirstTakedAgent])		'agent',
				INSERTED.[Initiative]												'origin',
				INSERTED.[TotalMessages]											'totalMessages',
				INSERTED.[RawChar]													'rawChar',
				INSERTED.[ExportedContent]											'exportedContent',
				'allegro'															'environmentType'
		FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
		INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
			ON AI.[ID] = PAI.[InteractionId]
				AND AI.[EndDate] = PAI.[EndDate]
		INNER JOIN [dbo].[Process] P (NOLOCK) 
			ON P.[Name] = PAI.[ProcessId] 
		WHERE AI.[VCC] = @VCC
			AND PAI.[ProcessId] = @ProcessId
			AND ((ISNULL(AI.[IsProcess], 0) = 0
					AND ISNULL(AI.[IsTranscribed], 0) = 0)	-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				OR (AI.[IsProcess] = 1
					AND AI.[IsCancel] = 1))					-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS
	END

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetProcessValidDurationTime]...';


GO
ALTER  PROCEDURE [dbo].[GetProcessValidDurationTime](
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50)
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE RETORNAR LA CANTIDAD DE SEGUNDOS DE TRANSCRIPCION DE AUDIO CORRESPONDIENTE A UN PROCESS
	SET XACT_ABORT, NOCOUNT ON
	
	SELECT P.[Name] 'name',
			SUM(A.[DurationLinguisticTime]) 'validDurationTime'
		FROM Process P (NOLOCK)
		LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON PA.[ProcessId] = P.[Name]
		LEFT JOIN [dbo].[Audio] A (NOLOCK) 
			ON A.[ID] = PA.[AudioId]
				AND A.[Section] = PA.[Section]
				AND A.[Part] = PA.[Part]
		WHERE P.[VCC] = @VCC 
			AND P.[Name] = @ProcessId
		GROUP BY P.[Name] 

	SET XACT_ABORT, NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetReports]...';


GO
ALTER PROCEDURE [dbo].[GetReports] (
	@VCC Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL, @Role Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	IF(@Role IS NULL)
	BEGIN
		IF @VCC = 'system' 
		BEGIN
			-- VOLCADO PARA LA CREACION DE VCC EN PROVISIONING
			SELECT
				[ID]								'id',
				[Description] 						'description',
				[Procedure] 						'procedure',
				[StartDate]							'startDate',
				[EndDate]							'endDate',
				[Frecuency]							'frecuency',
				[HourSpace]							'hourSpace',
				[ExactTime]							'exactTime',
				[Weekday]							'weekday',
				[DayMonth]							'dayMonth',
				[Summary]							'summary',
				[Filter]							'filter',
				[Email]								'email',
				[Type]								'type'
			FROM [Report] (NOLOCK)
			WHERE [VCC] = @VCC
			AND ISNULL([Id], '') + ' ' + ISNULL([Id], '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND ISNULL([Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND (
				[Type] IN (SELECT [Product] FROM VCCLicense (NOLOCK)  WHERE [VCC] = @VCC AND [Status] = 1)
					OR [Type] IN ('SHARED', 'BILLING', 'BUSINESS')
			)
		END 
		ELSE
		BEGIN
			-- VOLCADO PARA LA VISTA DE REPORTES SPEECH Y QUALITY
			SELECT
				[ID]								'id',
				[Description] 						'description',
				[Procedure] 						'procedure',
				[StartDate]							'startDate',
				[EndDate]							'endDate',
				[Frecuency]							'frecuency',
				[HourSpace]							'hourSpace',
				[ExactTime]							'exactTime',
				[Weekday]							'weekday',
				[DayMonth]							'dayMonth',
				[Summary]							'summary',
				[Filter]							'filter',
				[Email]								'email',
				[Type]								'type'
			FROM [Report] (NOLOCK)
			WHERE [VCC] = @VCC
			AND ISNULL([Id], '') + ' ' + ISNULL([Id], '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND ISNULL([Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND [Type] IN (SELECT [Product] FROM VCCLicense (NOLOCK)  WHERE [VCC] = @VCC AND [Status] = 1)
			OR [Type] = 'SHARED'
			/*
			AND (
				[Type] IN (SELECT [Product] FROM VCCLicense (NOLOCK)  WHERE [VCC] = @VCC AND [Status] = 1)
					OR [Type] = 'SHARED'
			)
			*/
		END
	END
	ELSE IF @Role = 'business_administrator'
	BEGIN
		SELECT [ID]									'id',
				[Description] 						'description',
				[Procedure] 						'procedure',
				[StartDate]							'startDate',
				[EndDate]							'endDate',
				[Frecuency]							'frecuency',
				[HourSpace]							'hourSpace',
				[ExactTime]							'exactTime',
				[Weekday]							'weekday',
				[DayMonth]							'dayMonth',
				[Summary]							'summary',
				[Filter]							'filter',
				[Email]								'email',
				[Type]								'type'
			FROM [Report] (NOLOCK)
			WHERE [VCC] = @VCC
			AND ISNULL([Id], '') + ' ' + ISNULL([Id], '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND ISNULL([Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND [Type] IN ('BUSINESS') 
	END
	ELSE IF @Role = 'provisioning'
	BEGIN 
		-- REPORTES PARA LA VISTA DEL PROVISIONING
		SELECT [ID]									'id',
				[Description] 						'description',
				[Procedure] 						'procedure',
				[StartDate]							'startDate',
				[EndDate]							'endDate',
				[Frecuency]							'frecuency',
				[HourSpace]							'hourSpace',
				[ExactTime]							'exactTime',
				[Weekday]							'weekday',
				[DayMonth]							'dayMonth',
				[Summary]							'summary',
				[Filter]							'filter',
				[Email]								'email',
				[Type]								'type'
			FROM [Report] (NOLOCK)
			WHERE [VCC] = @VCC
			AND ISNULL([Id], '') + ' ' + ISNULL([Id], '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND ISNULL([Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND [Type] IN ('BILLING') 
	END
	
	SET NOCOUNT OFF
END
GO
PRINT N'Creating [dbo].[BulkAsyncInteraction]...';


GO
CREATE PROCEDURE [dbo].[BulkAsyncInteraction]
AS
BEGIN
	-- ESTE SP INSERTA REGISTROS UNICOS DE ASYNCINTERACTION PROVENIENTES DE LA BD EXTERNA EN LA TABLA ASYNCINTERACTION Y PROCESSASYNCINTERACTION

	--
	INSERT INTO [dbo].[AsyncInteraction] (
		[VCC], [ID], [Folder], [ExportedContent], [Channel]
		, [Campaign], [StartDate], [EndDate], [Account], [Initiative]
		, [ContactName], [FirstTakedAgent], [LastTakedAgent], [IsTaken], [TotalMessages]
		, [DurationTime], [AttentionTime], [DispositionCode], [DispositionTreePath], [CreatedDate]
		, [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]
	)
		-- SELECCIONAMOS TODOS LOS REGISTROS DE LA TABLA TEMPORAL [#AsyncInteractionTemp] QUE NO EXISTEN EN [AsyncInteraction] POR LOS PK
		SELECT AIT.[VCC], AIT.[ID], AIT.[Folder], AIT.[ExportedContent], AIT.[Channel]
				, AIT.[Campaign], AIT.[StartDate], AIT.[EndDate], AIT.[Account], AIT.[Initiative]
				, AIT.[ContactName], AIT.[FirstTakedAgent], AIT.[LastTakedAgent], AIT.[IsTaken], AIT.[TotalMessages]
				, AIT.[DurationTime], AIT.[AttentionTime], AIT.[DispositionCode], AIT.[DispositionTreePath], AIT.[CreatedDate]
				, AIT.[CreatedByUserId], AIT.[LastModifiedDate], AIT.[LastModifiedByUserId], GETUTCDATE()
			FROM [#AsyncInteractionTemp] AIT
			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = AIT.[VCC]
					AND AI.[ID] = AIT.[ID]
					AND AI.[EndDate] = AIT.[EndDate]
			WHERE AI.[ID] IS NULL

	--
	INSERT INTO [dbo].[ProcessAsyncInteraction] (
		[VCC], [ProcessId], [InteractionType], [Campaign], [InteractionId]
		, [EndDate], [FormattedEndDate], [CreatedDate], [CreatedByUserId], [LastModifiedDate]
		, [LastModifiedByUserId], [TimeStamp]
	)
		-- SELECCIONAMOS TODOS LOS REGISTROS DE LA TABLA TEMPORAL [#ProcessAsyncInteractionTemp] QUE NO EXISTEN EN [ProcessAsyncInteraction] POR LOS PK
		SELECT PAIT.[VCC], PAIT.[ProcessId], PAIT.[InteractionType], PAIT.[InteractionId], PAIT.[Campaign]
				, PAIT.[EndDate], PAIT.[FormattedEndDate], PAIT.[CreatedDate], PAIT.[CreatedByUserId], PAIT.[LastModifiedDate]
				, PAIT.[LastModifiedByUserId], GETUTCDATE()
			FROM [#ProcessAsyncInteractionTemp] PAIT
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = PAIT.[VCC]
					AND PAI.[ProcessId] = PAIT.[ProcessId]
					AND PAI.[InteractionType] = PAIT.[InteractionType]
					AND PAI.[InteractionId] = PAIT.[InteractionId]
					AND PAI.[EndDate] = PAIT.[EndDate]
			WHERE PAI.[InteractionId] IS NULL
	
	-- ELIMINAMOS LAS TABLAS TEMPORALES
	DROP TABLE [#AsyncInteractionTemp]
	DROP TABLE [#ProcessAsyncInteractionTemp]
END
GO
PRINT N'Creating [dbo].[GetAsyncInteractions]...';


GO
-- ESTE SP RETORNA LAS INTERACCIONES ASINCRONAS 
CREATE PROCEDURE [dbo].[GetAsyncInteractions]
(
	@VCC					VARCHAR(50) = NULL,
	@IP						VARCHAR(50),						-- IP DEL SERVIDOR PARA LA BASE I6
	@Type					INT,								-- FLAG PARA INDICAR SI EL SERVIDOR I6 SE ENCUENTRA LOCAL O REMOTO
	@InteractionType		VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@Origins				VARCHAR(MAX) = NULL,
	@UniqueIds				BIT = 0								-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
)
AS
BEGIN
	-- INFO: EN CHAT SE CREAN UN ID EN CADA INTERACCION(EJM: CHATS DE ATENCION EN LAS WEB DE BANCOS), LOS DEMAS CANALES ID + ENDDATE
	
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UNA VARIABLE PARA IDENTIFICAR SI EL SP ES LLAMADO DEL SISTEMA O POR OTRO SP
	DECLARE @IS_NESTED BIT = 0

	-- DECLARAMOASUN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @HISTORICAL_DATA_I6_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_APPSTORE_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_CHAT_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_FACEBOOK_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_INSTAGRAM_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_MAIL_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_TWITTER_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_WEBCONTACT_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_WHATSAPP_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_YOUTUBE_TABLE NVARCHAR(100)

	-- EL PARAMETRO TYPE DEFINE SI LA BD HISTORICALDATAI6 SE ENCUENTRA LOCAL O REMOTO
	IF (@Type = 0)  
	BEGIN  
		SET @HISTORICAL_DATA_I6_APPSTORE_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Appstore]'
		SET @HISTORICAL_DATA_I6_CHAT_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Chat]'
		SET @HISTORICAL_DATA_I6_FACEBOOK_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Facebook]'
		SET @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Googleplay]'
		SET @HISTORICAL_DATA_I6_INSTAGRAM_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Instagram]'
		SET @HISTORICAL_DATA_I6_MAIL_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Mail]'
		SET @HISTORICAL_DATA_I6_TWITTER_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Twitter]'
		SET @HISTORICAL_DATA_I6_WEBCONTACT_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Webcontact]'
		SET @HISTORICAL_DATA_I6_WHATSAPP_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Whatsapp]'
		SET @HISTORICAL_DATA_I6_YOUTUBE_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Youtube]'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @HISTORICAL_DATA_I6_APPSTORE_TABLE = '[HistoricalDataI6].[dbo].[Detail_Appstore]'
		SET @HISTORICAL_DATA_I6_CHAT_TABLE = '[HistoricalDataI6].[dbo].[Detail_Chat]'
		SET @HISTORICAL_DATA_I6_FACEBOOK_TABLE = '[HistoricalDataI6].[dbo].[Detail_Facebook]'
		SET @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE = '[HistoricalDataI6].[dbo].[Detail_Googleplay]'
		SET @HISTORICAL_DATA_I6_INSTAGRAM_TABLE = '[HistoricalDataI6].[dbo].[Detail_Instagram]'
		SET @HISTORICAL_DATA_I6_MAIL_TABLE = '[HistoricalDataI6].[dbo].[Detail_Mail]'
		SET @HISTORICAL_DATA_I6_TWITTER_TABLE = '[HistoricalDataI6].[dbo].[Detail_Twitter]'
		SET @HISTORICAL_DATA_I6_WEBCONTACT_TABLE = '[HistoricalDataI6].[dbo].[Detail_Webcontact]'
		SET @HISTORICAL_DATA_I6_WHATSAPP_TABLE = '[HistoricalDataI6].[dbo].[Detail_Whatsapp]'
		SET @HISTORICAL_DATA_I6_YOUTUBE_TABLE = '[HistoricalDataI6].[dbo].[Detail_Youtube]'
	END  

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT '

	-- ARMAMOS LA PARTE BASE DE FILTROS
	SET @SQL_FILTER += '
			WHERE HDI6.[Vcc] = ''' + @VCC + '''
				AND HDI6.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' '

	-- DEPENDIENDO SI LA HORA DE FIN ES MAYOR A LA DE INICIO O NO DAMOS FORMA AL FILTRO DE HORA
	IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @SQL_FILTER += 'AND CAST(HDI6.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
	IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @SQL_FILTER += 'AND CAST(HDI6.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') SET @SQL_FILTER += 'AND HDI6.[Campaign] IN (SELECT VALUE FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') SET @SQL_FILTER += 'AND HDI6.[DispositionTreePath] IN (SELECT VALUE FROM [dbo].[split](''' + @DispositionCodes + ''','','')) '

	-- ARMAMOS EL SELECT PARA LOS DIFERENTES INTERACTION TYPES
	IF (@InteractionType = 'APPSTORE')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_APPSTORE_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_APPSTORE
		SET @SQL_SELECT += '
								Vcc														''vcc'', 
								ID														''id'', 
								CONVERT(VARCHAR, EndDate, 23)							''folder'',
								ExportedContent											''exportedContent'', 
								''APPSTORE''											''channel'',
								Campaign												''campaign'', 
								StartDate												''startDate'', 
								EndDate													''endDate'', 
								Account													''account'', 
								Initiative												''initiative'',
								ContactName												''contactName'', 
								FirstAgent												''firstTakedAgent'', 
								NULL													''lastTakedAgent'', 
								NULL													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)				''totalMessages'',
								DurationTime											''durationTime'', 
								AttentionTime											''attentionTime'', 
								DispositionCode											''dispositionCode'', 
								DispositionTreePath										''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END
	ELSE IF (@InteractionType = 'CHAT')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_CHAT_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_CHAT
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''CHAT''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								''IN''														''initiative'', 
								ContactName													''contactName'', 
								FirstTakeAgent												''firstTakedAgent'', 
								LastTakeAgent												''lastTakedAgent'', 
								IsTaken														''isTaken'',
								ISNULL(TRY_CAST(ChatMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[LastTakeAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

	END 
	ELSE IF (@InteractionType = 'FACEBOOK')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_FACEBOOK_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_FACEBOOK
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''FACEBOOK''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								NULL														''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END 
	ELSE IF (@InteractionType = 'GOOGLEPLAY')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_GOOGLEPLAY
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''GOOGLEPLAY''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'',  
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END
	ELSE IF (@InteractionType = 'INSTAGRAM')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_INSTAGRAM_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_INSTAGRAM
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''INSTAGRAM''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END  
	ELSE IF (@InteractionType = 'MAIL')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_MAIL_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_MAIL
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''MAIL''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								MailHasResponse												''isTaken'',
								ISNULL(TRY_CAST(MailTotalMessages AS INT), 1)				''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END  
	ELSE IF (@InteractionType = 'TWITTER')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_TWITTER_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_TWITTER
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''TWITTER''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END  
	ELSE IF (@InteractionType = 'WEBCONTACT')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_WEBCONTACT_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_WEBCONTACT
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''WEBCONTACT''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								''IN''														''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalResponses AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END
	ELSE IF (@InteractionType = 'WHATSAPP')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_WHATSAPP_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_WHATSAPP
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''WHATSAPP''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(WhatsappTotalMessages AS INT), 1)			''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END  
	ELSE IF (@InteractionType = 'YOUTUBE')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_YOUTUBE_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_YOUTUBE
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''YOUTUBE''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM ' + @HISTORICAL_DATA_I6_TABLE + ' HDI6 (NOLOCK) '

	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
	IF OBJECT_ID('TEMPDB..#TMP_HD_INTERACTIONS') IS NULL
	BEGIN
		-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
		CREATE TABLE #TMP_HD_INTERACTIONS
		(
			vcc VARCHAR(50), 
			id VARCHAR(250),  
			folder VARCHAR(50),
			exportedContent VARCHAR(250),  
			channel VARCHAR(50), 
			campaign VARCHAR(50), 
			startDate DATETIME,
			endDate DATETIME,
			account VARCHAR(50), 
			initiative VARCHAR(50), 
			contactName VARCHAR(50), 
			firstTakedAgent VARCHAR(50), 
			lastTakedAgent VARCHAR(50), 
			isTaken VARCHAR(50), 
			totalMessages INT,
			durationTime VARCHAR(50),  
			attentionTime VARCHAR(50), 
			dispositionCode VARCHAR(250), 
			dispositionTreePath VARCHAR(250), 
		)

		-- REAFIRMAMOS QUE EL SP NO ESTA ANIDADO EN OTRO
		SET @IS_NESTED = 0

		-- PRINT 'SP NO ANIDADO'
	END
	ELSE
	BEGIN
		-- SI LA TABLA TEMPORAL YA EXISTIA, EL SP ESTA ANIDADO EN OTRO (P.E.: [dbo].[GetAsyncBillingInteractions])
		SET @IS_NESTED = 1

		-- PRINT 'SP ANIDADO'
	END 

	-- INSERTAMOS EL RESULTADO EN LA TABLA TEMPORAL
	INSERT INTO #TMP_HD_INTERACTIONS
		-- EJECUTAMOS LA CONSULTA
		EXEC (@SQL_SELECT)

	-- SI EL SP NO ESTA ANIDADO, HACEMOS SELECT AL RESULTADO A MOSTRAR
	IF @IS_NESTED = 0
	BEGIN
		-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
		IF @UniqueIds = 1 
		BEGIN
			SELECT TBL.[channel]										AS 'interactionType',
					COUNT(DISTINCT (
						CASE WHEN @InteractionType = 'CALL' 
						THEN TBL.[id] 
						ELSE CONCAT(TBL.[id], TBL.[endDate]) 
						END))											AS 'interactions',
					COUNT(*) AS 'details'
				FROM #TMP_HD_INTERACTIONS TBL
				GROUP BY TBL.[channel]
		END
		ELSE
		BEGIN
			SELECT * FROM #TMP_HD_INTERACTIONS
		END
	END

	/*
	-- DECLARAMOS LAS CTE
	WITH CTE_AVAILABLE_BALANCE_REPORT AS (
		SELECT * FROM #TMP_HD_INTERACTIONS
	)
	select * from CTE_AVAILABLE_BALANCE_REPORT 
	*/
END
GO
PRINT N'Creating [dbo].[GetCSVBillingInteractions]...';


GO
-- ESTE SP RETORNA UN RESUMEN DE LA BUSQUEDA DE INTERACCIONES DE CSV CRUZANDO CON ALLEGRO PARA INDETIFICAR LOS YA TRANSCRITOS O INPROCESS SEGUN LOS FILTROS RECIBIDOS 
-- FUNCIONA IGUAL QUE LA FUNCION EN KNEX
CREATE PROCEDURE [dbo].[GetCSVBillingInteractions] (
	@VCC VARCHAR(50) = NULL,
	@SecondsPerRequest DECIMAL(18, 5),
	@StartDate DATETIME = '1980-01-01T00:00:00',
    @EndDate DATETIME = '2050-01-01T23:59:59',
	@Campaigns VARCHAR(MAX) = '',
 	@Agents VARCHAR(MAX) = '',
   	@Origins VARCHAR(100) = NULL,
	@StartHour VARCHAR(50) = NULL,
	@EndHour VARCHAR(50) = NULL,
	@MinDuration INT = 0,
    @MaxDuration INT = 100000,
    @Results VARCHAR(MAX) = NULL
) 
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @INTERACTION_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_ACTOR_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_MULTIMEDIA_PARTS_TABLE NVARCHAR(100)
	DECLARE @CAMPAIGN_GOAL_RESULT_MANAGEMENT_TABLE NVARCHAR(100)

	-- SETTEAMOS LOS VALORES DE DURACION MINIMA Y MAXIMA A UNO VALIDO
	IF @MinDuration = @MaxDuration AND @MaxDuration = 0 SET @MaxDuration = 100000
	IF @MinDuration IS NULL SET @MinDuration = 0
	IF @MaxDuration IS NULL SET @MaxDuration = 100000

	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '

	SET @SQL_SELECT_1 += '
				''CALL'' ''interactionType'',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN 1 ELSE 0 END) ''alreadyTranscribedAudio'',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN PCT.[DurationTime] ELSE 0 END) ''alreadyTranscribedDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL) THEN 1 ELSE 0 END) ''inProcessAudio'',
				SUM(CASE WHEN (A.[IsProcess] = 1 AND A.[IsTranscribed] IS NULL AND A.[IsCancel] IS NULL) THEN PCT.[DurationTime] ELSE 0 END) ''inProcessDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)) THEN 1 ELSE 0 END) ''notTranscribedAudio'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)) THEN PCT.[DurationTime] ELSE 0 END) ''notTranscribedDurationTime'', 
				SUM(PCT.[DurationTime] / ' + (SELECT CONVERT(varchar(10), @SecondsPerRequest)) + ') ''averageModelResquest'' '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [#ProcessCsvTemp] PCT
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
				-- ON CONCAT(A.[ID], ''_'', A.[Section], ''_'', A.[Part]) = PCT.[ID]
				ON A.[ID] = PCT.[ID]
					AND A.[VCC] = ''' + @VCC + ''' '

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE PCT.[ID] IS NOT NULL 
				AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' '

	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') SET @SQL_FILTER += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	IF (@Origins IS NOT NULL AND @Origins != '') SET @SQL_FILTER += 'AND PCT.[Type] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	IF (@Results IS NOT NULL AND @Results != '') SET @SQL_FILTER += 'AND PCT.[DispositionCode] IN (SELECT Value FROM [dbo].[split](''' + @Results + ''','','')) ';
	
	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	SET @SQL_EXTRA += 'DROP TABLE [#ProcessCsvTemp]'
	
	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	-- EJECUTAMOS LA CONSULTA
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Creating [dbo].[GetCSVSummaryInteractions]...';


GO
-- ESTE SP RETORNA LAS INTERACCIONES SINCRONAS(CALL) DE FTP
CREATE PROCEDURE [dbo].[GetCSVSummaryInteractions] 
(
	@VCC					VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@MinDuration			INT = 0,
    @MaxDuration			INT = 100000,
    @Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
   	@Origins				VARCHAR(100) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@IsSummary				BIT = 0								-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
) 
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NULL OR @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NULL OR @EndHour = '') SET @EndHour = '23:59:59'

	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE MINIMO Y MAXIMO
	IF (@MinDuration IS NULL OR @MinDuration = '') SET @MinDuration = 0
	IF (@MaxDuration IS NULL OR @MaxDuration = '') SET @MaxDuration = 100000
	
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
	IF @IsSummary = 1 
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_0 += '
			SELECT ''CALL''											AS ''interactionType'', 
					COUNT(DISTINCT PCT.[ID])						AS ''totalInteractions'',
					COUNT(*)										AS ''details'',
					ISNULL(SUM(PCT.[DurationTime]), 0)				AS ''totalAttentionTime''
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_0
	END
	ELSE
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_1 += '
			SELECT *
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_1
	END
	
	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [#ProcessCsvTemp] PCT '

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE PCT.[ID] IS NOT NULL 
				AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' '

	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') SET @SQL_FILTER += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	IF (@Origins IS NOT NULL AND @Origins != '') SET @SQL_FILTER += 'AND PCT.[Type] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') SET @SQL_FILTER += 'AND PCT.[DispositionCode] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')) ';
	
	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	SET @SQL_EXTRA += 'DROP TABLE [#ProcessCsvTemp]'
	
	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Creating [dbo].[GetIntegratedVCCs]...';


GO
-- SP SPEECHANALYTICS: RECUPERA LOS VCC DE LA MMPRODAT
CREATE PROCEDURE [dbo].[GetIntegratedVCCs] (
   	@VCC VARCHAR(50) = NULL,
	@IP VARCHAR(50), 
	@Type INT
) 
AS 
BEGIN 
	-- DECLARAMOS CADENAS DE TEXTO PARA EL QUERY FINAL
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''

	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @VCC_SERVICE_TABLE NVARCHAR(100)
	DECLARE @SYSTEM_SERVICE_TABLE NVARCHAR(100)

	-- EL PARAMETRO TYPE DEFINE SI LA BD ALLEGRO SE ENCUENTRA LOCAL O REMOTO
	IF (@Type = 0)  
	BEGIN  
		SET @VCC_SERVICE_TABLE = '[' + @Ip + ']' + '.[mmprodat].[dbo].[VCCService]'
		SET @SYSTEM_SERVICE_TABLE = '[' + @Ip + ']' + '.[mmprodat].[dbo].[SystemService]'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @VCC_SERVICE_TABLE = '[mmprodat].[dbo].[VCCService]';
		SET @SYSTEM_SERVICE_TABLE = '[mmprodat].[dbo].[SystemService]';
	END  

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				VS.[VCC] ''vcc'',
				SUM(CASE WHEN SS.[Type] = ''OMNICHANNELINTEGRATION'' THEN 1 ELSE 0 END) ''hasOmnichannel'' -- 1: OCC OR 0: ALLEGRO ' 

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM ' + @VCC_SERVICE_TABLE + ' VS (NOLOCK)
			LEFT JOIN ' + @SYSTEM_SERVICE_TABLE + ' SS (NOLOCK) 
				ON SS.[Id] = VS.[ServiceId] '

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '' 

	-- ARMAMOS LA PARTE DE EXTRAS
	SET @SQL_EXTRA += '
			GROUP BY VS.[VCC]
			ORDER BY VS.[VCC] ASC '

	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	-- EJECUTAMOS LA CONSULTA
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Creating [dbo].[GetProcessChannelByProcessId]...';


GO
CREATE PROCEDURE [dbo].[GetProcessChannelByProcessId]
(
	@VCC				VARCHAR(50),
	@ProcessId			VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	-- BUSCAMOS LOS INTERACTIONTYPES(CHANNELS) SELECCIONADOS EN EL PROCESS
	SELECT PF.[Value] 
		FROM [dbo].[ProcessFilter] PF (NOLOCK) 
		WHERE PF.[VCC] = @VCC 
			AND PF.[ProcessId] = @ProcessId 
			AND (PF.[Key] = 'types' OR PF.[Key] = 'channel') 

	SET NOCOUNT OFF
END
GO
PRINT N'Creating [dbo].[GetAsyncBillingInteractions]...';


GO
-- ESTE SP RETORNA UN RESUMEN DE LA BUSQUEDA DE INTERACCIONES DE ALLEGRO PARA INDETIFICAR LOS YA TRANSCRITOS O INPROCESS SEGUN LOS FILTROS RECIBIDOS 
-- FUNCIONA IGUAL QUE LA FUNCION EN KNEX
CREATE PROCEDURE [dbo].[GetAsyncBillingInteractions] (
   	@VCC					VARCHAR(50) = NULL,
	@IP						VARCHAR(50),						-- IP DEL SERVIDOR PARA LA BASE I6
	@Type					INT,								-- FLAG PARA INDICAR SI EL SERVIDOR I6 SE ENCUENTRA LOCAL O REMOTO
	@InteractionType		VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
   	@DispositionCodes		VARCHAR(MAX) = NULL,
   	@Origins				VARCHAR(100) = NULL
)
AS 
BEGIN 
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
	CREATE TABLE #TMP_HD_INTERACTIONS
	(
		vcc VARCHAR(50), 
		id VARCHAR(250), 
		folder VARCHAR(50),
		exportedContent VARCHAR(250),  
		channel VARCHAR(50), 
		campaign VARCHAR(50), 
		startDate DATETIME,
		endDate DATETIME,
		account VARCHAR(50), 
		initiative VARCHAR(50), 
		contactName VARCHAR(50), 
		firstTakedAgent VARCHAR(50), 
		lastTakedAgent VARCHAR(50), 
		isTaken VARCHAR(50), 
		totalMessages INT,
		durationTime VARCHAR(50),  
		attentionTime VARCHAR(50), 
		dispositionCode VARCHAR(250), 
		dispositionTreePath VARCHAR(250), 
	)

	-- EJECUTAMOS EL SP DE CONSULTA QUE LLENARA LA TABLA TEMPORAL
	EXEC [dbo].[GetAsyncInteractions]
		@Ip = @IP, @VCC = @VCC, @Type = @Type, @InteractionType = @InteractionType, @StartDate = @StartDate, 
		@EndDate = @EndDate, @StartHour = @StartHour, @EndHour = @EndHour, @Campaigns = @Campaigns, @Agents = @Agents,
		@DispositionCodes = @DispositionCodes, @Origins = @Origins, @UniqueIds = 0

	-- DECLARAMOS UNA VARIABLE PARA PARA EL TOTALDE RESULTADOS
	DECLARE @TOTAL_INTERACTIONS INT = 0

	-- SETTEAMOS EL NUMERO DE REGISTROS A LA VARIABLE DE TOTAL
	SELECT @TOTAL_INTERACTIONS = COUNT(*) FROM #TMP_HD_INTERACTIONS
	
	IF @TOTAL_INTERACTIONS = 0 
	BEGIN
		-- SI NO EXISTEN RESULTADOS EN HD LLENAMOSUN RESULTADOS CON 0
		SELECT @InteractionType												'interactionType',
				0															'alreadyTranscribedInteraction',
				0															'inProcessInteraction',
				0															'notTranscribedInteraction'
	END 
	ELSE
	BEGIN
		-- CRUZAMOS LA TABLA TEMPORAL DE INTERACCIONES ASINCRONAS CON LA TABLA LOCAL INTERACTION PARA LAS INTERACCIONES ASINCRONAS YA REGISTRADAS
		SELECT HDI.[channel]												'interactionType',
				SUM(CASE WHEN I.[VCC] IS NOT NULL THEN 1 ELSE 0 END)		'alreadyTranscribedInteraction',
				0															'inProcessInteraction',
				SUM(CASE WHEN I.[VCC] IS NULL THEN 1 ELSE 0 END)			'notTranscribedInteraction'
			FROM #TMP_HD_INTERACTIONS HDI (NOLOCK)
			LEFT JOIN [dbo].[AsyncInteraction] I (NOLOCK)
				ON HDI.[vcc] = I.[VCC]
					AND HDI.[channel] = I.[Channel]
					AND HDI.[campaign] = I.[Campaign]
					AND HDI.[id] = I.[ID]
					AND HDI.[endDate] = I.[EndDate]
			GROUP BY HDI.[vcc],
						HDI.[channel]
	END

END
GO
PRINT N'Refreshing [dbo].[DeleteVCC]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteVCC]';


GO
PRINT N'Update complete.';


GO
