PRINT N'Dropping [dbo].[DF_TranscriptionQualification_CreatedDate]...';


GO
ALTER TABLE [dbo].[Transcription] DROP CONSTRAINT [DF_TranscriptionQualification_CreatedDate];


GO
PRINT N'Starting rebuilding table [dbo].[Transcription]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_Transcription] (
    [VCC]                  VARCHAR (50) NOT NULL,
    [ProcessId]            VARCHAR (50) NOT NULL,
    [InteractionType]      VARCHAR (50) NULL,
    [Section]              NUMERIC (5)  NOT NULL,
    [Part]                 NUMERIC (5)  NOT NULL,
    [ID]                   VARCHAR (50) NOT NULL,
    [Campaign]             VARCHAR (50) NULL,
    [Folder]               VARCHAR (50) NULL,
    [Value]                INT          NULL,
    [CreatedDate]          DATETIME     CONSTRAINT [DF_TranscriptionQualification_CreatedDate] DEFAULT (getutcdate()) NULL,
    [CreatedByUserId]      VARCHAR (50) NULL,
    [LastModifiedDate]     DATETIME     NULL,
    [LastModifiedByUserId] VARCHAR (50) NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_Transcription1] PRIMARY KEY CLUSTERED ([VCC] ASC, [Section] ASC, [Part] ASC, [ID] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[Transcription])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_Transcription] ([VCC], [Section], [Part], [ID], [ProcessId], [Value], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId])
        SELECT   [VCC],
                 [Section],
                 [Part],
                 [ID],
                 [ProcessId],
                 [Value],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId]
        FROM     [dbo].[Transcription]
        ORDER BY [VCC] ASC, [Section] ASC, [Part] ASC, [ID] ASC;
    END

DROP TABLE [dbo].[Transcription];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_Transcription]', N'Transcription';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_Transcription1]', N'PK_Transcription', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Altering [dbo].[GetTranscription]...';


GO
-- [dbo].[GetTranscription] 'default', 'F040EA5A-E455-49EC-8A8D-4A4AD13D8786', 0, 0, 'FFB04B5FF6E242098CD31F419CC4E4A3'
ALTER PROCEDURE [dbo].[GetTranscription]
(
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50) = NULL,
	@InteractionType VARCHAR(50) = NULL,
	@Section NUMERIC(5, 0),
	@Part NUMERIC(5, 0),
	@Campaign VARCHAR(50) = NULL,
	@Folder VARCHAR(50) = NULL,
	@ID VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SI INTERACTIONTYPE ES NULL SETTEAMOS COMO CALL
	IF @InteractionType IS NULL SET @InteractionType = 'CALL'

	SELECT
		[VCC]						'vcc',
		[ProcessId]					'processId',
		[InteractionType]			'interactionType',
		[Section]					'section',
		[Part]						'part',
		[Folder]					'folder',
		[Campaign]					'campaign',
		[ID]						'id',
		[Value]						'value',
		[CreatedDate]				'createdDate',
		[CreatedByUserId]			'createdByUserId',
		[LastModifiedDate]			'lastModifiedDate',
		[LastModifiedByUserId]		'lastModifiedByUserId'
	FROM [dbo].[Transcription] (NOLOCK)
	WHERE
		[VCC] = @VCC 
		AND [ProcessId] = @ProcessId 
		AND [InteractionType] = @InteractionType
		AND (
			(
				[InteractionType] = 'CALL'
					AND [Section] = @Section 
					AND [Part] = @Part 
			) OR (
				[InteractionType] <> 'CALL'
					-- AND [Folder] = @Folder
					AND [Campaign] = @Campaign
			)
		)
		AND [ID] = @ID

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[SaveTranscription]...';


GO
-- [SaveTranscription] 'default', 'F040EA5A-E455-49EC-8A8D-4A4AD13D8786', 'FFB04B5FF6E242098CD31F419CC4E4A3', 0, 0, 2, 'admin'
ALTER PROCEDURE [dbo].[SaveTranscription]
(
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50) = NULL,
	@InteractionType VARCHAR(50) = NULL,
	@Section NUMERIC(5, 0),
	@Part NUMERIC(5, 0),
	@Campaign VARCHAR(50) = NULL,
	@Folder VARCHAR(50) = NULL,
	@ID VARCHAR(50) = NULL,
	@Value INT,
	@UserId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SI EL INTERACTIONTYPE ES NULL SETTEAMOS CALL POR DEFECTO
	IF @InteractionType IS NULL SET @InteractionType = 'CALL'

	UPDATE [dbo].[Transcription] SET
	[Value] = @Value,
	[LastModifiedDate] = GETUTCDATE(),
	[LastModifiedByUserId] = @UserId
	WHERE
		[VCC] = @VCC 
		AND [ProcessId] = @ProcessId 
		AND [InteractionType] = @InteractionType
		AND (
			(
				[InteractionType] = 'CALL'
					AND [Section] = @Section 
					AND [Part] = @Part 
			) OR (
				[InteractionType] <> 'CALL'
					AND [Folder] = @Folder
					AND [Campaign] = @Campaign
			)
		)
		AND [ID] = @ID

	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [dbo].[Transcription](
			[VCC],
			[ProcessId],
			[InteractionType],
			[Section],
			[Part],
			[Campaign],
			[Folder],
			[ID],
			[Value],
			[CreatedByUserId]
		)
		VALUES(
			@VCC,
			@ProcessId,
			@InteractionType,
			@Section,
			@Part,
			@Campaign,
			@Folder,
			@ID,
			@Value,
			@UserId
		)
	END

	SELECT 1 AS 'result'

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetAsyncInteractions]...';


GO
-- ESTE SP RETORNA LAS INTERACCIONES ASINCRONAS 
ALTER PROCEDURE [dbo].[GetAsyncInteractions]
(
	@VCC					VARCHAR(50) = NULL,
	@IP						VARCHAR(50),						-- IP DEL SERVIDOR PARA LA BASE I6
	@Type					INT,								-- FLAG PARA INDICAR SI EL SERVIDOR I6 SE ENCUENTRA LOCAL O REMOTO
	@InteractionType		VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@Origins				VARCHAR(MAX) = NULL,
	@UniqueIds				BIT = 0								-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
)
AS
BEGIN
	-- INFO: EN CHAT SE CREAN UN ID EN CADA INTERACCION(EJM: CHATS DE ATENCION EN LAS WEB DE BANCOS), LOS DEMAS CANALES ID + ENDDATE
	
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UNA VARIABLE PARA IDENTIFICAR SI EL SP ES LLAMADO DEL SISTEMA O POR OTRO SP
	DECLARE @IS_NESTED BIT = 0

	-- DECLARAMOASUN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @HISTORICAL_DATA_I6_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_APPSTORE_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_CHAT_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_FACEBOOK_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_INSTAGRAM_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_MAIL_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_TWITTER_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_WEBCONTACT_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_WHATSAPP_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_YOUTUBE_TABLE NVARCHAR(100)

	-- EL PARAMETRO TYPE DEFINE SI LA BD HISTORICALDATAI6 SE ENCUENTRA LOCAL O REMOTO
	IF (@Type = 0)  
	BEGIN  
		SET @HISTORICAL_DATA_I6_APPSTORE_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Appstore]'
		SET @HISTORICAL_DATA_I6_CHAT_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Chat]'
		SET @HISTORICAL_DATA_I6_FACEBOOK_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Facebook]'
		SET @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Googleplay]'
		SET @HISTORICAL_DATA_I6_INSTAGRAM_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Instagram]'
		SET @HISTORICAL_DATA_I6_MAIL_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Mail]'
		SET @HISTORICAL_DATA_I6_TWITTER_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Twitter]'
		SET @HISTORICAL_DATA_I6_WEBCONTACT_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Webcontact]'
		SET @HISTORICAL_DATA_I6_WHATSAPP_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Whatsapp]'
		SET @HISTORICAL_DATA_I6_YOUTUBE_TABLE = '[' + @Ip + ']' + '.[HistoricalDataI6].[dbo].[Detail_Youtube]'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @HISTORICAL_DATA_I6_APPSTORE_TABLE = '[HistoricalDataI6].[dbo].[Detail_Appstore]'
		SET @HISTORICAL_DATA_I6_CHAT_TABLE = '[HistoricalDataI6].[dbo].[Detail_Chat]'
		SET @HISTORICAL_DATA_I6_FACEBOOK_TABLE = '[HistoricalDataI6].[dbo].[Detail_Facebook]'
		SET @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE = '[HistoricalDataI6].[dbo].[Detail_Googleplay]'
		SET @HISTORICAL_DATA_I6_INSTAGRAM_TABLE = '[HistoricalDataI6].[dbo].[Detail_Instagram]'
		SET @HISTORICAL_DATA_I6_MAIL_TABLE = '[HistoricalDataI6].[dbo].[Detail_Mail]'
		SET @HISTORICAL_DATA_I6_TWITTER_TABLE = '[HistoricalDataI6].[dbo].[Detail_Twitter]'
		SET @HISTORICAL_DATA_I6_WEBCONTACT_TABLE = '[HistoricalDataI6].[dbo].[Detail_Webcontact]'
		SET @HISTORICAL_DATA_I6_WHATSAPP_TABLE = '[HistoricalDataI6].[dbo].[Detail_Whatsapp]'
		SET @HISTORICAL_DATA_I6_YOUTUBE_TABLE = '[HistoricalDataI6].[dbo].[Detail_Youtube]'
	END  

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT '

	-- ARMAMOS LA PARTE BASE DE FILTROS
	SET @SQL_FILTER += '
			WHERE HDI6.[Vcc] = ''' + @VCC + '''
				AND HDI6.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' '

	-- DEPENDIENDO SI LA HORA DE FIN ES MAYOR A LA DE INICIO O NO DAMOS FORMA AL FILTRO DE HORA
	IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @SQL_FILTER += 'AND CAST(HDI6.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
	IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @SQL_FILTER += 'AND CAST(HDI6.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') SET @SQL_FILTER += 'AND HDI6.[Campaign] IN (SELECT VALUE FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') SET @SQL_FILTER += 'AND HDI6.[DispositionTreePath] IN (SELECT VALUE FROM [dbo].[split](''' + @DispositionCodes + ''','','')) '

	-- ARMAMOS EL SELECT PARA LOS DIFERENTES INTERACTION TYPES
	IF (@InteractionType = 'APPSTORE')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_APPSTORE_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_APPSTORE
		SET @SQL_SELECT += '
								Vcc														''vcc'', 
								ID														''id'', 
								CONVERT(VARCHAR, EndDate, 23)							''folder'',
								ExportedContent											''exportedContent'', 
								''APPSTORE''											''channel'',
								Campaign												''campaign'', 
								StartDate												''startDate'', 
								EndDate													''endDate'', 
								Account													''account'', 
								Initiative												''initiative'',
								ContactName												''contactName'', 
								FirstAgent												''firstTakedAgent'', 
								NULL													''lastTakedAgent'', 
								NULL													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)				''totalMessages'',
								DurationTime											''durationTime'', 
								AttentionTime											''attentionTime'', 
								DispositionCode											''dispositionCode'', 
								DispositionTreePath										''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END
	ELSE IF (@InteractionType = 'CHAT')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_CHAT_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_CHAT
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''CHAT''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								''IN''														''initiative'', 
								ContactName													''contactName'', 
								FirstTakeAgent												''firstTakedAgent'', 
								LastTakeAgent												''lastTakedAgent'', 
								IsTaken														''isTaken'',
								ISNULL(TRY_CAST(ChatMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[LastTakeAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

	END 
	ELSE IF (@InteractionType = 'FACEBOOK')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_FACEBOOK_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_FACEBOOK
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''FACEBOOK''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								NULL														''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END 
	ELSE IF (@InteractionType = 'GOOGLEPLAY')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_GOOGLEPLAY
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''GOOGLEPLAY''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'',  
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END
	ELSE IF (@InteractionType = 'INSTAGRAM')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_INSTAGRAM_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_INSTAGRAM
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''INSTAGRAM''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END  
	ELSE IF (@InteractionType = 'MAIL')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_MAIL_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_MAIL
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''MAIL''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								MailHasResponse												''isTaken'',
								ISNULL(TRY_CAST(MailTotalMessages AS INT), 1)				''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END  
	ELSE IF (@InteractionType = 'TWITTER')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_TWITTER_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_TWITTER
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''TWITTER''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END  
	ELSE IF (@InteractionType = 'WEBCONTACT')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_WEBCONTACT_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_WEBCONTACT
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''WEBCONTACT''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								''IN''														''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalResponses AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END
	ELSE IF (@InteractionType = 'WHATSAPP')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_WHATSAPP_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_WHATSAPP
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''WHATSAPP''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								Initiative													''initiative'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(WhatsappTotalMessages AS INT), 1)			''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END  
	ELSE IF (@InteractionType = 'YOUTUBE')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_YOUTUBE_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_YOUTUBE
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''YOUTUBE''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								ContactName													''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								DurationTime												''durationTime'', 
								AttentionTime												''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @SQL_FILTER += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
	END

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM ' + @HISTORICAL_DATA_I6_TABLE + ' HDI6 (NOLOCK) '

	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
	IF OBJECT_ID('TEMPDB..#TMP_HD_INTERACTIONS') IS NULL
	BEGIN
		-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
		CREATE TABLE #TMP_HD_INTERACTIONS
		(
			vcc VARCHAR(50), 
			id VARCHAR(250),  
			folder VARCHAR(50),
			exportedContent VARCHAR(250),  
			channel VARCHAR(50), 
			campaign VARCHAR(50), 
			startDate DATETIME,
			endDate DATETIME,
			account VARCHAR(50), 
			initiative VARCHAR(50), 
			contactName VARCHAR(250), 
			firstTakedAgent VARCHAR(50), 
			lastTakedAgent VARCHAR(50), 
			isTaken VARCHAR(50), 
			totalMessages INT,
			durationTime VARCHAR(50),  
			attentionTime VARCHAR(50), 
			dispositionCode VARCHAR(250), 
			dispositionTreePath VARCHAR(250), 
		)

		-- REAFIRMAMOS QUE EL SP NO ESTA ANIDADO EN OTRO
		SET @IS_NESTED = 0

		-- PRINT 'SP NO ANIDADO'
	END
	ELSE
	BEGIN
		-- SI LA TABLA TEMPORAL YA EXISTIA, EL SP ESTA ANIDADO EN OTRO (P.E.: [dbo].[GetAsyncBillingInteractions])
		SET @IS_NESTED = 1

		-- PRINT 'SP ANIDADO'
	END 

	-- INSERTAMOS EL RESULTADO EN LA TABLA TEMPORAL
	INSERT INTO #TMP_HD_INTERACTIONS
		-- EJECUTAMOS LA CONSULTA
		EXEC (@SQL_SELECT)

	-- SI EL SP NO ESTA ANIDADO, HACEMOS SELECT AL RESULTADO A MOSTRAR
	IF @IS_NESTED = 0
	BEGIN
		-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
		IF @UniqueIds = 1 
		BEGIN
			SELECT TBL.[channel]										AS 'interactionType',
					COUNT(DISTINCT (
						CASE WHEN @InteractionType = 'CALL' 
						THEN TBL.[id] 
						ELSE CONCAT(TBL.[id], TBL.[endDate]) 
						END))											AS 'interactions',
					COUNT(*) AS 'details'
				FROM #TMP_HD_INTERACTIONS TBL
				GROUP BY TBL.[channel]
		END
		ELSE
		BEGIN
			SELECT * FROM #TMP_HD_INTERACTIONS
		END
	END

	/*
	-- DECLARAMOS LAS CTE
	WITH CTE_AVAILABLE_BALANCE_REPORT AS (
		SELECT * FROM #TMP_HD_INTERACTIONS
	)
	select * from CTE_AVAILABLE_BALANCE_REPORT 
	*/
END
GO
PRINT N'Altering [dbo].[GetAudio]...';


GO
ALTER PROCEDURE [dbo].[GetAudio] (
	@VCC Varchar(50) = NULL,
	@ProcessId Varchar(50) = NULL,
	@ID Varchar(100) = NULL,
	@Section NUMERIC(5, 0) NULL,
	@Part NUMERIC(5, 0) NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT TOP 1
		A.[ID]						'id',
		A.[Section]					'section',
		A.[Part]					'part',
		PA.[ProcessId]				'processId',
		A.[Number]					'number',
		A.[Gender]					'gender',
		A.[SilenceTime]				'silenceTime',
		A.[DurationTime]			'durationTime',
		A.[DurationLinguisticTime]	'durationLinguisticTime',
		A.[Category1]				'category1',
		A.[Category2]				'category2',
		A.[Category3]				'category3',
		A.[Description]				'description',
		A.[Campaign]				'campaign',
		A.[Agent]					'agent',
		A.[Type]					'type',
		A.[Init]					'init',
		A.[IsTranscribed]			'isTranscribed',
		A.[FileName]				'fileName'
	FROM [Audio] A (NOLOCK)
	LEFT JOIN [ProcessAudio] PA (NOLOCK)
		ON A.ID = PA.AudioId 
			AND A.Section = PA.Section 
			AND A.Part = PA.Part
	LEFT JOIN [dbo].[Process] P (NOLOCK)
		ON PA.[ProcessId] = P.[Name]
	WHERE A.[VCC] = @VCC
		AND (
			(@ProcessId IS NOT NULL AND P.[Name] = @ProcessId)
			OR 
			(@ProcessId IS NULL)
		)
		AND A.[ID] = @ID
		AND A.[Section] = @Section
		AND A.[Part] = @Part
		AND A.[IsTranscribed] = 1
		AND A.[IsCancel] IS NULL
		AND P.[Name] IS NOT NULL
	ORDER BY A.CreatedDate DESC

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetAudiosProcess]...';


GO
-- [dbo].[GetAudiosProcess] 5, 1, 'allegro', 'proceso1', '', '2019-04-11 00:00:00.000', '2019-06-06 04:59:59.997', 22, 26, 23, 59, 'entrantes,PruebasJair,VideoCall', 'icagente', NULL, 'allegro', '', ''
ALTER PROCEDURE [dbo].[GetAudiosProcess]
(
	@PageSize				INT,
	@PageNumber				INT,
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@ID						VARCHAR(250),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				INT,
	@StartMinute			INT,
	@EndHour				INT,
	@EndMinute				INT,
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					VARCHAR(50),
	@IdathaResults			NVARCHAR(MAX),
	@TotalIdathaResults		INT,
	@InteractionType		VARCHAR(50),
	@Folder					VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- DEFINIMOS UNA TABLE TEMPORAL PARA DEPOSITAR LA TODOS LAS INTERACCIONES DEL PROCESS
	CREATE TABLE #PROCESS_INTERACTIONS(
		vcc VARCHAR(50),
		interactionType VARCHAR(100),
		id VARCHAR(250),
		section VARCHAR(100),
		part VARCHAR(100),
		processId VARCHAR(100),
		number VARCHAR(100),
		name VARCHAR(100),
		silenceTime INT,
		durationTime INT,
		durationLinguisticTime INT,
		category1 VARCHAR(100),
		category2 VARCHAR(100),
		category3 VARCHAR(100),
		agent VARCHAR(100),
		description VARCHAR(100),
		environment VARCHAR(100),
		isTranscribed VARCHAR(100),
		createdDate DATETIME,
		endDate DATETIME,
		campaign VARCHAR(50),
		dispositionCode VARCHAR(250),
		folder VARCHAR(50)
	)

	-- INSERTAMOS LOS REGISTROS CALL
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT A.[VCC]						'vcc',
				'CALL'						'interactionType',
				A.[ID]						'id',
				A.[Section]					'section',
				A.[Part]					'part',
				PA.[ProcessId]				'processId',
				A.[Number]					'number',
				P.[Name]					'name',
				A.[SilenceTime]				'silenceTime',
				A.[DurationTime]			'durationTime',
				A.[DurationLinguisticTime]	'durationLinguisticTime',
				A.[Category1]				'category1',
				A.[Category2]				'category2',
				A.[Category3]				'category3',
				A.[Agent]					'agent',
				A.[Description]				'description',
				P.[Environment]				'environment',
				A.[IsTranscribed]			'isTranscribed',
				A.[CreatedDate]				'createdDate',
				A.[EndDate]					'endDate',
				A.[Campaign]				'campaign',
				A.[DispositionCode]			'dispositionCode',
				NULL						'folder'
			FROM [dbo].[Audio] A (NOLOCK)
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON A.ID = PA.AudioId 
					AND A.Section = PA.Section 
					AND A.Part = PA.Part
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON PA.[ProcessId] = P.[Name]
			WHERE A.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'

	-- INSERTAMOS LOS REGISTROS DE INTERACCIONES DE OTROS CANALES
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT AI.[VCC]						'vcc',
				AI.[Channel]				'interactionType',
				AI.[ID]						'id',
				NULL						'section',
				NULL						'part',
				PAI.[ProcessId]				'processId',
				NULL						'number',
				PAI.[ProcessId]				'name',
				NULL						'silenceTime',
				NULL						'durationTime',
				NULL						'durationLinguisticTime',
				NULL						'category1',
				NULL						'category2',
				NULL						'category3',
				AI.[FirstTakedAgent]		'agent',
				''							'description',
				'I6'						'environment',
				AI.[IsTranscribed]			'isTranscribed',
				AI.[CreatedDate]			'createdDate',
				AI.[EndDate]				'endDate',
				AI.[Campaign]				'campaign',
				AI.[DispositionTreePath]	'dispositionCode',
				AI.[Folder]					'folder'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
					--AND AI.[Campaign] = PAI.[Campaign]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON P.[Name] = PAI.[ProcessId]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
		
	-- DECLARAMOS VARIABLE PARA LA CONSULTA ACUMULADA QUE LANZAREMOS
	DECLARE @SQL NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE_IDATHA NVARCHAR(MAX) = ''
	
	SET @SQL_WHERE = ''
	SET @SQL_WHERE_IDATHA = ''

	-- HACEMOS EL PRIMER QUERY PARA SACAR EL NUMERO DE REGISTROS DEL PROCESS
	SET @SQL = ' SET NOCOUNT ON
	DECLARE @rows INT
	DECLARE @SYNC_INTERACTIONS INT
	DECLARE @ASYNC_INTERACTIONS INT
	DECLARE @maxDurationTime Numeric(12,3)

	SELECT @SYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] = ''CALL''
	SELECT @ASYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] <> ''CALL''
	SELECT @maxDurationTime = MAX([durationTime]) FROM #PROCESS_INTERACTIONS 
	'

	SET @SQL += '
		SET @rows = (
			SELECT COUNT(PI.[id])
				FROM #PROCESS_INTERACTIONS PI (NOLOCK)
				WHERE PI.[vcc] = ''' + @VCC + ''' 
					'
	IF (@ProcessId IS NOT NULL) 
			SET @SQL += 'AND PI.[ProcessId]= ''' + @ProcessId + ''' 
						'

	IF(@Type = 'query')
	BEGIN
		SET @SQL_WHERE_IDATHA += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) IN (''' + @IdathaResults + '''))
						OR (PI.[id] IN (''' + @IdathaResults + ''')))
					'
	
		SET @SQL += @SQL_WHERE_IDATHA

	END
	ELSE IF(@Type = 'allegro' OR @Type = 'ftp' OR @Type = 'sftp' OR @Type = 'fileSystem')
	BEGIN
		IF (@ID IS NOT NULL) 
			SET @SQL_WHERE += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) LIKE ''%' + @ID + '%'')
						OR (PI.[id] = ''' + @ID + '''))
					'
		
		IF (@Campaign IS NOT NULL AND LEN(@Campaign) > 0) 
			SET @SQL_WHERE += 'AND PI.[campaign] IN (''' + @Campaign + ''')
						'
		
		IF (@Agent IS NOT NULL AND LEN(@Agent) > 0) 
			SET @SQL_WHERE += 'AND (PI.[agent] IN (''' + @Agent + '''))
							OR (PI.[agent] IS NULL)
						'
		
		/*CORREGIR
		IF (@ResultCode IS NOT NULL AND LEN(@ResultCode) > 0) 
			SET @SQL_WHERE += 'AND (CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), '''')) IN (''' + @ResultCode + '''))
							OR (PI.[dispositionCode] IN (''' + @ResultCode + ''')) '
		*/
		
		IF (@InteractionType IS NOT NULL AND LEN(@InteractionType) > 0) 
			SET @SQL_WHERE += 'AND PI.[interactionType] = ''' + @InteractionType + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 
			SET @SQL_WHERE += 'AND PI.[folder] = ''' + @Folder + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 

		IF (@StartDate IS NOT NULL AND @EndDate IS NOT NULL) 
			SET @SQL_WHERE += 'AND PI.[endDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' 
						AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
						'
		
		IF (@StartHour IS NOT NULL AND @EndHour IS NOT NULL) 
			SET @SQL_WHERE += 'AND DATEPART(HOUR, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartHour) + ' 
						AND DATEPART(HOUR, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndHour) + '
						'
		
		IF (@StartMinute IS NOT NULL AND @EndMinute IS NOT NULL) 
			SET @SQL_WHERE += 'AND DATEPART(MINUTE, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartMinute) + ' 
						AND DATEPART(MINUTE, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndMinute) + '
						'
		
	END

	SET @SQL += @SQL_WHERE
	SET @SQL += ') '
	SET @SQL += 'SELECT @rows AS total, 
						@maxDurationTime AS maxDurationTime,
						@ASYNC_INTERACTIONS AS asyncDetails, 
						@SYNC_INTERACTIONS AS audios'
		
	SET @SQL += '
		SELECT PI.[interactionType],
				PI.[id],
				PI.[section],
				PI.[part],
				PI.[processId],
				PI.[folder],
				PI.[campaign],
				PI.[number],
				PI.[name],
				PI.[silenceTime],
				PI.[durationTime],
				PI.[durationLinguisticTime],
				PI.[category1],
				PI.[category2],
				PI.[category3],
				PI.[agent],
				PI.[description],
				PI.[environment],
				PI.[isTranscribed],
				PI.[createdDate],
				PI.[endDate]
			FROM #PROCESS_INTERACTIONS PI
			WHERE PI.[vcc] = ''' + @VCC + ''' 
				'

	IF(@ProcessId IS NOT NULL) SET @SQL += 'AND PI.[processId] = ''' + @ProcessId + ''' '
			
	SET @SQL += ' '

	SET @SQL += @SQL_WHERE
	SET @SQL += @SQL_WHERE_IDATHA
	SET @SQL += 'ORDER BY PI.[ID], 
						PI.[ProcessId], 
						PI.[Agent], 
						PI.[Description], 
						PI.[Environment], 
						PI.[DurationTime], 
						PI.[CreatedDate]
			OFFSET ' + CONVERT(VARCHAR(50), @PageSize) + ' * (' + CONVERT(VARCHAR(50), @PageNumber) + ' - 1) ROWS
			FETCH NEXT ' + CONVERT(VARCHAR(50), @PageSize) + ' ROWS ONLY
			'

	SET @SQL += ' SET NOCOUNT OFF'
	print @SQL
	EXEC(@SQL)
	
	DROP TABLE #PROCESS_INTERACTIONS
END
GO
PRINT N'Altering [dbo].[GetProcessValidDurationTime]...';


GO
ALTER  PROCEDURE [dbo].[GetProcessValidDurationTime](
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50)
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE RETORNAR LA CANTIDAD DE SEGUNDOS DE TRANSCRIPCION DE AUDIO CORRESPONDIENTE A UN PROCESS
	SET XACT_ABORT, NOCOUNT ON
	
	SELECT P.[Name] 'name',
			SUM(A.[DurationLinguisticTime]) 'validDurationTime'
		FROM Process P (NOLOCK)
		LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON PA.[ProcessId] = P.[Name]
		LEFT JOIN [dbo].[Audio] A (NOLOCK) 
			ON A.[ID] = PA.[AudioId]
				AND A.[Section] = PA.[Section]
				AND A.[Part] = PA.[Part]
		WHERE P.[VCC] = @VCC 
			AND P.[Name] = @ProcessId
		GROUP BY P.[Name] 

	SET XACT_ABORT, NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetStudyGenericQueryTask]...';


GO

ALTER PROCEDURE [dbo].[GetStudyGenericQueryTask]
(
	@VCC				VARCHAR(50),
	@ProcessId			VARCHAR(50),
	@StudyId			VARCHAR(200)
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT DISTINCT
		S.[VCC]				'vcc',
		S.[ProcessId]		'processId',
		TTI.[ID]			'queryId',
		S.[Name]			'studyId'
	FROM
		[dbo].[Study] S WITH (NOLOCK)
		INNER JOIN [dbo].[TemplateThemeItem] TTI WITH (NOLOCK) ON S.[TemplateId] = TTI.[TemplateId]
		INNER JOIN [dbo].[GenericQuery] GQ WITH (NOLOCK) ON TTI.[ID] = GQ.[Name]
	WHERE
		S.[VCC] = @VCC
		AND S.[ProcessId] = @ProcessId
		AND S.[Name] = @StudyId

	SET NOCOUNT OFF
END
GO
PRINT N'Creating [dbo].[GetInteractionTranscription]...';


GO
-- ESTE SP RETORN LAS TRANSCRIPCIONES DE UNA INTERACCION SEGUN SU VCC, INTERACTIONTYPE(CHANNEL), INTERACTIONID
CREATE PROCEDURE [dbo].[GetInteractionTranscription] (
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50) = NULL,
	@InteractionType VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SI PROCESSID IS NULL RETORNA TODAS LAS TRANSCRIPCIONES DEL ID
	-- SI PROCESSID IS NOT NULL RETORNA TOADAS LAS TRANSCRIPCIONES DE ID RELACIONADAS CON EL PROCESSASYNCINTERACTION

	-- AGREGAMOS LA BUSQUEDA PARA CANALES DE TEXTO
	IF @InteractionType <> 'CALL'
	BEGIN
	
		SELECT DISTINCT AI.[VCC]					'vcc',
						AI.[Campaign]				'campaign',
						AI.[Channel]				'interactionType',
						AI.[ID]						'interactionId',
						AI.[Folder]					'folder',
						AI.[FileName]				'jsonFileName',
						AI.[ViewFileName]			'viewFileName',
						P.[Name]					'processId'
			FROM [dbo].[AsyncInteraction] AI (NOLOCK)
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = AI.[VCC]
					AND PAI.[Campaign] = AI.[Campaign]
					AND PAI.[InteractionType] = AI.[Channel]
					AND PAI.[FormattedEndDate] = AI.[Folder]
					AND PAI.[InteractionId] = AI.[ID]
					AND PAI.[ProcessId] = @ProcessId
			LEFT JOIN [dbo].[Process] P (NOLOCK)
				ON P.[VCC] = AI.[VCC]
					AND P.[Name] = PAI.[ProcessId]
			WHERE AI.[VCC] = @VCC
				AND AI.[Channel] = @InteractionType
				AND AI.[ID] = @InteractionId
				AND AI.[IsTranscribed] = 1
				AND (
					(@ProcessId IS NOT NULL AND PAI.[ProcessId] IS NOT NULL)
					OR
					(@ProcessId IS NULL AND PAI.[ProcessId] IS NULL)	
				)
			ORDER BY AI.[Folder] ASC

	END
	ELSE 
	BEGIN
		DECLARE @ID VARCHAR(50) = ''
		IF EXISTS (
			SELECT 1 
				FROM [dbo].[Audio] A (NOLOCK)
				WHERE A.[VCC] = 'occ_test'--@VCC 
					AND (
						(CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
						OR
						(A.[ID] = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
					)
		) 
		BEGIN
			SET @ID = (
						SELECT TOP 1 A.[ID]
							FROM [dbo].[Audio] A (NOLOCK)
								WHERE A.[VCC] = 'occ_test'--@VCC 
									AND (
										(CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
										OR
										(A.[ID] = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
									)
						)

			SELECT *
				FROM [dbo].[Audio] A (NOLOCK)
				WHERE A.[VCC] = 'occ_test'--@VCC 
					AND A.[ID] = @ID
		END

		SELECT 'SOON...'

	END

	SET NOCOUNT OFF
END
GO
PRINT N'Refreshing [dbo].[DeleteProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteProcess]';


GO
PRINT N'Refreshing [dbo].[GetAsyncBillingInteractions]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAsyncBillingInteractions]';


GO
PRINT N'Update complete.';


GO
