PRINT N'Starting rebuilding table [dbo].[EvaluationFormat]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_EvaluationFormat] (
    [Instance]                   VARCHAR (50)   NOT NULL,
    [ID]                         VARCHAR (50)   NOT NULL,
    [Description]                VARCHAR (100)  NULL,
    [type]                       VARCHAR (100)  NULL,
    [EnvironmentType]            VARCHAR (50)   NULL,
    [MinQualificationAcceptable] NUMERIC (5, 2) NOT NULL,
    [CreatedDate]                DATETIME       NULL,
    [CreatedByUserId]            VARCHAR (50)   NULL,
    [LastModifiedDate]           DATETIME       NULL,
    [LastModifiedByUserId]       VARCHAR (50)   NULL,
    [TimeStamp]                  DATETIME       NULL,
    [ManagementFormURL]          VARCHAR (1000) NULL,
    [Enabled]                    BIT            NULL,
    [templateId]                 VARCHAR (50)   NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_EvaluationFormat1] PRIMARY KEY CLUSTERED ([Instance] ASC, [ID] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[EvaluationFormat])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_EvaluationFormat] ([Instance], [ID], [Description], [type], [MinQualificationAcceptable], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp], [ManagementFormURL], [Enabled], [templateId])
        SELECT   [Instance],
                 [ID],
                 [Description],
                 [type],
                 [MinQualificationAcceptable],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp],
                 [ManagementFormURL],
                 [Enabled],
                 [templateId]
        FROM     [dbo].[EvaluationFormat]
        ORDER BY [Instance] ASC, [ID] ASC;
    END

DROP TABLE [dbo].[EvaluationFormat];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_EvaluationFormat]', N'EvaluationFormat';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_EvaluationFormat1]', N'PK_EvaluationFormat', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Starting rebuilding table [dbo].[EvaluationPlan]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_EvaluationPlan] (
    [Instance]                  VARCHAR (50)   NOT NULL,
    [ID]                        VARCHAR (50)   NOT NULL,
    [Modality]                  VARCHAR (50)   NOT NULL,
    [DateFin]                   DATETIME       NOT NULL,
    [CreatedDate]               DATETIME       NULL,
    [CreatedByUserId]           VARCHAR (50)   NULL,
    [LastModifiedDate]          DATETIME       NULL,
    [LastModifiedByUserId]      VARCHAR (50)   NULL,
    [TimeStamp]                 DATETIME       NULL,
    [IdEvaluationFormat]        VARCHAR (50)   NULL,
    [EnvironmentId]             VARCHAR (100)  NULL,
    [Description]               VARCHAR (200)  NULL,
    [Enabled]                   BIT            NULL,
    [Total]                     INT            NULL,
    [Progress]                  INT            NULL,
    [Error]                     INT            NULL,
    [Percentage]                FLOAT (53)     NULL,
    [StatusDescription]         VARCHAR (MAX)  NULL,
    [Status]                    NUMERIC (2)    NULL,
    [Evaluation_Mode]           VARCHAR (1)    NULL,
    [FilterByContent]           BIT            NULL,
    [FilterByContentPercentage] NUMERIC (3)    NULL,
    [EvaluatePercentage]        NUMERIC (3)    NULL,
    [ProcessAndEvaluate]        BIT            NULL,
    [FilterByContentQueryName]  VARCHAR (50)   NULL,
    [FilterByContentQuery]      VARCHAR (1000) NULL,
    [EvaluationStarted]         BIT            NULL,
    [ProcessId]                 VARCHAR (50)   NULL,
    [BatchStatus]               VARCHAR (50)   NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_EvaluationPlan1] PRIMARY KEY CLUSTERED ([Instance] ASC, [ID] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[EvaluationPlan])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_EvaluationPlan] ([Instance], [ID], [Modality], [DateFin], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp], [IdEvaluationFormat], [Description], [Enabled], [Total], [Progress], [Error], [Percentage], [StatusDescription], [Status], [Evaluation_Mode], [FilterByContent], [FilterByContentPercentage], [EvaluatePercentage], [ProcessAndEvaluate], [FilterByContentQueryName], [FilterByContentQuery], [EvaluationStarted], [ProcessId], [BatchStatus])
        SELECT   [Instance],
                 [ID],
                 [Modality],
                 [DateFin],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp],
                 [IdEvaluationFormat],
                 [Description],
                 [Enabled],
                 [Total],
                 [Progress],
                 [Error],
                 [Percentage],
                 [StatusDescription],
                 [Status],
                 [Evaluation_Mode],
                 [FilterByContent],
                 [FilterByContentPercentage],
                 [EvaluatePercentage],
                 [ProcessAndEvaluate],
                 [FilterByContentQueryName],
                 [FilterByContentQuery],
                 [EvaluationStarted],
                 [ProcessId],
                 [BatchStatus]
        FROM     [dbo].[EvaluationPlan]
        ORDER BY [Instance] ASC, [ID] ASC;
    END

DROP TABLE [dbo].[EvaluationPlan];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_EvaluationPlan]', N'EvaluationPlan';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_EvaluationPlan1]', N'PK_EvaluationPlan', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Altering [dbo].[GetEvaluationFormat]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationFormat] (
	@Instance Varchar(50) = NULL, @ID Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[ID]							'id',
		[Description]					'description',
		[EnvironmentType]				'environmentType',
		[Type]							'type',
		[MinQualificationAcceptable]	'minQualificationAcceptable',
		[CreatedDate]					'createdDate',
		[CreatedByUserId]				'createdByUserId',
		[LastModifiedDate]				'lastModifiedDate',
		[LastModifiedByUserId]			'lastModifiedByUserId',
		[ManagementFormURL]				'managementFormURL',
		[Enabled]						'enabled',
		[templateId]					'templateId'
	FROM [EvaluationFormat] (NOLOCK)
	WHERE [Instance] = @Instance
	AND [ID] = @ID

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetEvaluationFormats]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationFormats] (
@Instance Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL, @Disabled bit = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		e.ID							'id',
		e.Description					'description',
		e.EnvironmentType				'environmentType',
		e.Type							'type',
		e.MinQualificationAcceptable	'minQualificationAcceptable',
		e.CreatedDate					'createdDate',
		e.CreatedByUserId				'createdByUserId',
		e.LastModifiedDate				'lastModifiedDate',
		e.LastModifiedByUserId			'lastModifiedByUserId',
		e.[Enabled]						'enabled',
		e.[templateId]					'templateId'
	FROM EvaluationFormat e (NOLOCK)
	WHERE e.Instance = @Instance
		AND ISNULL(e.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(e.Description, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' COLLATE Latin1_General_CI_AI ELSE '%' END
		AND ISNULL(@Disabled, 0) <> [Enabled]

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[SaveEvaluationFormat]...';


GO

ALTER PROCEDURE [dbo].[SaveEvaluationFormat] (
	@Instance Varchar(50) = NULL, 						
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type Varchar(50) = NULL,
	@EnvironmentType VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,						
	@CreatedByUserId Varchar(50) = NULL,		
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,			
	@MinQualificationAcceptable numeric(5,2),	
	@ManagementFormURL varchar(1000) = NULL,
	@Enabled bit = NULL, 
	@templateId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- Danny Jhonston:
	-- Inicio:
	-- Validar si el formato tiene al menos un plan asignado.
	-- Validar si el formato tiene un plan de evaluacion que tiene evaluaciones pendientes.

	-- DECLARE @ID VARCHAR(50)
	-- SET @ID = '183fedb7-9dbf-4b1c-8efd-b1164f33c8ba'

	-- Tabla temporal para almacenar resultado de consulta.
	DECLARE @EvaluationsData TABLE (
		[ID]						VARCHAR(50),
		[totalEvaluations]			INT,
		[completedEvaluations]		INT
	)
	INSERT INTO @EvaluationsData
	SELECT
		EP.[ID]									'id',
		COUNT(AEP.[IdInteraction])				'totalEvaluations',
		SUM(CAST(AEP.[Completed] AS INT))		'completedEvaluations'
	FROM
		[dbo].[EvaluationPlan] EP
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP ON EP.[ID] = AEP.[IdEvaluationPlan]
	WHERE
		EP.[Instance] = @Instance
		AND EP.[IdEvaluationFormat] = @ID
	GROUP BY EP.[ID]

	-- Contiene las evaluaciones de un formato.
	DECLARE @TotalEvaluations INT
	SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE (CAST([completedEvaluations] AS NUMERIC(5, 2)) / CAST([totalEvaluations] AS NUMERIC(5, 2))) * 100 > 0)

	--PRINT @TotalEvaluations
	IF(@TotalEvaluations > 0)
	BEGIN
		BEGIN
			-- Tiene evaluaciones asociadas que en al menos se esta evaluando un plan de evaluacion.
			SELECT CAST(-1 AS INT) 'idEvaluationFormat'
			PRINT @@ROWCOUNT
		END
	END
	ELSE
	-- Danny Jhonston:
	-- Fin:
	BEGIN
		-- No tiene evaluaciones asociadas.
		-- Debe continuar con el guardado.

		UPDATE [EvaluationFormat] SET
			[Description] = @Description,
			[Type] = @Type,
			[EnvironmentType] = @EnvironmentType,
			[MinQualificationAcceptable] = @MinQualificationAcceptable,
			[ManagementFormURL] = @ManagementFormURL,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[Enabled] = CASE WHEN @Enabled IS NULL THEN 1 ELSE @Enabled END,
			[TimeStamp] = GETUTCDATE(),
			[templateId] = @templateId
		WHERE [Instance] = @Instance
		AND [ID] = @ID

		

		IF @@ROWCOUNT = 0
			INSERT INTO [EvaluationFormat] (
				[Instance],[ID], [Description], 
				[Type], [EnvironmentType], [MinQualificationAcceptable], [ManagementFormURL],
				[CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
				[Enabled], [TimeStamp], [templateId]
				)
			VALUES (
				@Instance, @ID, @Description, 
				@Type, @EnvironmentType, @MinQualificationAcceptable, @ManagementFormURL,
				@CreatedDate, @CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
				@Enabled, GETUTCDATE(), @templateId
			)

		SELECT CAST(Scope_Identity() AS INT) as 'idEvaluationFormat';
	END

	

    SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetEvaluationPlan]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationPlan] (
    @Instance Varchar(50) = NULL, @ID Varchar(50) = NULL
)
AS
BEGIN
SET NOCOUNT ON

	SELECT
		EP.[ID]												'id',
		EP.[Modality]										'modality',
		EP.[DateFin]										'dateFin',
		EP.[IdEvaluationFormat]								'idEvaluationFormat',
		EP.[Description]									'description',
		EP.[Enabled]										'enabled',
		EP.[CreatedDate]									'createdDate',
		EP.[CreatedByUserId]								'createdByUserId',
		EP.[LastModifiedDate]								'lastModifiedDate',
		EP.[LastModifiedByUserId]							'lastModifiedByUserId',
		EP.[Status]											'status',
		EP.[Evaluation_Mode]								'evaluation_mode',
		EP.[ProcessId]										'processId',
		EP.[EvaluationStarted]								'evaluationStarted',
		EP.[FilterByContent]								'filterByContent',
		EP.[FilterByContentPercentage]						'filterByContentPercentage',
		EP.[FilterByContentQuery]							'filterByContentQuery',
		EP.[FilterByContentQueryName]						'filterByContentQueryName',
		EP.[ProcessAndEvaluate]								'processAndEvaluate',
		EP.[EnvironmentId]									'environmentId',
		E.[Type]											'environmentType'
	FROM [EvaluationPlan] EP (NOLOCK)
	LEFT JOIN [Environment] E (NOLOCK)
		ON E.[VCC] = EP.[Instance]
			AND E.[Name] = EP.[EnvironmentId]
 	WHERE [Instance] = @Instance
		AND [ID] = @ID

SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[SaveEvaluationPlan]...';


GO
ALTER PROCEDURE [dbo].[SaveEvaluationPlan] (
	@Instance Varchar(50) = NULL,
	@ID Varchar(50) = NULL,
	@Modality Varchar(50) = NULL,
	@DateFin Datetime = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@IdEvaluationFormat Varchar(50) = NULL,
	@EnvironmentId VARCHAR(100) = NULL,
	@Description Varchar(200) = NULL,
	@Enabled Bit = NULL,

	@FilterByContent BIT = NULL,
	@FilterByContentPercentage NUMERIC(3,0) = NULL,
	@EvaluatePercentage NUMERIC(3,0) = NULL,
	@ProcessAndEvaluate BIT = NULL,
	@FilterByContentQueryName VARCHAR(50) = NULL,
	@FilterByContentQuery VARCHAR(1000) = NULL,
	@EvaluationStarted BIT = NULL,
	@ProcessId VARCHAR(50) = NULL,
	@Status	NUMERIC(2,0) = NULL,
	@Evaluation_Mode VARCHAR(10) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [EvaluationPlan]
	SET
		[Modality] = @Modality,
		[DateFin] = @DateFin,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE(),
		[IdEvaluationFormat] = @IdEvaluationFormat,
		[EnvironmentId] = @EnvironmentId,
		[Description] =@Description,
		[Enabled] = CASE WHEN @Enabled IS NULL THEN [Enabled] ELSE @Enabled END,
		[EvaluatePercentage] = @EvaluatePercentage,
		[ProcessAndEvaluate] = @ProcessAndEvaluate,
		[FilterByContent] = CASE WHEN @FilterByContent IS NULL THEN [FilterByContent] ELSE @FilterByContent END,
		[FilterByContentPercentage] = CASE WHEN @FilterByContentPercentage IS NULL THEN [FilterByContentPercentage] ELSE @FilterByContentPercentage END,
		[FilterByContentQueryName] = CASE WHEN @FilterByContentQueryName IS NULL THEN [FilterByContentQueryName] ELSE @FilterByContentQueryName END,
		[FilterByContentQuery] = CASE WHEN @FilterByContentQuery IS NULL THEN [FilterByContentQuery] ELSE @FilterByContentQuery END,
		
		[EvaluationStarted] = @EvaluationStarted,
		[ProcessId] = @ProcessId,
		[Status] = @Status,
		[Total] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Total] END,
		[Progress] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Progress] END,
		[Error] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Error] END,
		[Percentage] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Percentage] END,
		[Evaluation_Mode] = @Evaluation_Mode
	WHERE [Instance] = @Instance
    AND [ID] = @ID

    IF @@ROWCOUNT = 0
		INSERT INTO [EvaluationPlan] (
			[Instance],[ID],
			[Modality], [DateFin], [CreatedDate],
			[CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
			[TimeStamp], [IdEvaluationFormat], [EnvironmentId],
			[Description], [Enabled],
			[FilterByContent], [FilterByContentPercentage], [EvaluatePercentage], [ProcessAndEvaluate], [FilterByContentQueryName], [FilterByContentQuery], [EvaluationStarted], [ProcessId],
			[Status],[Evaluation_Mode]
			)
		VALUES (
			@Instance,@ID,
			@Modality, @DateFin, @CreatedDate,
			@CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
			GETUTCDATE(), @IdEvaluationFormat, @EnvironmentId, 
			@Description, 1,
			@FilterByContent, @FilterByContentPercentage, @EvaluatePercentage, @ProcessAndEvaluate, @FilterByContentQueryName, @FilterByContentQuery, @EvaluationStarted, @ProcessId,
			@Status, @Evaluation_Mode
		)

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetAllegroBillingInteractionsForEvaluationPlan]...';


GO
-- ESTE SCRIPT TIENE POR FINALIDAD RETORNAR UN RESUMEN DE LOS AUDIOS EN EL PROCESSID INPUT QUE YA EXISTEN EN UN PROCESSID ANTERIOR
-- DEBIDO A QUE PLANES CREAN EL PROCESS Y EL EVALUATION_PLAN EN DIFERENTES ENDPOINTS, DEJARA DE SER NECESARIO SI SE INTEGRA EL 
-- GUARDADO DE PLAN DE EVALUACION
ALTER PROCEDURE [dbo].[GetAllegroBillingInteractionsForEvaluationPlan] (
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50) = NULL,
	@SecondsPerRequest DECIMAL(18, 5) = NULL
)
AS 
BEGIN 
	-- CREAMOS UNA VARIEBLE PARA ALMACENAR LA FECHA DE CREACION DEL PROCESS INPUT
	--DECLARE @vcc VARCHAR(50) = 'allegro'
	--DECLARE @ProcessId VARCHAR(50) = '3EU91680-UB6U-3GT5-8T50-73474D13WVB8'
	DECLARE @PROCESS_CREATED_DATE DATETIME = NULL

	-- RECUPERAMOS LA FECHA DE CREACION DEL PROCESS INPUT
	SELECT @PROCESS_CREATED_DATE = P.[CreatedDate] 
		FROM [dbo].[Process] P (NOLOCK) 
		WHERE P.[VCC] = @vcc
			AND P.[Name] = @processId;

	-- CREAMOS LAS CTE QUE USAREMOS PARA RECUPERAR EL HISTORICO DE LOS AUDIOS DEL PROCESS INPUT
	WITH CTE_PROCESS_AUDIO AS (
		-- RECUPERAMOS LOS AUDIOS DEL PROCESS INPUT
		SELECT PA.[AudioId],
				PA.[Section],
				PA.[Part]
			FROM [dbo].[ProcessAudio] PA (NOLOCK) 
			WHERE PA.[VCC] = @vcc
				AND PA.[ProcessId] = @processId
	), CTE_PROCESS_AUDIO_2 AS (
		-- CON LA PRIMERA CTE, RECUPERAMOSEL DETALLE DE LOS AUDIOS Y LA CANTIDAD DE VECES QUE SE REPITE EN PROCESS ANTERIORES
		SELECT PA.[AudioId],
				PA.[Section],
				PA.[Part],
				COUNT(*) 'Times' 
			FROM CTE_PROCESS_AUDIO CPA
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON PA.[AudioId] = CPA.[AudioId]
					AND PA.[Section] = CPA.[Section]
					AND PA.[Part] = CPA.[Part]
			WHERE PA.[VCC] = @vcc
				AND PA.[CreatedDate] < @PROCESS_CREATED_DATE
			GROUP BY PA.[AudioId], PA.[Section], PA.[Part]
	), CTE_PROCESS_AUDIO_3 AS (
		-- ARMAMOS UNA CTE CON TODOS LOS AUDIOS QUE SE REPITEN Y EL DETALLE DE CADA AUDIO
		SELECT CPA2.[AudioId],
				CPA2.[Section],
				CPA2.[Part],
				A.[DurationTime],
				A.[DurationLinguisticTime],
				A.[IsProcess],
				A.[IsCancel],
				A.[IsTranscribed],
				A.[TotalPhrases]
			FROM CTE_PROCESS_AUDIO_2 CPA2
			LEFT JOIN [dbo].[Audio] A
				ON A.[ID] = CPA2.[AudioId]
					AND A.[Section] = CPA2.[Section]
					AND A.[Part] = CPA2.[Part]
			WHERE A.[VCC] = @vcc
				AND CPA2.[Times] > 0
	)

	SELECT SUM(CASE WHEN PA3.[IsTranscribed] = 1 THEN 1 ELSE 0 END)							'alreadyTranscribedAudio', 
			SUM(CASE WHEN PA3.[IsTranscribed] = 1 THEN PA3.[DurationTime] ELSE 0 END)		'alreadyTranscribedDurationTime',
			SUM(CASE WHEN PA3.[IsTranscribed] IS NULL 
							AND PA3.[IsCancel] IS NULL 
						THEN 1 ELSE 0 END)													'inProcessAudio', 
			SUM(CASE WHEN PA3.[IsTranscribed] IS NULL 
							AND PA3.[IsCancel] IS NULL 
						THEN PA3.[DurationTime] ELSE 0 END)									'inProcessDurationTime', 
			SUM(CASE WHEN PA3.[IsCancel] = 1 THEN 1 ELSE 0 END)								'canceledAudio', 
			SUM(CASE WHEN PA3.[IsCancel] = 1 THEN PA3.[DurationTime] ELSE 0 END)			'canceledDurationTime',
			SUM(CASE WHEN PA3.[IsTranscribed] = 1 
							AND PA3.[TotalPhrases] IS NOT NULL
						THEN PA3.[TotalPhrases] ELSE 0 END)									'totalPhrases',
			SUM(CASE WHEN PA3.[TotalPhrases] IS NULL 
						THEN (PA3.[DurationTime] / @SecondsPerRequest) ELSE 0 END)			'totalRawPhrases' 
		FROM CTE_PROCESS_AUDIO_3 PA3 
	--SELECT * FROM CTE_PROCESS_AUDIO_4
END
GO
PRINT N'Altering [dbo].[GetAudio]...';


GO
ALTER PROCEDURE [dbo].[GetAudio] (
	@VCC Varchar(50) = NULL,
	@ProcessId Varchar(50) = NULL,
	@ID Varchar(100) = NULL,
	@Section NUMERIC(5, 0) NULL,
	@Part NUMERIC(5, 0) NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT TOP 1
		A.[ID]						'id',
		A.[Section]					'section',
		A.[Part]					'part',
		PA.[ProcessId]				'processId',
		A.[Number]					'number',
		A.[Gender]					'gender',
		A.[SilenceTime]				'silenceTime',
		A.[DurationTime]			'durationTime',
		A.[DurationLinguisticTime]	'durationLinguisticTime',
		A.[Category1]				'category1',
		A.[Category2]				'category2',
		A.[Category3]				'category3',
		A.[Description]				'description',
		A.[Campaign]				'campaign',
		A.[Agent]					'agent',
		A.[Type]					'type',
		A.[Init]					'init',
		A.[IsTranscribed]			'isTranscribed',
		A.[FileName]				'fileName'
	FROM [Audio] A (NOLOCK)
	LEFT JOIN [ProcessAudio] PA (NOLOCK)
		ON A.ID = PA.AudioId 
			AND A.Section = PA.Section 
			AND A.Part = PA.Part
	LEFT JOIN [dbo].[Process] P (NOLOCK)
		ON PA.[ProcessId] = P.[Name]
	WHERE A.[VCC] = @VCC
		AND (
			(@ProcessId IS NOT NULL AND P.[Name] = @ProcessId)
			OR 
			(@ProcessId IS NULL)
		)
		AND A.[ID] = @ID
		AND A.[Section] = @Section
		AND A.[Part] = @Part
		AND A.[IsTranscribed] = 1
		AND A.[IsCancel] IS NULL
		AND P.[Name] IS NOT NULL
	ORDER BY A.CreatedDate DESC, PA.[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
PRINT N'Altering [dbo].[GetCSVBillingInteractions]...';


GO
-- ESTE SP RETORNA UN RESUMEN DE LA BUSQUEDA DE INTERACCIONES DE CSV CRUZANDO CON ALLEGRO PARA INDETIFICAR LOS YA TRANSCRITOS O INPROCESS SEGUN LOS FILTROS RECIBIDOS 
-- FUNCIONA IGUAL QUE LA FUNCION EN KNEX
ALTER PROCEDURE [dbo].[GetCSVBillingInteractions] (
	@VCC VARCHAR(50) = NULL,
	@SecondsPerRequest DECIMAL(18, 5),
	@StartDate DATETIME = '1980-01-01T00:00:00',
    @EndDate DATETIME = '2050-01-01T23:59:59',
	@Campaigns VARCHAR(MAX) = '',
 	@Agents VARCHAR(MAX) = '',
   	@Origins VARCHAR(100) = NULL,
	@StartHour VARCHAR(50) = NULL,
	@EndHour VARCHAR(50) = NULL,
	@MinDuration INT = 0,
    @MaxDuration INT = 100000,
    @Results VARCHAR(MAX) = NULL
) 
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @INTERACTION_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_ACTOR_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_MULTIMEDIA_PARTS_TABLE NVARCHAR(100)
	DECLARE @CAMPAIGN_GOAL_RESULT_MANAGEMENT_TABLE NVARCHAR(100)

	-- SETTEAMOS LOS VALORES DE DURACION MINIMA Y MAXIMA A UNO VALIDO
	IF @MinDuration = @MaxDuration AND @MaxDuration = 0 SET @MaxDuration = 100000
	IF @MinDuration IS NULL SET @MinDuration = 0
	IF @MaxDuration IS NULL SET @MaxDuration = 100000

	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '

	SET @SQL_SELECT_1 += '
				''CALL''																	''interactionType'',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN 1 ELSE 0 END)						''alreadyTranscribedAudio'',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN PCT.[DurationTime] ELSE 0 END)		''alreadyTranscribedDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] = 1 
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL
								) THEN 1 ELSE 0 END)										''inProcessAudio'',
				SUM(CASE WHEN (A.[IsProcess] = 1
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL
								) THEN PCT.[DurationTime] ELSE 0 END)						''inProcessDurationTime'',
				SUM(CASE WHEN A.[IsCancel] = 1 THEN 1 ELSE 0 END)							''canceledAudio'', 
				SUM(CASE WHEN A.[IsCancel] = 1 THEN A.[DurationTime] ELSE 0 END)			''canceledDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL
								OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)
								) THEN 1 ELSE 0 END)										''notTranscribedAudio'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)
								) THEN PCT.[DurationTime] ELSE 0 END)						''notTranscribedDurationTime'', 
				SUM(CASE WHEN A.[IsTranscribed] = 1 
							AND A.[TotalPhrases] IS NOT NULL
						THEN A.[TotalPhrases] ELSE 0 END)									''totalPhrases'',
				SUM(CASE WHEN A.[TotalPhrases] IS NULL 
						THEN (PCT.[DurationTime] / ' + (SELECT CONVERT(varchar(10), @SecondsPerRequest)) + ') ELSE 0 END)			''totalRawPhrases'' ' 
				--SUM(PCT.[DurationTime] / ' + (SELECT CONVERT(varchar(10), @SecondsPerRequest)) + ') ''averageModelResquest'' '
	
	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [#ProcessCsvTemp] PCT
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
				-- ON CONCAT(A.[ID], ''_'', A.[Section], ''_'', A.[Part]) = PCT.[ID]
				ON A.[ID] = PCT.[ID]
					AND A.[VCC] = ''' + @VCC + ''' '

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE PCT.[ID] IS NOT NULL 
				AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' '

	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') 
		SET @SQL_FILTER += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@Agents IS NOT NULL AND @Agents != '') 
		SET @SQL_FILTER += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	
	IF (@Origins IS NOT NULL AND @Origins != '') 
		SET @SQL_FILTER += 'AND PCT.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	
	IF (@Results IS NOT NULL AND @Results != '') 
		SET @SQL_FILTER += ' 
			AND (
				(CONCAT(PCT.[Campaign], ''_'', ISNULL(CONVERT(VARCHAR(4), PCT.[DispositionCode]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @Results + ''','',''))) 
				OR
				(PCT.[Description] IN (SELECT Value FROM [dbo].[split](''' + @Results + ''','','')))
			) '
	
	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	SET @SQL_EXTRA += 'DROP TABLE [#ProcessCsvTemp]'
	
	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	-- EJECUTAMOS LA CONSULTA
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Altering [dbo].[GetCSVSummaryInteractions]...';


GO
-- ESTE SP RETORNA LAS INTERACCIONES SINCRONAS(CALL) DE FTP
ALTER PROCEDURE [dbo].[GetCSVSummaryInteractions] 
(
	@VCC					VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@MinDuration			INT = 0,
    @MaxDuration			INT = 100000,
    @Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
   	@Origins				VARCHAR(100) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@IsSummary				BIT = 0								-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
) 
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NULL OR @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NULL OR @EndHour = '') SET @EndHour = '23:59:59'

	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE MINIMO Y MAXIMO
	IF (@MinDuration IS NULL OR @MinDuration = '') SET @MinDuration = 0
	IF (@MaxDuration IS NULL OR @MaxDuration = '') SET @MaxDuration = 100000
	
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
	IF @IsSummary = 1 
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_0 += '
			SELECT ''CALL''											AS ''interactionType'', 
					COUNT(DISTINCT PCT.[ID])						AS ''totalInteractions'',
					COUNT(*)										AS ''details'',
					ISNULL(SUM(PCT.[DurationTime]), 0)				AS ''totalAttentionTime''
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_0
	END
	ELSE
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_1 += '
			SELECT PCT.[ID]											AS ''ID'',
					PCT.[Number]									AS ''Number'',
					PCT.[Gender]									AS ''Gender'',
					PCT.[SilenceTime]								AS ''SilenceTime'',
					PCT.[DurationTime]								AS ''DurationTime'',
					PCT.[Category1]									AS ''Category1'',
					PCT.[Category2]									AS ''Category2'',
					PCT.[Category3]									AS ''Category3'',
					PCT.[Description]								AS ''Description'',
					PCT.[Campaign]									AS ''Campaign'',
					PCT.[Agent]										AS ''Agent'',
					PCT.[Direction]									AS ''Direction'',
					CONVERT(VARCHAR, PCT.[StartDate], 120)			AS ''StartDate'',
					CONVERT(VARCHAR, PCT.[EndDate], 120)			AS ''EndDate'',
					PCT.[DispositionCode]							AS ''DispositionCode''
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_1
	END
	
	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [#ProcessCsvTemp] PCT '

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE PCT.[ID] IS NOT NULL 
				AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' '

	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') 
		SET @SQL_FILTER += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@Agents IS NOT NULL AND @Agents != '') 
		SET @SQL_FILTER += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	
	IF (@Origins IS NOT NULL AND @Origins != '') 
		SET @SQL_FILTER += 'AND PCT.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') 
		--SET @SQL_FILTER += 'AND PCT.[DispositionCode] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')) '
		SET @SQL_FILTER += ' 
			AND (
				(CONCAT(PCT.[Campaign], ''_'', ISNULL(CONVERT(VARCHAR(4), PCT.[DispositionCode]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','',''))) 
				OR
				(PCT.[Description] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')))
			) '
	
	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @SQL_FILTER += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	SET @SQL_EXTRA += 'DROP TABLE [#ProcessCsvTemp]'
	
	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Creating [dbo].[GetCSVFiltersInteractions]...';


GO
CREATE PROCEDURE [dbo].[GetCSVFiltersInteractions] 
AS
BEGIN
	-- BUSCAMOS LAS CAMPAIGNS DE LA TABLA
	SELECT DISTINCT PCT.[Campaign]									AS 'id',
					PCT.[Campaign]									AS 'description' 
		FROM [#ProcessCsvTemp] PCT
		ORDER BY PCT.[Campaign] ASC

	-- BUSCAMOS LOS AGENTES DE LA TABLA
	SELECT DISTINCT PCT.[Agent]										AS 'userId' 
		FROM [#ProcessCsvTemp] PCT
		ORDER BY PCT.[Agent] ASC

	-- BUSCAMOS LOS DISPOSITIONCODE DE LA TABLA
	SELECT DISTINCT PCT.[Campaign]									AS 'campaignId' ,
					PCT.[Category1]									AS 'description',
					PCT.[Category2]									AS 'description2',
					PCT.[Category3]									AS 'description3',
					PCT.[Description]								AS 'description4',
					PCT.[DispositionCode]							AS 'code'
		FROM [#ProcessCsvTemp] PCT
		WHERE PCT.[Description] IS NOT NULL
			AND PCT.[DispositionCode] IS NOT NULL
		ORDER BY PCT.[Category1] ASC, 
					PCT.[Category2] ASC, 
					PCT.[Category3] ASC,  
					PCT.[Description] ASC

	-- ELIMINAMOSLA TABLA TEMPORAL
	DROP TABLE [#ProcessCsvTemp]
	
END
GO
PRINT N'Creating [dbo].[GetEvaluationPlanByInteractionId]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanByInteractionId] (
	@VCC VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

 	SELECT TOP 1
		EP.[ID]									'id',
		EP.[Modality]							'modality',
		EP.[DateFin]							'dateFin',
		EP.[CreatedDate]						'createdDate',
		EP.[CreatedByUserId]					'createdByUserId',
		EP.[LastModifiedDate]					'lastModifiedDate',
		EP.[LastModifiedByUserId]				'lastModifiedByUserId',
		EP.[Description]						'description',
		EP.[IdEvaluationFormat]					'idEvaluationFormat',
		EP.[EnvironmentId]						'environmentId',
		EP.[Enabled]							'enabled',
		EP.[Status]								'status',
        EP.[Evaluation_Mode]					'evaluation_mode',
        EP.[processId]    						'processId',
        EP.FilterByContent						'filterByContent',
        EP.EvaluatePercentage					'evaluatePercentage',
        EP.ProcessAndEvaluate    				'processAndEvaluate'
	FROM EvaluationPlan EP (NOLOCK) 
	INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
		ON IEP.[IdEvaluationPlan] = EP.[ID]
	WHERE EP.[Instance] = @VCC
		AND IEP.[IdInteraction] = @InteractionId
	GROUP BY EP.[ID], EP.[Modality], EP.[DateFin], EP.[CreatedDate], EP.[CreatedByUserId],
			 EP.[LastModifiedDate], EP.[LastModifiedByUserId], EP.[Description], EP.[IdEvaluationFormat], EP.[EnvironmentId], 
			 EP.[Enabled], EP.[Status], EP.[Evaluation_Mode], EP.[processId], EP.[FilterByContent], 
			 EP.[EvaluatePercentage], EP.[ProcessAndEvaluate]
	ORDER BY EP.[CreatedDate] DESC

 	SET NOCOUNT OFF
END
GO
PRINT N'Refreshing [dbo].[BulkAbilityCognitive]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkAbilityCognitive]';


GO
PRINT N'Refreshing [dbo].[BulkEvaluationPlanAbility]...';


GO
SET ANSI_NULLS ON;

SET QUOTED_IDENTIFIER OFF;


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkEvaluationPlanAbility]';


GO
SET ANSI_NULLS, QUOTED_IDENTIFIER ON;


GO
PRINT N'Refreshing [dbo].[DeleteEvaluationFormat]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteEvaluationFormat]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationFormatDescription]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationFormatDescription]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationFormatDescriptionsBySearchCriteria]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationFormatDescriptionsBySearchCriteria]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlans]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlans]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlansByStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlansByStatus]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]';


GO
PRINT N'Refreshing [dbo].[GetReportByDetailAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetReportByDetailAgent]';


GO
PRINT N'Refreshing [dbo].[GetReportBySummaryAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetReportBySummaryAgent]';


GO
PRINT N'Refreshing [dbo].[ReportByDetailAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportByDetailAgent]';


GO
PRINT N'Refreshing [dbo].[ReportBySummaryAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportBySummaryAgent]';


GO
PRINT N'Refreshing [dbo].[ReportBySummaryFormat]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportBySummaryFormat]';


GO
PRINT N'Refreshing [dbo].[BulkEvaluationPlanQuery]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkEvaluationPlanQuery]';


GO
PRINT N'Refreshing [dbo].[BulkInteractionProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkInteractionProcess]';


GO
PRINT N'Refreshing [dbo].[BulkProgress]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkProgress]';


GO
PRINT N'Refreshing [dbo].[DeleteAuditorEvaluationPlanByInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteAuditorEvaluationPlanByInteraction]';


GO
PRINT N'Refreshing [dbo].[DeleteEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteEvaluationPlan]';


GO
PRINT N'Refreshing [dbo].[EvaluateProcessStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[EvaluateProcessStatus]';


GO
PRINT N'Refreshing [dbo].[FinishedBatchClose]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[FinishedBatchClose]';


GO
PRINT N'Refreshing [dbo].[GetAuditorEvaluationPlanEvaluation]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAuditorEvaluationPlanEvaluation]';


GO
PRINT N'Refreshing [dbo].[GetBatchDetail]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetBatchDetail]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanAbilityGenericQueryTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanAbilityGenericQueryTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanAbilityTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanAbilityTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanByName]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanByName]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanByProcessId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanByProcessId]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanCognitiveInteractionTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveInteractionTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanCognitiveTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanInteractionByTypeAndId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanInteractionByTypeAndId]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationPlanTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanTask]';


GO
PRINT N'Refreshing [dbo].[GetEvaluationsOfInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationsOfInteraction]';


GO
PRINT N'Refreshing [dbo].[GetGenericQueryUsage]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetGenericQueryUsage]';


GO
PRINT N'Refreshing [dbo].[GetProcessEvaluationPlanTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessEvaluationPlanTask]';


GO
PRINT N'Refreshing [dbo].[SaveBatchStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveBatchStatus]';


GO
PRINT N'Refreshing [dbo].[SaveEvaluationPlanAbilityStatusTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationPlanAbilityStatusTask]';


GO
PRINT N'Refreshing [dbo].[SaveEvaluationPlanCompleted]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationPlanCompleted]';


GO
PRINT N'Update complete.';


GO
