ALTER PROCEDURE [dbo].[GetAbilityEvaluationFormats] (
	@Instance Varchar(50) = NULL, @IdEvaluationFormat Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	SELECT
		A.[ID]							'id',
		A.[IdEvaluationFormat]			'idEvaluationFormat',
		A.[IdAbility]					'idAbility',
		AB.[Title]						'titleAbility',
		AB.[Detail]						'detailAbility',
		A.[IdGroup]						'idGroup',
		G.[Description]                 'descriptionGroup',
		A.[IdSubGroup]					'idSubGroup',
		S.[Description]                 'descriptionSubGroup',
		A.[Penalizes]					'penalizes',
		A.[Score]						'score',
		A.[Order]						'order',
		AB.[NotApply]					'acceptNotApplies',
		AB.[AcceptComments]				'acceptComments',
		AB.[Detail]						'descriptionAbility',
		A.[Conditional]					'conditional',
        AB.QueryName					'query'
	FROM [SubGroup] S full join [AbilityEvaluationFormat] A on S.ID=A.IdSubGroup, [Ability] AB,
		 [Group] G (NOLOCK)
	WHERE A.[Instance] = @Instance
	AND S.[Instance] = @Instance
	AND G.[Instance] = @Instance
	AND AB.[Instance] = @Instance
	AND A.IdAbility=AB.ID
	AND A.IdGroup=G.ID
	AND A.[IdEvaluationFormat]= @IdEvaluationFormat
	ORDER BY [Order] ASC
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationPlan]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationPlan] (
    @Instance Varchar(50) = NULL, @ID Varchar(50) = NULL
)
AS
BEGIN
SET NOCOUNT ON

	SELECT
		EP.[ID]												'id',
		EP.[Modality]										'modality',
		EP.[DateFin]										'dateFin',
		EP.[IdEvaluationFormat]								'idEvaluationFormat',
		EP.[Description]									'description',
		EP.[Enabled]										'enabled',
		EP.[CreatedDate]									'createdDate',
		EP.[CreatedByUserId]								'createdByUserId',
		EP.[LastModifiedDate]								'lastModifiedDate',
		EP.[LastModifiedByUserId]							'lastModifiedByUserId',
		EP.[Status]											'status',
		EP.[Evaluation_Mode]								'evaluation_mode',
		EP.[ProcessId]										'processId',
		EP.[EvaluationStarted]								'evaluationStarted',
		EP.[FilterByContent]								'filterByContent',
		EP.[FilterByContentPercentage]						'filterByContentPercentage',
		EP.[FilterByContentQuery]							'filterByContentQuery',
		EP.[FilterByContentQueryName]						'filterByContentQueryName',
		EP.[ProcessAndEvaluate]								'processAndEvaluate',
		EP.[TranscriptionLanguage]							'transcriptionLanguage',
		EP.[EnvironmentId]									'environmentId',
		E.[Type]											'environmentType'
	FROM [EvaluationPlan] EP (NOLOCK)
	LEFT JOIN [Environment] E (NOLOCK)
		ON E.[VCC] = EP.[Instance]
			AND E.[Name] = EP.[EnvironmentId]
 	WHERE [Instance] = @Instance
		AND [ID] = @ID

SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan] (
	@Instance Varchar(50) = NULL,
    @EvaluationPlanId Varchar(50) = NULL,
    @InteractionId varchar(250) = NULL,
    @InteractionType varchar(50) = NULL,
    @AuditorId varchar(50) = NULL,
    @AgentId varchar(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON

    SELECT
         EF.Id										'EvaluationFormatId'				-- Id
        ,EF.Description								'EvaluationFormatDescription'		-- Titulo del reporte
        ,ER.Instance								'Instance'							-- Subtitulo del reporte
        ,ER.IdAgent									'AgentId'							-- Agente
        ,ER.IdAgent									'AgentDescription'					-- Agente
        ,CONCAT(U.Firstname, ' ', U.Lastname)		'CoordinatorFullName'				-- Coordinador
        ,AEP.IdAuditor								'AuditorId'							-- Auditor
        ,CONCAT(UA.Firstname, ' ',UA.Lastname)		'AuditorDescription'				-- Auditor
		,AEP.IdAuditor
        ,ER.IdCampaign								'CampaignDescription'				-- Campana
        ,ER.IdInteraction							'InteractionId'						-- Grabacion
        ,ER.InteractionType							'InteractionType'					-- Tipo interaccion
        ,ER.InteractionDateini						'InteractionDateIni'				-- Fecha inicio de la interaccion
		,ER.[InteractionDatefin]					'InteractionDateFin'				-- Fecha fin de la interaccion
        ,ER.InteractionAddress						'Contacto'							-- Telefono
        ,ER.EvaluationDate							'EvaluationDate'					-- Fecha monitoreo
        ,AEP.Score									'TotalScore'						-- Puntaje total
        ,G.Id										'GroupId'							-- Grupo
        ,G.Description								'Group'								-- Grupo
        ,SG.Id										'SubGroupId'						-- Subgrupo
        ,SG.Description								'SubGroup'							-- Subgrupo
        ,AB.Id										'AbilityId'							-- Habilidad
        ,AB.Title									'Ability'							-- Habilidad
		,AB.[Detail]								'AbilityDetail'						-- Habilidad
        ,ER.Comment									'Observacion'						-- Observacion de la habilidad
        ,ER.MaxAbilityScore							'Puntaje'							-- Puntaje
        ,ER.ScoreDescription						'Eval'								-- Eval
        ,ER.Qualification							'Nota'								-- Nota
        ,ER.NotApplies								'NotApplies'
        ,ER.AbilityOrder							'Order'
        ,ER.Conditional                             'conditionalSelected'
    FROM [EvaluationResult] ER (NOLOCK)
    INNER JOIN	[EvaluationFormat] EF (NOLOCK)
	--LEFT JOIN [EvaluationFormat] EF (NOLOCK)
		ON (ER.Instance = EF.Instance 
			AND	ER.IdEvaluationFormat = EF.ID)
    LEFT JOIN [User] U (NOLOCK)
		ON (EF.Instance = U.VCC
			AND EF.CreatedByUserId = U.ID)
    --INNER JOIN [User] UA (NOLOCK)
	LEFT JOIN [User] UA (NOLOCK)
		ON (ER.Instance = UA.VCC 
			AND ER.IdEvaluator = UA.ID)
    --INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
	LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
		ON (ER.IdEvaluationPlan	= AEP.IdEvaluationPlan
			AND UA.ID = AEP.IdAuditor
			AND ER.IdInteraction = AEP.IdInteraction
			AND ER.InteractionType = AEP.InteractionType
			AND ER.IdAgent = AEP.IdAgent)
    LEFT JOIN [Group] G (NOLOCK)
		ON (ER.Instance = G.Instance
			AND ER.IdGroup = G.ID)
    LEFT JOIN [SubGroup] SG (NOLOCK)
		ON (ER.Instance = SG.Instance 
			AND ER.IdSubGroup = SG.ID)
    LEFT JOIN [Ability] AB (NOLOCK)
		ON (ER.Instance = AB.Instance 
			AND ER.IdAbility = AB.ID)
    WHERE ER.Instance = @Instance
		AND ER.IdEvaluationPlan	= @EvaluationPlanId
		AND ER.IdInteraction = @InteractionId
		AND ER.InteractionType = @InteractionType
		--AND ER.IdEvaluator = @AuditorId
		AND ER.IdAgent = @AgentId
    ORDER BY ER.AbilityOrder ASC;

    SET NOCOUNT OFF
END
GO
PRINT N'Actualización completada.';


GO
